@@ -62,9 +62,11 @@ func (q *Quantile) Add(in telegraf.Metric) {
 	}
 	for k, field := range in.Fields() {
 		if v, isconvertible := convert(field); isconvertible {
-			// This should never error out as we tested it in Init()
-			algo, _ := q.newAlgorithm(q.Compression)
-			err := algo.Add(v)
+			algo, err := q.newAlgorithm(q.Compression)
+			if err != nil {
+				q.Log.Errorf("generating algorithm %s: %v", k, err)
+			}
+			err = algo.Add(v)
 			if err != nil {
 				q.Log.Errorf("adding field %s: %v", k, err)
 			}
