@@ -7,6 +7,7 @@ import (
 	mqttv3 "github.com/eclipse/paho.mqtt.golang" // Library that supports v3.1.1
 
 	"github.com/influxdata/telegraf/internal"
+	"github.com/influxdata/telegraf/logger"
 )
 
 type mqttv311Client struct {
@@ -77,6 +78,14 @@ func NewMQTTv311Client(cfg *MqttConfig) (*mqttv311Client, error) {
 		opts.AddBroker(broker)
 	}
 
+	if cfg.ClientTrace {
+		log := &mqttLogger{logger.NewLogger("paho", "", "")}
+		mqttv3.ERROR = log
+		mqttv3.CRITICAL = log
+		mqttv3.WARN = log
+		mqttv3.DEBUG = log
+	}
+
 	return &mqttv311Client{
 		client:  mqttv3.NewClient(opts),
 		timeout: time.Duration(cfg.Timeout),
