@@ -191,7 +191,7 @@ func TestPluginInitialize(t *testing.T) {
 			if tt.expectedErrorString != "" {
 				require.EqualError(t, plugin.Init(), tt.expectedErrorString)
 			} else {
-				require.Equal(t, nil, plugin.Init())
+				require.NoError(t, plugin.Init())
 			}
 			if len(tt.regions) == 0 { //Check if set to default
 				require.Equal(t, plugin.Regions, aliyunRegionList)
@@ -295,14 +295,15 @@ func TestPluginMetricsInitialize(t *testing.T) {
 			if tt.expectedErrorString != "" {
 				require.EqualError(t, plugin.Init(), tt.expectedErrorString)
 			} else {
-				require.Equal(t, nil, plugin.Init())
+				require.NoError(t, plugin.Init())
 			}
 		})
 	}
 }
 
 func TestUpdateWindow(t *testing.T) {
-	duration, _ := time.ParseDuration("1m")
+	duration, err := time.ParseDuration("1m")
+	require.NoError(t, err)
 	internalDuration := config.Duration(duration)
 
 	plugin := &AliyunCMS{
@@ -391,10 +392,10 @@ func TestGather(t *testing.T) {
 
 	//test table:
 	tests := []struct {
-		name          string
-		hasMeasurment bool
-		metricNames   []string
-		expected      []telegraf.Metric
+		name           string
+		hasMeasurement bool
+		metricNames    []string
+		expected       []telegraf.Metric
 	}{
 		{
 			name:        "Empty data point",
@@ -408,9 +409,9 @@ func TestGather(t *testing.T) {
 			},
 		},
 		{
-			name:          "Data point with fields & tags",
-			hasMeasurment: true,
-			metricNames:   []string{"InstanceActiveConnection"},
+			name:           "Data point with fields & tags",
+			hasMeasurement: true,
+			metricNames:    []string{"InstanceActiveConnection"},
 			expected: []telegraf.Metric{
 				testutil.MustMetric(
 					"aliyuncms_acs_slb_dashboard",
@@ -434,8 +435,8 @@ func TestGather(t *testing.T) {
 			var acc testutil.Accumulator
 			plugin.Metrics[0].MetricNames = tt.metricNames
 			require.Empty(t, acc.GatherError(plugin.Gather))
-			require.Equal(t, acc.HasMeasurement("aliyuncms_acs_slb_dashboard"), tt.hasMeasurment)
-			if tt.hasMeasurment {
+			require.Equal(t, acc.HasMeasurement("aliyuncms_acs_slb_dashboard"), tt.hasMeasurement)
+			if tt.hasMeasurement {
 				acc.AssertContainsTaggedFields(t, "aliyuncms_acs_slb_dashboard", tt.expected[0].Fields(), tt.expected[0].Tags())
 			}
 		})
