@@ -6,6 +6,7 @@ import (
 	"errors"
 	"io"
 	"net"
+	"os"
 	"testing"
 	"time"
 
@@ -13,6 +14,7 @@ import (
 	telemetryBis "github.com/cisco-ie/nx-telemetry-proto/telemetry_bis"
 	"github.com/stretchr/testify/require"
 	"google.golang.org/grpc"
+	"google.golang.org/grpc/connectivity"
 	"google.golang.org/grpc/credentials/insecure"
 	"google.golang.org/protobuf/proto"
 
@@ -22,7 +24,13 @@ import (
 )
 
 func TestHandleTelemetryTwoSimple(t *testing.T) {
-	c := &CiscoTelemetryMDT{Log: testutil.Logger{}, Transport: "dummy", Aliases: map[string]string{"alias": "type:model/some/path"}}
+	c := &CiscoTelemetryMDT{
+		Log:       testutil.Logger{},
+		Transport: "dummy",
+		Aliases: map[string]string{
+			"alias": "type:model/some/path",
+		},
+	}
 	acc := &testutil.Accumulator{}
 	err := c.Start(acc)
 	// error is expected since we are passing in dummy transport
@@ -90,11 +98,22 @@ func TestHandleTelemetryTwoSimple(t *testing.T) {
 	c.handleTelemetry(data)
 	require.Empty(t, acc.Errors)
 
-	tags := map[string]string{"path": "type:model/some/path", "name": "str", "uint64": "1234", "source": "hostname", "subscription": "subscription"}
+	tags := map[string]string{
+		"path":         "type:model/some/path",
+		"name":         "str",
+		"uint64":       "1234",
+		"source":       "hostname",
+		"subscription": "subscription",
+	}
 	fields := map[string]interface{}{"bool": true}
 	acc.AssertContainsTaggedFields(t, "alias", fields, tags)
 
-	tags = map[string]string{"path": "type:model/some/path", "name": "str2", "source": "hostname", "subscription": "subscription"}
+	tags = map[string]string{
+		"path":         "type:model/some/path",
+		"name":         "str2",
+		"source":       "hostname",
+		"subscription": "subscription",
+	}
 	fields = map[string]interface{}{"bool": false}
 	acc.AssertContainsTaggedFields(t, "alias", fields, tags)
 }
@@ -268,7 +287,13 @@ func TestIncludeDeleteField(t *testing.T) {
 }
 
 func TestHandleTelemetrySingleNested(t *testing.T) {
-	c := &CiscoTelemetryMDT{Log: testutil.Logger{}, Transport: "dummy", Aliases: map[string]string{"nested": "type:model/nested/path"}}
+	c := &CiscoTelemetryMDT{
+		Log:       testutil.Logger{},
+		Transport: "dummy",
+		Aliases: map[string]string{
+			"nested": "type:model/nested/path",
+		},
+	}
 	acc := &testutil.Accumulator{}
 	err := c.Start(acc)
 	// error is expected since we are passing in dummy transport
@@ -330,13 +355,22 @@ func TestHandleTelemetrySingleNested(t *testing.T) {
 	c.handleTelemetry(data)
 	require.Empty(t, acc.Errors)
 
-	tags := map[string]string{"path": "type:model/nested/path", "level": "3", "source": "hostname", "subscription": "subscription"}
+	tags := map[string]string{
+		"path":         "type:model/nested/path",
+		"level":        "3",
+		"source":       "hostname",
+		"subscription": "subscription",
+	}
 	fields := map[string]interface{}{"nested/value/foo": "bar"}
 	acc.AssertContainsTaggedFields(t, "nested", fields, tags)
 }
 
 func TestHandleEmbeddedTags(t *testing.T) {
-	c := &CiscoTelemetryMDT{Transport: "dummy", Aliases: map[string]string{"extra": "type:model/extra"}, EmbeddedTags: []string{"type:model/extra/list/name"}}
+	c := &CiscoTelemetryMDT{
+		Transport:    "dummy",
+		Aliases:      map[string]string{"extra": "type:model/extra"},
+		EmbeddedTags: []string{"type:model/extra/list/name"},
+	}
 	acc := &testutil.Accumulator{}
 	err := c.Start(acc)
 	// error is expected since we are passing in dummy transport
@@ -400,16 +434,31 @@ func TestHandleEmbeddedTags(t *testing.T) {
 	c.handleTelemetry(data)
 	require.Empty(t, acc.Errors)
 
-	tags1 := map[string]string{"path": "type:model/extra", "foo": "bar", "source": "hostname", "subscription": "subscription", "list/name": "entry1"}
+	tags1 := map[string]string{
+		"path":         "type:model/extra",
+		"foo":          "bar",
+		"source":       "hostname",
+		"subscription": "subscription",
+		"list/name":    "entry1",
+	}
 	fields1 := map[string]interface{}{"list/test": "foo"}
-	tags2 := map[string]string{"path": "type:model/extra", "foo": "bar", "source": "hostname", "subscription": "subscription", "list/name": "entry2"}
+	tags2 := map[string]string{
+		"path":         "type:model/extra",
+		"foo":          "bar",
+		"source":       "hostname",
+		"subscription": "subscription",
+		"list/name":    "entry2",
+	}
 	fields2 := map[string]interface{}{"list/test": "bar"}
 	acc.AssertContainsTaggedFields(t, "extra", fields1, tags1)
 	acc.AssertContainsTaggedFields(t, "extra", fields2, tags2)
 }
 
 func TestHandleNXAPI(t *testing.T) {
-	c := &CiscoTelemetryMDT{Transport: "dummy", Aliases: map[string]string{"nxapi": "show nxapi"}}
+	c := &CiscoTelemetryMDT{
+		Transport: "dummy",
+		Aliases:   map[string]string{"nxapi": "show nxapi"},
+	}
 	acc := &testutil.Accumulator{}
 	err := c.Start(acc)
 	// error is expected since we are passing in dummy transport
@@ -489,16 +538,34 @@ func TestHandleNXAPI(t *testing.T) {
 	c.handleTelemetry(data)
 	require.Empty(t, acc.Errors)
 
-	tags1 := map[string]string{"path": "show nxapi", "foo": "bar", "TABLE_nxapi": "i1", "row_number": "0", "source": "hostname", "subscription": "subscription"}
+	tags1 := map[string]string{
+		"path":         "show nxapi",
+		"foo":          "bar",
+		"TABLE_nxapi":  "i1",
+		"row_number":   "0",
+		"source":       "hostname",
+		"subscription": "subscription",
+	}
 	fields1 := map[string]interface{}{"value": "foo"}
-	tags2 := map[string]string{"path": "show nxapi", "foo": "bar", "TABLE_nxapi": "i2", "row_number": "0", "source": "hostname", "subscription": "subscription"}
+	tags2 := map[string]string{
+		"path":         "show nxapi",
+		"foo":          "bar",
+		"TABLE_nxapi":  "i2",
+		"row_number":   "0",
+		"source":       "hostname",
+		"subscription": "subscription",
+	}
 	fields2 := map[string]interface{}{"value": "bar"}
 	acc.AssertContainsTaggedFields(t, "nxapi", fields1, tags1)
 	acc.AssertContainsTaggedFields(t, "nxapi", fields2, tags2)
 }
 
 func TestHandleNXAPIXformNXAPI(t *testing.T) {
-	c := &CiscoTelemetryMDT{Log: testutil.Logger{}, Transport: "dummy", Aliases: map[string]string{"nxapi": "show nxapi"}}
+	c := &CiscoTelemetryMDT{
+		Log:       testutil.Logger{},
+		Transport: "dummy",
+		Aliases:   map[string]string{"nxapi": "show nxapi"},
+	}
 	acc := &testutil.Accumulator{}
 	err := c.Start(acc)
 	// error is expected since we are passing in dummy transport
@@ -579,7 +646,10 @@ func TestHandleNXAPIXformNXAPI(t *testing.T) {
 }
 
 func TestHandleNXXformMulti(t *testing.T) {
-	c := &CiscoTelemetryMDT{Transport: "dummy", Aliases: map[string]string{"dme": "sys/lldp"}}
+	c := &CiscoTelemetryMDT{
+		Transport: "dummy",
+		Aliases:   map[string]string{"dme": "sys/lldp"},
+	}
 	acc := &testutil.Accumulator{}
 	err := c.Start(acc)
 	// error is expected since we are passing in dummy transport
@@ -659,12 +729,20 @@ func TestHandleNXXformMulti(t *testing.T) {
 	c.handleTelemetry(data)
 	require.Empty(t, acc.Errors)
 	//validate various transformation scenaarios newly added in the code.
-	fields := map[string]interface{}{"portIdV": "12", "portDesc": "100", "test": int64(281474976710655), "subscriptionId": "2814749767106551"}
+	fields := map[string]interface{}{
+		"portIdV":        "12",
+		"portDesc":       "100",
+		"test":           int64(281474976710655),
+		"subscriptionId": "2814749767106551",
+	}
 	acc.AssertContainsFields(t, "dme", fields)
 }
 
 func TestHandleNXDME(t *testing.T) {
-	c := &CiscoTelemetryMDT{Transport: "dummy", Aliases: map[string]string{"dme": "sys/dme"}}
+	c := &CiscoTelemetryMDT{
+		Transport: "dummy",
+		Aliases:   map[string]string{"dme": "sys/dme"},
+	}
 	acc := &testutil.Accumulator{}
 	err := c.Start(acc)
 	// error is expected since we are passing in dummy transport
@@ -732,13 +810,23 @@ func TestHandleNXDME(t *testing.T) {
 	c.handleTelemetry(data)
 	require.Empty(t, acc.Errors)
 
-	tags1 := map[string]string{"path": "sys/dme", "foo": "bar", "fooEntity": "some-rn", "source": "hostname", "subscription": "subscription"}
+	tags1 := map[string]string{
+		"path":         "sys/dme",
+		"foo":          "bar",
+		"fooEntity":    "some-rn",
+		"source":       "hostname",
+		"subscription": "subscription",
+	}
 	fields1 := map[string]interface{}{"value": "foo"}
 	acc.AssertContainsTaggedFields(t, "dme", fields1, tags1)
 }
 
 func TestTCPDialoutOverflow(t *testing.T) {
-	c := &CiscoTelemetryMDT{Log: testutil.Logger{}, Transport: "tcp", ServiceAddress: "127.0.0.1:0"}
+	c := &CiscoTelemetryMDT{
+		Log:            testutil.Logger{},
+		Transport:      "tcp",
+		ServiceAddress: "127.0.0.1:0",
+	}
 	acc := &testutil.Accumulator{}
 	err := c.Start(acc)
 	require.NoError(t, err)
@@ -764,6 +852,20 @@ func TestTCPDialoutOverflow(t *testing.T) {
 	require.Contains(t, acc.Errors, errors.New("dialout packet too long: 1000000000"))
 }
 
+func mockTelemetryMicroburstMessage() *telemetryBis.Telemetry {
+	data, err := os.ReadFile("./testdata/microburst")
+	if err != nil {
+		panic(err)
+	}
+
+	newMessage := &telemetryBis.Telemetry{}
+	err = proto.Unmarshal(data, newMessage)
+	if err != nil {
+		panic(err)
+	}
+	return newMessage
+}
+
 func mockTelemetryMessage() *telemetryBis.Telemetry {
 	return &telemetryBis.Telemetry{
 		MsgTimestamp: 1543236572000,
@@ -797,9 +899,57 @@ func mockTelemetryMessage() *telemetryBis.Telemetry {
 	}
 }
 
+func TestGRPCDialoutMicroburst(t *testing.T) {
+	c := &CiscoTelemetryMDT{
+		Log:            testutil.Logger{},
+		Transport:      "grpc",
+		ServiceAddress: "127.0.0.1:0",
+		Aliases: map[string]string{
+			"some":     "microburst",
+			"parallel": "type:model/parallel/path",
+			"other":    "type:model/other/path",
+		},
+	}
+	acc := &testutil.Accumulator{}
+	err := c.Start(acc)
+	require.NoError(t, err)
+
+	telemetry := mockTelemetryMicroburstMessage()
+	data, err := proto.Marshal(telemetry)
+	require.NoError(t, err)
+
+	c.handleTelemetry(data)
+	require.Empty(t, acc.Errors)
+	tags := map[string]string{
+		"microburst":   "microburst",
+		"path":         "microburst",
+		"source":       "n9k-eor-tm4",
+		"subscription": "1",
+	}
+	fields := map[string]interface{}{
+		"duration":      uint64(1200),
+		"endDepth":      int64(0),
+		"interfaceName": "Eth0/0/0",
+		"peak":          int64(500),
+		"queue":         "queue-255",
+		"queueType":     "unicast",
+		"threshold":     int64(0),
+		"ts":            "2023-08-03T20:12:59.655308Z",
+	}
+	acc.AssertContainsTaggedFields(t, "microburst", fields, tags)
+}
+
 func TestTCPDialoutMultiple(t *testing.T) {
-	c := &CiscoTelemetryMDT{Log: testutil.Logger{}, Transport: "tcp", ServiceAddress: "127.0.0.1:0", Aliases: map[string]string{
-		"some": "type:model/some/path", "parallel": "type:model/parallel/path", "other": "type:model/other/path"}}
+	c := &CiscoTelemetryMDT{
+		Log:            testutil.Logger{},
+		Transport:      "tcp",
+		ServiceAddress: "127.0.0.1:0",
+		Aliases: map[string]string{
+			"some":     "type:model/some/path",
+			"parallel": "type:model/parallel/path",
+			"other":    "type:model/other/path",
+		},
+	}
 	acc := &testutil.Accumulator{}
 	err := c.Start(acc)
 	require.NoError(t, err)
@@ -856,29 +1006,48 @@ func TestTCPDialoutMultiple(t *testing.T) {
 	require.NoError(t, conn.Close())
 
 	// We use the invalid dialout flags to let the server close the connection
-	require.Equal(t, acc.Errors, []error{errors.New("invalid dialout flags: 257"), errors.New("invalid dialout flags: 257")})
+	require.Equal(t, []error{errors.New("invalid dialout flags: 257"), errors.New("invalid dialout flags: 257")}, acc.Errors)
 
-	tags := map[string]string{"path": "type:model/some/path", "name": "str", "source": "hostname", "subscription": "subscription"}
+	tags := map[string]string{
+		"path":         "type:model/some/path",
+		"name":         "str",
+		"source":       "hostname",
+		"subscription": "subscription",
+	}
 	fields := map[string]interface{}{"value": int64(-1)}
 	acc.AssertContainsTaggedFields(t, "some", fields, tags)
 
-	tags = map[string]string{"path": "type:model/parallel/path", "name": "str", "source": "hostname", "subscription": "subscription"}
+	tags = map[string]string{
+		"path":         "type:model/parallel/path",
+		"name":         "str",
+		"source":       "hostname",
+		"subscription": "subscription",
+	}
 	fields = map[string]interface{}{"value": int64(-1)}
 	acc.AssertContainsTaggedFields(t, "parallel", fields, tags)
 
-	tags = map[string]string{"path": "type:model/other/path", "name": "str", "source": "hostname", "subscription": "subscription"}
+	tags = map[string]string{
+		"path":         "type:model/other/path",
+		"name":         "str",
+		"source":       "hostname",
+		"subscription": "subscription",
+	}
 	fields = map[string]interface{}{"value": int64(-1)}
 	acc.AssertContainsTaggedFields(t, "other", fields, tags)
 }
 
 func TestGRPCDialoutError(t *testing.T) {
-	c := &CiscoTelemetryMDT{Log: testutil.Logger{}, Transport: "grpc", ServiceAddress: "127.0.0.1:0"}
+	c := &CiscoTelemetryMDT{
+		Log:            testutil.Logger{},
+		Transport:      "grpc",
+		ServiceAddress: "127.0.0.1:0",
+	}
 	acc := &testutil.Accumulator{}
 	err := c.Start(acc)
 	require.NoError(t, err)
 
 	addr := c.Address()
-	conn, err := grpc.Dial(addr.String(), grpc.WithTransportCredentials(insecure.NewCredentials()))
+	conn, err := grpc.NewClient(addr.String(), grpc.WithTransportCredentials(insecure.NewCredentials()))
 	require.NoError(t, err)
 	client := dialout.NewGRPCMdtDialoutClient(conn)
 	stream, err := client.MdtDialout(context.Background())
@@ -892,20 +1061,29 @@ func TestGRPCDialoutError(t *testing.T) {
 	require.True(t, err == nil || errors.Is(err, io.EOF))
 	c.Stop()
 
-	require.Equal(t, acc.Errors, []error{errors.New("GRPC dialout error: foobar")})
+	require.Equal(t, []error{errors.New("GRPC dialout error: foobar")}, acc.Errors)
 }
 
 func TestGRPCDialoutMultiple(t *testing.T) {
-	c := &CiscoTelemetryMDT{Log: testutil.Logger{}, Transport: "grpc", ServiceAddress: "127.0.0.1:0", Aliases: map[string]string{
-		"some": "type:model/some/path", "parallel": "type:model/parallel/path", "other": "type:model/other/path"}}
+	c := &CiscoTelemetryMDT{
+		Log:            testutil.Logger{},
+		Transport:      "grpc",
+		ServiceAddress: "127.0.0.1:0",
+		Aliases: map[string]string{
+			"some":     "type:model/some/path",
+			"parallel": "type:model/parallel/path",
+			"other":    "type:model/other/path",
+		},
+	}
 	acc := &testutil.Accumulator{}
 	err := c.Start(acc)
 	require.NoError(t, err)
 	telemetry := mockTelemetryMessage()
 
 	addr := c.Address()
-	conn, err := grpc.Dial(addr.String(), grpc.WithTransportCredentials(insecure.NewCredentials()), grpc.WithBlock())
+	conn, err := grpc.NewClient(addr.String(), grpc.WithTransportCredentials(insecure.NewCredentials()))
 	require.NoError(t, err)
+	require.True(t, conn.WaitForStateChange(context.Background(), connectivity.Connecting))
 	client := dialout.NewGRPCMdtDialoutClient(conn)
 	stream, err := client.MdtDialout(context.TODO())
 	require.NoError(t, err)
@@ -915,8 +1093,9 @@ func TestGRPCDialoutMultiple(t *testing.T) {
 	args := &dialout.MdtDialoutArgs{Data: data, ReqId: 456}
 	require.NoError(t, stream.Send(args))
 
-	conn2, err := grpc.Dial(addr.String(), grpc.WithTransportCredentials(insecure.NewCredentials()), grpc.WithBlock())
+	conn2, err := grpc.NewClient(addr.String(), grpc.WithTransportCredentials(insecure.NewCredentials()))
 	require.NoError(t, err)
+	require.True(t, conn.WaitForStateChange(context.Background(), connectivity.Connecting))
 	client2 := dialout.NewGRPCMdtDialoutClient(conn2)
 	stream2, err := client2.MdtDialout(context.TODO())
 	require.NoError(t, err)
@@ -943,32 +1122,52 @@ func TestGRPCDialoutMultiple(t *testing.T) {
 	c.Stop()
 	require.NoError(t, conn.Close())
 
-	require.Equal(t, acc.Errors, []error{errors.New("GRPC dialout error: testclose"), errors.New("GRPC dialout error: testclose")})
+	require.Equal(t, []error{errors.New("GRPC dialout error: testclose"), errors.New("GRPC dialout error: testclose")}, acc.Errors)
 
-	tags := map[string]string{"path": "type:model/some/path", "name": "str", "source": "hostname", "subscription": "subscription"}
+	tags := map[string]string{
+		"path":         "type:model/some/path",
+		"name":         "str",
+		"source":       "hostname",
+		"subscription": "subscription",
+	}
 	fields := map[string]interface{}{"value": int64(-1)}
 	acc.AssertContainsTaggedFields(t, "some", fields, tags)
 
-	tags = map[string]string{"path": "type:model/parallel/path", "name": "str", "source": "hostname", "subscription": "subscription"}
+	tags = map[string]string{
+		"path":         "type:model/parallel/path",
+		"name":         "str",
+		"source":       "hostname",
+		"subscription": "subscription",
+	}
 	fields = map[string]interface{}{"value": int64(-1)}
 	acc.AssertContainsTaggedFields(t, "parallel", fields, tags)
 
-	tags = map[string]string{"path": "type:model/other/path", "name": "str", "source": "hostname", "subscription": "subscription"}
+	tags = map[string]string{
+		"path":         "type:model/other/path",
+		"name":         "str",
+		"source":       "hostname",
+		"subscription": "subscription",
+	}
 	fields = map[string]interface{}{"value": int64(-1)}
 	acc.AssertContainsTaggedFields(t, "other", fields, tags)
 }
 
 func TestGRPCDialoutKeepalive(t *testing.T) {
-	c := &CiscoTelemetryMDT{Log: testutil.Logger{}, Transport: "grpc", ServiceAddress: "127.0.0.1:0", EnforcementPolicy: GRPCEnforcementPolicy{
-		PermitKeepaliveWithoutCalls: true,
-		KeepaliveMinTime:            0,
-	}}
+	c := &CiscoTelemetryMDT{
+		Log:            testutil.Logger{},
+		Transport:      "grpc",
+		ServiceAddress: "127.0.0.1:0",
+		EnforcementPolicy: GRPCEnforcementPolicy{
+			PermitKeepaliveWithoutCalls: true,
+			KeepaliveMinTime:            0,
+		},
+	}
 	acc := &testutil.Accumulator{}
 	err := c.Start(acc)
 	require.NoError(t, err)
 
 	addr := c.Address()
-	conn, err := grpc.Dial(addr.String(), grpc.WithTransportCredentials(insecure.NewCredentials()))
+	conn, err := grpc.NewClient(addr.String(), grpc.WithTransportCredentials(insecure.NewCredentials()))
 	require.NoError(t, err)
 	client := dialout.NewGRPCMdtDialoutClient(conn)
 	stream, err := client.MdtDialout(context.Background())
@@ -983,3 +1182,61 @@ func TestGRPCDialoutKeepalive(t *testing.T) {
 	c.Stop()
 	require.NoError(t, conn.Close())
 }
+
+func TestSourceFieldRewrite(t *testing.T) {
+	c := &CiscoTelemetryMDT{
+		Log:       testutil.Logger{},
+		Transport: "dummy",
+		Aliases:   map[string]string{"alias": "type:model/some/path"},
+	}
+	c.SourceFieldName = "mdt_source"
+	acc := &testutil.Accumulator{}
+	err := c.Start(acc)
+	// error is expected since we are passing in dummy transport
+	require.Error(t, err)
+
+	telemetry := &telemetryBis.Telemetry{
+		MsgTimestamp: 1543236572000,
+		EncodingPath: "type:model/some/path",
+		NodeId:       &telemetryBis.Telemetry_NodeIdStr{NodeIdStr: "hostname"},
+		Subscription: &telemetryBis.Telemetry_SubscriptionIdStr{SubscriptionIdStr: "subscription"},
+		DataGpbkv: []*telemetryBis.TelemetryField{
+			{
+				Fields: []*telemetryBis.TelemetryField{
+					{
+						Name: "keys",
+						Fields: []*telemetryBis.TelemetryField{
+							{
+								Name:        "source",
+								ValueByType: &telemetryBis.TelemetryField_StringValue{StringValue: "str"},
+							},
+						},
+					},
+					{
+						Name: "content",
+						Fields: []*telemetryBis.TelemetryField{
+							{
+								Name:        "bool",
+								ValueByType: &telemetryBis.TelemetryField_BoolValue{BoolValue: false},
+							},
+						},
+					},
+				},
+			},
+		},
+	}
+	data, err := proto.Marshal(telemetry)
+	require.NoError(t, err)
+
+	c.handleTelemetry(data)
+	require.Empty(t, acc.Errors)
+
+	tags := map[string]string{
+		"path":         "type:model/some/path",
+		"mdt_source":   "str",
+		"source":       "hostname",
+		"subscription": "subscription",
+	}
+	fields := map[string]interface{}{"bool": false}
+	acc.AssertContainsTaggedFields(t, "alias", fields, tags)
+}
