@@ -54,7 +54,9 @@ type ClickHouse struct {
 	ClusterInclude []string        `toml:"cluster_include"`
 	ClusterExclude []string        `toml:"cluster_exclude"`
 	Timeout        config.Duration `toml:"timeout"`
-	HTTPClient     http.Client
+	Variant        string          `toml:"variant"`
+
+	HTTPClient http.Client
 	tls.ClientConfig
 }
 
@@ -62,6 +64,19 @@ func (*ClickHouse) SampleConfig() string {
 	return sampleConfig
 }
 
+func (ch *ClickHouse) Init() error {
+	switch ch.Variant {
+	case "":
+		ch.Variant = "self-hosted"
+	case "self-hosted", "managed":
+		// valid options
+	default:
+		return fmt.Errorf("unknown variant %q", ch.Variant)
+	}
+
+	return nil
+}
+
 // Start ClickHouse input service
 func (ch *ClickHouse) Start(telegraf.Accumulator) error {
 	timeout := defaultTimeout
@@ -130,7 +145,6 @@ func (ch *ClickHouse) Gather(acc telegraf.Accumulator) (err error) {
 	for i := range connects {
 		metricsFuncs := []func(acc telegraf.Accumulator, conn *connect) error{
 			ch.tables,
-			ch.zookeeper,
 			ch.replicationQueue,
 			ch.detachedParts,
 			ch.dictionaries,
@@ -140,6 +154,12 @@ func (ch *ClickHouse) Gather(acc telegraf.Accumulator) (err error) {
 			ch.textLog,
 		}
 
+		// Managed instances on Clickhouse Cloud does not give a user
+		// permissions to the zookeeper table
+		if ch.Variant != "managed" {
+			metricsFuncs = append(metricsFuncs, ch.zookeeper)
+		}
+
 		for _, metricFunc := range metricsFuncs {
 			if err := metricFunc(acc, &connects[i]); err != nil {
 				acc.AddError(err)
@@ -509,7 +529,10 @@ func (ch *ClickHouse) execQuery(address *url.URL, query string, i interface{}) e
 	q := address.Query()
 	q.Set("query", query+" FORMAT JSON")
 	address.RawQuery = q.Encode()
-	req, _ := http.NewRequest("GET", address.String(), nil)
+	req, err := http.NewRequest("GET", address.String(), nil)
+	if err != nil {
+		return err
+	}
 	if ch.Username != "" {
 		req.Header.Add("X-ClickHouse-User", ch.Username)
 	}
@@ -522,6 +545,7 @@ func (ch *ClickHouse) execQuery(address *url.URL, query string, i interface{}) e
 	}
 	defer func() { _ = resp.Body.Close() }()
 	if resp.StatusCode >= 300 {
+		//nolint:errcheck // reading body for error reporting
 		body, _ := io.ReadAll(io.LimitReader(resp.Body, 200))
 		return &clickhouseError{
 			StatusCode: resp.StatusCode,
