@@ -4,9 +4,9 @@
 
 counter=0
 
-while read LINE; do
+while read -r _; do
     echo "counter_bash count=${counter}"
     counter=$((counter+1))
 done
 
-trap "echo terminate 1>&2" EXIT
\ No newline at end of file
+trap "echo terminate 1>&2" EXIT
