@@ -140,8 +140,8 @@ func TestUsernamePassword(t *testing.T) {
 	plugin := &GNMI{
 		Log:       testutil.Logger{},
 		Addresses: []string{listener.Addr().String()},
-		Username:  "theusername",
-		Password:  "thepassword",
+		Username:  config.NewSecret([]byte("theusername")),
+		Password:  config.NewSecret([]byte("thepassword")),
 		Encoding:  "proto",
 		Redial:    config.Duration(1 * time.Second),
 	}
@@ -1210,7 +1210,7 @@ func TestCases(t *testing.T) {
 			require.Eventually(t,
 				func() bool {
 					return acc.NMetrics() >= uint64(len(expected))
-				}, 1*time.Second, 100*time.Millisecond)
+				}, 15*time.Second, 100*time.Millisecond)
 			plugin.Stop()
 			grpcServer.Stop()
 			wg.Wait()
