@@ -30,7 +30,10 @@ func (s statServer) serverSocket(l net.Listener) {
 			defer c.Close()
 
 			buf := make([]byte, 1024)
-			n, _ := c.Read(buf)
+			n, err := c.Read(buf)
+			if err != nil {
+				return
+			}
 
 			data := buf[:n]
 			if string(data) == "show stat\n" {
@@ -92,7 +95,7 @@ func TestHaproxyGeneratesMetricsWithAuthentication(t *testing.T) {
 }
 
 func TestHaproxyGeneratesMetricsWithoutAuthentication(t *testing.T) {
-	ts := httptest.NewServer(http.HandlerFunc(func(w http.ResponseWriter, r *http.Request) {
+	ts := httptest.NewServer(http.HandlerFunc(func(w http.ResponseWriter, _ *http.Request) {
 		_, err := fmt.Fprint(w, string(csvOutputSample))
 		require.NoError(t, err)
 	}))
@@ -213,7 +216,7 @@ func TestHaproxyDefaultGetFromLocalhost(t *testing.T) {
 }
 
 func TestHaproxyKeepFieldNames(t *testing.T) {
-	ts := httptest.NewServer(http.HandlerFunc(func(w http.ResponseWriter, r *http.Request) {
+	ts := httptest.NewServer(http.HandlerFunc(func(w http.ResponseWriter, _ *http.Request) {
 		_, err := fmt.Fprint(w, string(csvOutputSample))
 		require.NoError(t, err)
 	}))
