@@ -5,17 +5,19 @@ package intel_dlb
 
 import (
 	"encoding/json"
+	"errors"
 	"fmt"
 	"net"
 	"os"
 	"testing"
 	"time"
 
+	"github.com/stretchr/testify/mock"
+	"github.com/stretchr/testify/require"
+
 	"github.com/influxdata/telegraf"
 	"github.com/influxdata/telegraf/plugins/inputs/dpdk/mocks"
 	"github.com/influxdata/telegraf/testutil"
-	"github.com/stretchr/testify/mock"
-	"github.com/stretchr/testify/require"
 )
 
 func TestDLB_Init(t *testing.T) {
@@ -26,7 +28,8 @@ func TestDLB_Init(t *testing.T) {
 		}
 		require.Equal(t, "", dlb.SocketPath)
 
-		_ = dlb.Init()
+		//nolint:errcheck // we are just testing that socket path gets set to default, not that default is valid
+		dlb.Init()
 
 		require.Equal(t, defaultSocketPath, dlb.SocketPath)
 	})
@@ -131,7 +134,7 @@ func TestDLB_Init(t *testing.T) {
 			Log:        testutil.Logger{},
 		}
 		const emptyPath = ""
-		fileMock.On("gatherPaths", mock.Anything).Return([]string{emptyPath}, fmt.Errorf("can't find device folder")).Once()
+		fileMock.On("gatherPaths", mock.Anything).Return([]string{emptyPath}, errors.New("can't find device folder")).Once()
 		err := dlb.Init()
 		require.Error(t, err)
 		require.Contains(t, err.Error(), "can't find device folder")
@@ -146,7 +149,7 @@ func TestDLB_writeReadSocketMessage(t *testing.T) {
 			connection: mockConn,
 			Log:        testutil.Logger{},
 		}
-		mockConn.On("Write", []byte{}).Return(0, fmt.Errorf("write error")).Once().
+		mockConn.On("Write", []byte{}).Return(0, errors.New("write error")).Once().
 			On("Close").Return(nil).Once()
 
 		_, _, err := dlb.writeReadSocketMessage("")
@@ -162,7 +165,7 @@ func TestDLB_writeReadSocketMessage(t *testing.T) {
 			connection: mockConn,
 			Log:        testutil.Logger{},
 		}
-		simulateResponse(mockConn, "", fmt.Errorf("read error"))
+		simulateResponse(mockConn, "", errors.New("read error"))
 
 		_, _, err := dlb.writeReadSocketMessage("")
 
@@ -310,7 +313,7 @@ func TestDLB_gatherCommandsWithDeviceIndex(t *testing.T) {
 			maxInitMessageLength: 1024,
 			EventdevCommands:     []string{"/eventdev/dev_xstats"},
 		}
-		response := fmt.Sprintf(`{"%s": [0, 1]}`, eventdevListCommand)
+		response := fmt.Sprintf(`{%q: [0, 1]}`, eventdevListCommand)
 		simulateResponse(mockConn, response, nil)
 
 		expectedCommands := []string{"/eventdev/dev_xstats,0", "/eventdev/dev_xstats,1"}
@@ -330,7 +333,7 @@ func TestDLB_gatherCommandsWithDeviceIndex(t *testing.T) {
 			maxInitMessageLength: 1024,
 			EventdevCommands:     []string{"/eventdev/queue_links"},
 		}
-		responseDevList := fmt.Sprintf(`{"%s": [0]}`, eventdevListCommand)
+		responseDevList := fmt.Sprintf(`{%q: [0]}`, eventdevListCommand)
 		simulateResponse(mockConn, responseDevList, nil)
 		responseQueueLinks := `{"0": [0]}`
 		simulateResponse(mockConn, responseQueueLinks, nil)
@@ -352,7 +355,7 @@ func TestDLB_gatherCommandsWithDeviceIndex(t *testing.T) {
 			maxInitMessageLength: 1024,
 			EventdevCommands:     []string{"/eventdev/dev_xstats", "/eventdev/wrong"},
 		}
-		response := fmt.Sprintf(`{"%s": [0, 1]}`, eventdevListCommand)
+		response := fmt.Sprintf(`{%q: [0, 1]}`, eventdevListCommand)
 		mockConn.On("Write", mock.Anything).Return(0, nil).Once()
 		mockConn.On("Read", mock.Anything).Run(func(arg mock.Arguments) {
 			elem := arg.Get(0).([]byte)
@@ -419,7 +422,7 @@ func TestDLB_gatherSecondDeviceIndex(t *testing.T) {
 		mockConn.On("Close").Return(nil).Once()
 
 		_, err := dlb.gatherSecondDeviceIndex(0, dlb.EventdevCommands[0])
-		require.Equal(t, nil, dlb.connection)
+		require.Nil(t, dlb.connection)
 		require.Error(t, err)
 		require.Contains(t, err.Error(), "failed to parse json")
 		dlb.SocketPath = pathToSocket
@@ -443,7 +446,7 @@ func TestDLB_gatherSecondDeviceIndex(t *testing.T) {
 			EventdevCommands:     []string{"/eventdev/port_xstats"},
 		}
 		eventdevListWithSecondIndex := []string{"/eventdev/port_list", "/eventdev/queue_list"}
-		response := fmt.Sprintf(`{"%s": [0, 1]}`, eventdevListWithSecondIndex[0])
+		response := fmt.Sprintf(`{%q: [0, 1]}`, eventdevListWithSecondIndex[0])
 		simulateResponse(mockConn, response, nil)
 
 		expectedCommands := []string{"/eventdev/port_xstats,0,0", "/eventdev/port_xstats,0,1"}
@@ -468,7 +471,7 @@ func TestDLB_processCommandResult(t *testing.T) {
 			maxInitMessageLength: 1024,
 			EventdevCommands:     []string{"/eventdev/dev_xstats"},
 		}
-		response := fmt.Sprintf(`{"%s": [0]}`, eventdevListCommand)
+		response := fmt.Sprintf(`{%q: [0]}`, eventdevListCommand)
 		simulateResponse(mockConn, response, nil)
 
 		response = `{"/eventdev/dev_xstats": {"dev_rx_ok": 0}}`
@@ -506,7 +509,7 @@ func TestDLB_processCommandResult(t *testing.T) {
 			rasReader:            fileMock,
 			maxInitMessageLength: 1024,
 		}
-		responseGather := fmt.Sprintf(`{"%s": [0]}`, eventdevListCommand)
+		responseGather := fmt.Sprintf(`{%q: [0]}`, eventdevListCommand)
 		mockConn.On("Write", mock.Anything).Return(0, nil).Twice()
 		mockConn.On("Read", mock.Anything).Run(func(arg mock.Arguments) {
 			elem := arg.Get(0).([]byte)
@@ -537,7 +540,7 @@ func TestDLB_processCommandResult(t *testing.T) {
 			Log:              testutil.Logger{},
 			EventdevCommands: []string{"/eventdev/dev_xstats"},
 		}
-		response := fmt.Sprintf(`{"%s": [0]}`, eventdevListCommand)
+		response := fmt.Sprintf(`{%q: [0]}`, eventdevListCommand)
 		simulateResponse(mockConn, response, nil)
 
 		simulateResponse(mockConn, "/wrong/json", nil)
@@ -583,7 +586,7 @@ func TestDLB_processCommandResult(t *testing.T) {
 		mockConn.On("Read", mock.Anything).Run(func(arg mock.Arguments) {
 			elem := arg.Get(0).([]byte)
 			copy(elem, response)
-		}).Return(len(response), fmt.Errorf("read error")).Once()
+		}).Return(len(response), errors.New("read error")).Once()
 		mockConn.On("Close").Return(nil)
 
 		err := dlb.gatherMetricsFromSocket(mockAcc)
@@ -622,7 +625,7 @@ func TestDLB_processCommandResult(t *testing.T) {
 		}
 		mockConn.On("Close").Return(nil)
 
-		responseGather := fmt.Sprintf(`{"%s": [0]}`, eventdevListCommand)
+		responseGather := fmt.Sprintf(`{%q: [0]}`, eventdevListCommand)
 		mockConn.On("Write", mock.Anything).Return(0, nil).Once().
 			On("Read", mock.Anything).Run(func(arg mock.Arguments) {
 			elem := arg.Get(0).([]byte)
@@ -651,7 +654,7 @@ func Test_checkAndAddDLBDevice(t *testing.T) {
 			rasReader: fileMock,
 			Log:       testutil.Logger{},
 		}
-		fileMock.On("gatherPaths", mock.AnythingOfType("string")).Return(nil, fmt.Errorf("can't find device folder")).Once()
+		fileMock.On("gatherPaths", mock.AnythingOfType("string")).Return(nil, errors.New("can't find device folder")).Once()
 
 		err := dlb.checkAndAddDLBDevice()
 
@@ -669,7 +672,7 @@ func Test_checkAndAddDLBDevice(t *testing.T) {
 		}
 		const globPath = "/sys/devices/pci0000:00/0000:00:00.0/device"
 		fileMock.On("gatherPaths", mock.Anything).Return([]string{globPath}, nil).Once().
-			On("readFromFile", mock.Anything).Return([]byte("0x2710"), fmt.Errorf("read error while getting device folders")).Once()
+			On("readFromFile", mock.Anything).Return([]byte("0x2710"), errors.New("read error while getting device folders")).Once()
 
 		err := dlb.checkAndAddDLBDevice()
 
@@ -700,7 +703,7 @@ func Test_checkAndAddDLBDevice(t *testing.T) {
 		}
 		const globPath = "/sys/devices/pci0000:00/0000:00:00.0/device"
 		fileMock.On("gatherPaths", mock.Anything).Return([]string{globPath}, nil).Once().
-			On("readFromFile", mock.Anything).Return([]byte("0x2710"), fmt.Errorf("read error while getting device folders")).Once()
+			On("readFromFile", mock.Anything).Return([]byte("0x2710"), errors.New("read error while getting device folders")).Once()
 
 		err := dlb.checkAndAddDLBDevice()
 
@@ -777,7 +780,7 @@ func Test_readRasMetrics(t *testing.T) {
 		err            error
 		errMsg         string
 	}{
-		{"error when reading fails", []byte(aerCorrectableData), fmt.Errorf("read error"), "read error"},
+		{"error when reading fails", []byte(aerCorrectableData), errors.New("read error"), "read error"},
 		{"error when empty data is given", []byte(""), nil, "no value to parse"},
 		{"error when trying to split empty data", []byte("x1 x2"), nil, "failed to parse value"},
 	}
@@ -883,7 +886,7 @@ func Test_rasReader(t *testing.T) {
 		// Remove the temporary file after this test
 		defer os.Remove(fileobj.Name())
 
-		_, err = fileobj.Write([]byte(testFileContent))
+		_, err = fileobj.WriteString(testFileContent)
 		require.NoError(t, err)
 		err = fileobj.Close()
 		require.NoError(t, err)
@@ -939,17 +942,18 @@ func simulateSocketResponseForGather(socket net.Listener, t *testing.T) {
 		Pid          int    `json:"pid"`
 		MaxOutputLen uint32 `json:"max_output_len"`
 	}
-	initMsg, _ := json.Marshal(initMessage{
+	initMsg, err := json.Marshal(initMessage{
 		Version:      "",
 		Pid:          1,
 		MaxOutputLen: 1024,
 	})
+	require.NoError(t, err)
 	_, err = conn.Write(initMsg)
 	require.NoError(t, err)
 
 	require.NoError(t, err)
 	eventdevListWithSecondIndex := []string{"/eventdev/port_list", "/eventdev/queue_list"}
-	_, err = conn.Write([]byte(fmt.Sprintf(`{"%s": [0, 1]}`, eventdevListWithSecondIndex[0])))
+	_, err = fmt.Fprintf(conn, `{%q: [0, 1]}`, eventdevListWithSecondIndex[0])
 	require.NoError(t, err)
 }
 
