@@ -44,12 +44,12 @@ func TestParseCoresMeasurement(t *testing.T) {
 		require.NoError(t, err)
 		require.Equal(t, expectedCores, result.cores)
 		require.Equal(t, expectedTimestamp, result.time)
-		require.Equal(t, result.values[0], metricsValues["IPC"])
-		require.Equal(t, result.values[1], metricsValues["LLC_Misses"])
-		require.Equal(t, result.values[2], metricsValues["LLC"])
-		require.Equal(t, result.values[3], metricsValues["MBL"])
-		require.Equal(t, result.values[4], metricsValues["MBR"])
-		require.Equal(t, result.values[5], metricsValues["MBT"])
+		require.InDelta(t, result.values[0], metricsValues["IPC"], testutil.DefaultDelta)
+		require.InDelta(t, result.values[1], metricsValues["LLC_Misses"], testutil.DefaultDelta)
+		require.InDelta(t, result.values[2], metricsValues["LLC"], testutil.DefaultDelta)
+		require.InDelta(t, result.values[3], metricsValues["MBL"], testutil.DefaultDelta)
+		require.InDelta(t, result.values[4], metricsValues["MBR"], testutil.DefaultDelta)
+		require.InDelta(t, result.values[5], metricsValues["MBT"], testutil.DefaultDelta)
 	})
 	t.Run("not valid measurement string", func(t *testing.T) {
 		measurement := "not, valid, measurement"
@@ -131,12 +131,12 @@ func TestParseProcessesMeasurement(t *testing.T) {
 		require.Equal(t, processName, result.process)
 		require.Equal(t, expectedCores, result.cores)
 		require.Equal(t, expectedTimestamp, result.time)
-		require.Equal(t, result.values[0], metricsValues["IPC"])
-		require.Equal(t, result.values[1], metricsValues["LLC_Misses"])
-		require.Equal(t, result.values[2], metricsValues["LLC"])
-		require.Equal(t, result.values[3], metricsValues["MBL"])
-		require.Equal(t, result.values[4], metricsValues["MBR"])
-		require.Equal(t, result.values[5], metricsValues["MBT"])
+		require.InDelta(t, result.values[0], metricsValues["IPC"], testutil.DefaultDelta)
+		require.InDelta(t, result.values[1], metricsValues["LLC_Misses"], testutil.DefaultDelta)
+		require.InDelta(t, result.values[2], metricsValues["LLC"], testutil.DefaultDelta)
+		require.InDelta(t, result.values[3], metricsValues["MBL"], testutil.DefaultDelta)
+		require.InDelta(t, result.values[4], metricsValues["MBR"], testutil.DefaultDelta)
+		require.InDelta(t, result.values[5], metricsValues["MBT"], testutil.DefaultDelta)
 	})
 
 	invalidTimestamp := "2020-20-20-31"
