@@ -5,6 +5,7 @@ import (
 	"bufio"
 	"bytes"
 	_ "embed"
+	"errors"
 	"fmt"
 	"os"
 	"os/exec"
@@ -58,7 +59,7 @@ func (m *Ipmi) Init() error {
 	if m.Path == "" {
 		path, err := exec.LookPath(cmd)
 		if err != nil {
-			return fmt.Errorf("looking up %q failed: %v", cmd, err)
+			return fmt.Errorf("looking up %q failed: %w", cmd, err)
 		}
 		m.Path = path
 	}
@@ -77,7 +78,7 @@ func (m *Ipmi) Init() error {
 // Gather is the main execution function for the plugin
 func (m *Ipmi) Gather(acc telegraf.Accumulator) error {
 	if len(m.Path) == 0 {
-		return fmt.Errorf("ipmitool not found: verify that ipmitool is installed and that ipmitool is in your PATH")
+		return errors.New("ipmitool not found: verify that ipmitool is installed and that ipmitool is in your PATH")
 	}
 
 	if len(m.Servers) > 0 {
@@ -118,8 +119,7 @@ func (m *Ipmi) parse(acc telegraf.Accumulator, server string) error {
 		if os.IsNotExist(err) {
 			dumpOpts := opts
 			// init cache file
-			dumpOpts = append(dumpOpts, "dump")
-			dumpOpts = append(dumpOpts, cacheFile)
+			dumpOpts = append(dumpOpts, "dump", cacheFile)
 			name := m.Path
 			if m.UseSudo {
 				// -n - avoid prompting the user for input of any kind
@@ -129,11 +129,10 @@ func (m *Ipmi) parse(acc telegraf.Accumulator, server string) error {
 			cmd := execCommand(name, dumpOpts...)
 			out, err := internal.CombinedOutputTimeout(cmd, time.Duration(m.Timeout))
 			if err != nil {
-				return fmt.Errorf("failed to run command %s: %s - %s", strings.Join(sanitizeIPMICmd(cmd.Args), " "), err, string(out))
+				return fmt.Errorf("failed to run command %q: %w - %s", strings.Join(sanitizeIPMICmd(cmd.Args), " "), err, string(out))
 			}
 		}
-		opts = append(opts, "-S")
-		opts = append(opts, cacheFile)
+		opts = append(opts, "-S", cacheFile)
 	}
 	if m.MetricVersion == 2 {
 		opts = append(opts, "elist")
@@ -148,7 +147,7 @@ func (m *Ipmi) parse(acc telegraf.Accumulator, server string) error {
 	out, err := internal.CombinedOutputTimeout(cmd, time.Duration(m.Timeout))
 	timestamp := time.Now()
 	if err != nil {
-		return fmt.Errorf("failed to run command %s: %s - %s", strings.Join(sanitizeIPMICmd(cmd.Args), " "), err, string(out))
+		return fmt.Errorf("failed to run command %q: %w - %s", strings.Join(sanitizeIPMICmd(cmd.Args), " "), err, string(out))
 	}
 	if m.MetricVersion == 2 {
 		return m.parseV2(acc, hostname, out, timestamp)
