@@ -121,7 +121,7 @@ func destinationTags(d *ipvs.Destination) map[string]string {
 	}
 }
 
-// helper: convert protocol uint16 to human readable string (if possible)
+// helper: convert protocol uint16 to human-readable string (if possible)
 func protocolToString(p uint16) string {
 	switch p {
 	case syscall.IPPROTO_TCP:
@@ -131,11 +131,11 @@ func protocolToString(p uint16) string {
 	case syscall.IPPROTO_SCTP:
 		return "sctp"
 	default:
-		return fmt.Sprintf("%d", p)
+		return strconv.FormatUint(uint64(p), 10)
 	}
 }
 
-// helper: convert addressFamily to a human readable string
+// helper: convert addressFamily to a human-readable string
 func addressFamilyToString(af uint16) string {
 	switch af {
 	case syscall.AF_INET:
@@ -143,7 +143,7 @@ func addressFamilyToString(af uint16) string {
 	case syscall.AF_INET6:
 		return "inet6"
 	default:
-		return fmt.Sprintf("%d", af)
+		return strconv.FormatUint(uint64(af), 10)
 	}
 }
 
