@@ -2,11 +2,11 @@ package kubernetes
 
 import (
 	"fmt"
-	"github.com/influxdata/telegraf/filter"
 	"net/http"
 	"net/http/httptest"
 	"testing"
 
+	"github.com/influxdata/telegraf/filter"
 	"github.com/influxdata/telegraf/testutil"
 	"github.com/stretchr/testify/require"
 )
@@ -26,15 +26,17 @@ func TestKubernetesStats(t *testing.T) {
 	}))
 	defer ts.Close()
 
-	labelFilter, _ := filter.NewIncludeExcludeFilter([]string{"app", "superkey"}, nil)
+	labelFilter, err := filter.NewIncludeExcludeFilter([]string{"app", "superkey"}, nil)
+	require.NoError(t, err)
 
 	k := &Kubernetes{
-		URL:         ts.URL,
-		labelFilter: labelFilter,
+		URL:            ts.URL,
+		labelFilter:    labelFilter,
+		NodeMetricName: "kubernetes_node",
 	}
 
 	var acc testutil.Accumulator
-	err := acc.GatherError(k.Gather)
+	err = acc.GatherError(k.Gather)
 	require.NoError(t, err)
 
 	fields := map[string]interface{}{
@@ -141,6 +143,8 @@ func TestKubernetesStats(t *testing.T) {
 		"volume_name": "volume1",
 		"namespace":   "foons",
 		"pod_name":    "foopod",
+		"app":         "foo",
+		"superkey":    "foobar",
 	}
 	acc.AssertContainsTaggedFields(t, "kubernetes_pod_volume", fields, tags)
 
@@ -154,6 +158,8 @@ func TestKubernetesStats(t *testing.T) {
 		"node_name": "node1",
 		"namespace": "foons",
 		"pod_name":  "foopod",
+		"app":       "foo",
+		"superkey":  "foobar",
 	}
 	acc.AssertContainsTaggedFields(t, "kubernetes_pod_network", fields, tags)
 }
