@@ -7,10 +7,11 @@ import (
 	"time"
 
 	mb "github.com/grid-x/modbus"
-	"github.com/influxdata/telegraf"
-	"github.com/influxdata/telegraf/testutil"
 	"github.com/stretchr/testify/require"
 	"github.com/tbrandon/mbserver"
+
+	"github.com/influxdata/telegraf"
+	"github.com/influxdata/telegraf/testutil"
 )
 
 func TestRequest(t *testing.T) {
@@ -457,6 +458,7 @@ func TestRequestTypesHoldingABCD(t *testing.T) {
 	tests := []struct {
 		name        string
 		address     uint16
+		length      uint16
 		byteOrder   string
 		dataTypeIn  string
 		dataTypeOut string
@@ -989,6 +991,14 @@ func TestRequestTypesHoldingABCD(t *testing.T) {
 			write:      []byte{0xb8, 0x14},
 			read:       float64(-0.509765625),
 		},
+		{
+			name:       "register110_string",
+			address:    110,
+			dataTypeIn: "STRING",
+			length:     7,
+			write:      []byte{0x4d, 0x6f, 0x64, 0x62, 0x75, 0x73, 0x20, 0x53, 0x74, 0x72, 0x69, 0x6e, 0x67, 0x00},
+			read:       "Modbus String",
+		},
 	}
 
 	serv := mbserver.NewServer()
@@ -1024,6 +1034,7 @@ func TestRequestTypesHoldingABCD(t *testing.T) {
 							OutputType: hrt.dataTypeOut,
 							Scale:      hrt.scale,
 							Address:    hrt.address,
+							Length:     hrt.length,
 						},
 					},
 				},
@@ -1058,6 +1069,7 @@ func TestRequestTypesHoldingDCBA(t *testing.T) {
 	tests := []struct {
 		name        string
 		address     uint16
+		length      uint16
 		byteOrder   string
 		dataTypeIn  string
 		dataTypeOut string
@@ -1590,6 +1602,14 @@ func TestRequestTypesHoldingDCBA(t *testing.T) {
 			write:      []byte{0xb8, 0x14},
 			read:       float64(-0.509765625),
 		},
+		{
+			name:       "register110_string",
+			address:    110,
+			dataTypeIn: "STRING",
+			length:     7,
+			write:      []byte{0x6f, 0x4d, 0x62, 0x64, 0x73, 0x75, 0x53, 0x20, 0x72, 0x74, 0x6e, 0x69, 0x00, 0x67},
+			read:       "Modbus String",
+		},
 	}
 
 	serv := mbserver.NewServer()
@@ -1605,8 +1625,13 @@ func TestRequestTypesHoldingDCBA(t *testing.T) {
 		t.Run(hrt.name, func(t *testing.T) {
 			quantity := uint16(len(hrt.write) / 2)
 			invert := make([]byte, 0, len(hrt.write))
-			for i := len(hrt.write) - 1; i >= 0; i-- {
-				invert = append(invert, hrt.write[i])
+			if hrt.dataTypeIn != "STRING" {
+				for i := len(hrt.write) - 1; i >= 0; i-- {
+					invert = append(invert, hrt.write[i])
+				}
+			} else {
+				// Put in raw data for strings
+				invert = append(invert, hrt.write...)
 			}
 			_, err := client.WriteMultipleRegisters(hrt.address, quantity, invert)
 			require.NoError(t, err)
@@ -1629,6 +1654,7 @@ func TestRequestTypesHoldingDCBA(t *testing.T) {
 							OutputType: hrt.dataTypeOut,
 							Scale:      hrt.scale,
 							Address:    hrt.address,
+							Length:     hrt.length,
 						},
 					},
 				},
@@ -2222,7 +2248,6 @@ func TestRequestEmptyFields(t *testing.T) {
 }
 
 func TestRequestMultipleSlavesOneFail(t *testing.T) {
-	telegraf.Debug = true
 	modbus := Modbus{
 		Name:              "Test",
 		Controller:        "tcp://localhost:1502",
@@ -2275,7 +2300,7 @@ func TestRequestMultipleSlavesOneFail(t *testing.T) {
 	defer serv.Close()
 
 	serv.RegisterFunctionHandler(3,
-		func(s *mbserver.Server, frame mbserver.Framer) ([]byte, *mbserver.Exception) {
+		func(_ *mbserver.Server, frame mbserver.Framer) ([]byte, *mbserver.Exception) {
 			tcpframe, ok := frame.(*mbserver.TCPFrame)
 			if !ok {
 				return nil, &mbserver.IllegalFunction
@@ -2318,7 +2343,7 @@ func TestRequestMultipleSlavesOneFail(t *testing.T) {
 	actual := acc.GetTelegrafMetrics()
 	testutil.RequireMetricsEqual(t, expected, actual, testutil.IgnoreTime(), testutil.SortMetrics())
 	require.Len(t, acc.Errors, 1)
-	require.EqualError(t, acc.FirstError(), "slave 2: modbus: exception '11' (gateway target device failed to respond), function '131'")
+	require.ErrorContains(t, acc.FirstError(), "slave 2: modbus: exception '11' (gateway target device failed to respond)")
 }
 
 func TestRequestOptimizationShrink(t *testing.T) {
@@ -3277,3 +3302,28 @@ func TestRequestOverlap(t *testing.T) {
 	require.Len(t, plugin.requests, 1)
 	require.Len(t, plugin.requests[1].holding, 1)
 }
+
+func TestRequestAddressOverflow(t *testing.T) {
+	logger := &testutil.CaptureLogger{}
+	plugin := Modbus{
+		Name:              "Test",
+		Controller:        "tcp://localhost:1502",
+		ConfigurationType: "request",
+		Log:               logger,
+		Workarounds:       ModbusWorkarounds{ReadCoilsStartingAtZero: true},
+	}
+	plugin.Requests = []requestDefinition{
+		{
+			SlaveID:      1,
+			RegisterType: "holding",
+			Fields: []requestFieldDefinition{
+				{
+					Name:      "field",
+					InputType: "UINT64",
+					Address:   uint16(65534),
+				},
+			},
+		},
+	}
+	require.ErrorIs(t, plugin.Init(), errAddressOverflow)
+}
