@@ -7,8 +7,8 @@ import (
 	"net"
 	"time"
 
-	"github.com/google/gopacket"
-	"github.com/google/gopacket/layers"
+	"github.com/gopacket/gopacket"
+	"github.com/gopacket/gopacket/layers"
 	"github.com/netsampler/goflow2/v2/decoders/sflow"
 
 	"github.com/influxdata/telegraf"
