@@ -15,7 +15,6 @@ import (
 	"github.com/influxdata/telegraf/plugins/inputs"
 )
 
-// DO NOT REMOVE THE NEXT TWO LINES! This is required to embed the sampleConfig data.
 //go:embed sample.conf
 var sampleConfig string
 
@@ -43,8 +42,8 @@ const (
 	httpLocationZonesPath = "http/location_zones"
 	httpUpstreamsPath     = "http/upstreams"
 	httpCachesPath        = "http/caches"
-
-	resolverZonesPath = "resolvers"
+	httpLimitReqsPath     = "http/limit_reqs"
+	resolverZonesPath     = "resolvers"
 
 	streamServerZonesPath = "stream/server_zones"
 	streamUpstreamsPath   = "stream/upstreams"
@@ -75,7 +74,7 @@ func (n *NginxPlusAPI) Gather(acc telegraf.Accumulator) error {
 	for _, u := range n.Urls {
 		addr, err := url.Parse(u)
 		if err != nil {
-			acc.AddError(fmt.Errorf("Unable to parse address '%s': %s", u, err))
+			acc.AddError(fmt.Errorf("Unable to parse address %q: %w", u, err))
 			continue
 		}
 
