@@ -1,27 +1,19 @@
 package nvidia_smi
 
 import (
+	"errors"
 	"os"
 	"path/filepath"
 	"testing"
 	"time"
 
 	"github.com/influxdata/telegraf"
+	"github.com/influxdata/telegraf/internal"
+	"github.com/influxdata/telegraf/models"
 	"github.com/influxdata/telegraf/testutil"
 	"github.com/stretchr/testify/require"
 )
 
-func TestErrorBehaviorError(t *testing.T) {
-	// make sure we can't find nvidia-smi in $PATH somewhere
-	os.Unsetenv("PATH")
-	plugin := &NvidiaSMI{
-		BinPath:              "/random/non-existent/path",
-		Log:                  &testutil.Logger{},
-		StartupErrorBehavior: "error",
-	}
-	require.Error(t, plugin.Init())
-}
-
 func TestErrorBehaviorDefault(t *testing.T) {
 	// make sure we can't find nvidia-smi in $PATH somewhere
 	os.Unsetenv("PATH")
@@ -29,31 +21,72 @@ func TestErrorBehaviorDefault(t *testing.T) {
 		BinPath: "/random/non-existent/path",
 		Log:     &testutil.Logger{},
 	}
-	require.Error(t, plugin.Init())
+	model := models.NewRunningInput(plugin, &models.InputConfig{
+		Name: "nvidia_smi",
+	})
+	require.NoError(t, model.Init())
+
+	var acc testutil.Accumulator
+	var ferr *internal.FatalError
+	require.False(t, errors.As(model.Start(&acc), &ferr))
+	require.ErrorIs(t, model.Gather(&acc), internal.ErrNotConnected)
+}
+
+func TestErrorBehaviorError(t *testing.T) {
+	// make sure we can't find nvidia-smi in $PATH somewhere
+	os.Unsetenv("PATH")
+	plugin := &NvidiaSMI{
+		BinPath: "/random/non-existent/path",
+		Log:     &testutil.Logger{},
+	}
+	model := models.NewRunningInput(plugin, &models.InputConfig{
+		Name:                 "nvidia_smi",
+		StartupErrorBehavior: "error",
+	})
+	require.NoError(t, model.Init())
+
+	var acc testutil.Accumulator
+	var ferr *internal.FatalError
+	require.False(t, errors.As(model.Start(&acc), &ferr))
+	require.ErrorIs(t, model.Gather(&acc), internal.ErrNotConnected)
+}
+
+func TestErrorBehaviorRetry(t *testing.T) {
+	// make sure we can't find nvidia-smi in $PATH somewhere
+	os.Unsetenv("PATH")
+	plugin := &NvidiaSMI{
+		BinPath: "/random/non-existent/path",
+		Log:     &testutil.Logger{},
+	}
+	model := models.NewRunningInput(plugin, &models.InputConfig{
+		Name:                 "nvidia_smi",
+		StartupErrorBehavior: "retry",
+	})
+	require.NoError(t, model.Init())
+
+	var acc testutil.Accumulator
+	var ferr *internal.FatalError
+	require.False(t, errors.As(model.Start(&acc), &ferr))
+	require.ErrorIs(t, model.Gather(&acc), internal.ErrNotConnected)
 }
 
 func TestErrorBehaviorIgnore(t *testing.T) {
 	// make sure we can't find nvidia-smi in $PATH somewhere
 	os.Unsetenv("PATH")
 	plugin := &NvidiaSMI{
-		BinPath:              "/random/non-existent/path",
-		Log:                  &testutil.Logger{},
+		BinPath: "/random/non-existent/path",
+		Log:     &testutil.Logger{},
+	}
+	model := models.NewRunningInput(plugin, &models.InputConfig{
+		Name:                 "nvidia_smi",
 		StartupErrorBehavior: "ignore",
-	}
-	require.NoError(t, plugin.Init())
-	acc := testutil.Accumulator{}
-	require.NoError(t, plugin.Gather(&acc))
-}
+	})
+	require.NoError(t, model.Init())
 
-func TestErrorBehaviorInvalidOption(t *testing.T) {
-	// make sure we can't find nvidia-smi in $PATH somewhere
-	os.Unsetenv("PATH")
-	plugin := &NvidiaSMI{
-		BinPath:              "/random/non-existent/path",
-		Log:                  &testutil.Logger{},
-		StartupErrorBehavior: "giveup",
-	}
-	require.Error(t, plugin.Init())
+	var acc testutil.Accumulator
+	var ferr *internal.FatalError
+	require.ErrorAs(t, model.Start(&acc), &ferr)
+	require.ErrorIs(t, model.Gather(&acc), internal.ErrNotConnected)
 }
 
 func TestGatherValidXML(t *testing.T) {
@@ -224,7 +257,8 @@ func TestGatherValidXML(t *testing.T) {
 						"memory_used":                   1,
 						"pcie_link_gen_current":         1,
 						"pcie_link_width_current":       8,
-						"power_draw":                    float64(4.61),
+						"power_draw":                    4.61,
+						"power_limit":                   75.0,
 						"serial":                        "0322218049033",
 						"temperature_gpu":               34,
 						"utilization_gpu":               0,
@@ -460,6 +494,54 @@ func TestGatherValidXML(t *testing.T) {
 					time.Unix(1689872450, 0)),
 			},
 		},
+		{
+			name:     "RTC 3090 schema v12",
+			filename: "rtx-3090-v12.xml",
+			expected: []telegraf.Metric{
+				testutil.MustMetric(
+					"nvidia_smi",
+					map[string]string{
+						"compute_mode": "Default",
+						"index":        "0",
+						"name":         "NVIDIA GeForce RTX 3090",
+						"arch":         "Ampere",
+						"pstate":       "P8",
+						"uuid":         "GPU-12345678-aaaa-bbbb-cccc-0123456789ab",
+					},
+					map[string]interface{}{
+						"clocks_current_graphics":       0,
+						"clocks_current_memory":         405,
+						"clocks_current_sm":             0,
+						"clocks_current_video":          555,
+						"cuda_version":                  "12.0",
+						"display_active":                "Disabled",
+						"display_mode":                  "Disabled",
+						"driver_version":                "525.147.05",
+						"encoder_stats_average_fps":     0,
+						"encoder_stats_average_latency": 0,
+						"encoder_stats_session_count":   0,
+						"fbc_stats_average_fps":         0,
+						"fbc_stats_average_latency":     0,
+						"fbc_stats_session_count":       0,
+						"fan_speed":                     0,
+						"power_draw":                    27.23,
+						"power_limit":                   200.0,
+						"memory_free":                   24258,
+						"memory_total":                  24576,
+						"memory_used":                   1,
+						"memory_reserved":               316,
+						"pcie_link_gen_current":         1,
+						"pcie_link_width_current":       16,
+						"temperature_gpu":               37,
+						"utilization_gpu":               0,
+						"utilization_memory":            0,
+						"utilization_encoder":           0,
+						"utilization_decoder":           0,
+						"vbios_version":                 "94.02.71.40.72",
+					},
+					time.Unix(1689872450, 0)),
+			},
+		},
 		{
 			name:     "A100-SXM4 schema v12",
 			filename: "a100-sxm4-v12.xml",
