@@ -2,6 +2,7 @@ package opcua_listener
 
 import (
 	"context"
+	"errors"
 	"fmt"
 	"reflect"
 	"time"
@@ -11,12 +12,14 @@ import (
 
 	"github.com/influxdata/telegraf"
 	"github.com/influxdata/telegraf/config"
+	opcuaclient "github.com/influxdata/telegraf/plugins/common/opcua"
 	"github.com/influxdata/telegraf/plugins/common/opcua/input"
 )
 
 type SubscribeClientConfig struct {
 	input.InputClientConfig
 	SubscriptionInterval config.Duration `toml:"subscription_interval"`
+	ConnectFailBehavior  string          `toml:"connect_fail_behavior"`
 }
 
 type SubscribeClient struct {
@@ -28,8 +31,54 @@ type SubscribeClient struct {
 	dataNotifications  chan *opcua.PublishNotificationData
 	metrics            chan telegraf.Metric
 
-	processingCtx    context.Context
-	processingCancel context.CancelFunc
+	ctx    context.Context
+	cancel context.CancelFunc
+}
+
+func checkDataChangeFilterParameters(params *input.DataChangeFilter) error {
+	switch {
+	case params.Trigger != input.Status &&
+		params.Trigger != input.StatusValue &&
+		params.Trigger != input.StatusValueTimestamp:
+		return fmt.Errorf("trigger '%s' not supported", params.Trigger)
+	case params.DeadbandType != input.Absolute &&
+		params.DeadbandType != input.Percent:
+		return fmt.Errorf("deadband_type '%s' not supported", params.DeadbandType)
+	case params.DeadbandValue == nil:
+		return errors.New("deadband_value was not set")
+	case *params.DeadbandValue < 0:
+		return errors.New("negative deadband_value not supported")
+	default:
+		return nil
+	}
+}
+
+func assignConfigValuesToRequest(req *ua.MonitoredItemCreateRequest, monParams *input.MonitoringParameters) error {
+	req.RequestedParameters.SamplingInterval = float64(time.Duration(monParams.SamplingInterval) / time.Millisecond)
+
+	if monParams.QueueSize != nil {
+		req.RequestedParameters.QueueSize = *monParams.QueueSize
+	}
+
+	if monParams.DiscardOldest != nil {
+		req.RequestedParameters.DiscardOldest = *monParams.DiscardOldest
+	}
+
+	if monParams.DataChangeFilter != nil {
+		if err := checkDataChangeFilterParameters(monParams.DataChangeFilter); err != nil {
+			return fmt.Errorf(err.Error()+", node '%s'", req.ItemToMonitor.NodeID)
+		}
+
+		req.RequestedParameters.Filter = ua.NewExtensionObject(
+			&ua.DataChangeFilter{
+				Trigger:       ua.DataChangeTriggerFromString(string(monParams.DataChangeFilter.Trigger)),
+				DeadbandType:  uint32(ua.DeadbandTypeFromString(string(monParams.DataChangeFilter.DeadbandType))),
+				DeadbandValue: *monParams.DataChangeFilter.DeadbandValue,
+			},
+		)
+	}
+
+	return nil
 }
 
 func (sc *SubscribeClientConfig) CreateSubscribeClient(log telegraf.Logger) (*SubscribeClient, error) {
@@ -42,6 +91,7 @@ func (sc *SubscribeClientConfig) CreateSubscribeClient(log telegraf.Logger) (*Su
 		return nil, err
 	}
 
+	processingCtx, processingCancel := context.WithCancel(context.Background())
 	subClient := &SubscribeClient{
 		OpcUAInputClient:   client,
 		Config:             *sc,
@@ -51,12 +101,17 @@ func (sc *SubscribeClientConfig) CreateSubscribeClient(log telegraf.Logger) (*Su
 		// the same time. It could be made dependent on the number of nodes subscribed to and the subscription interval.
 		dataNotifications: make(chan *opcua.PublishNotificationData, 100),
 		metrics:           make(chan telegraf.Metric, 100),
+		ctx:               processingCtx,
+		cancel:            processingCancel,
 	}
 
 	log.Debugf("Creating monitored items")
 	for i, nodeID := range client.NodeIDs {
 		// The node id index (i) is used as the handle for the monitored item
 		req := opcua.NewMonitoredItemCreateRequestWithDefaults(nodeID, ua.AttributeIDValue, uint32(i))
+		if err := assignConfigValuesToRequest(req, &client.NodeMetricMapping[i].Tag.MonitoringParams); err != nil {
+			return nil, err
+		}
 		subClient.monitoredItemsReqs[i] = req
 	}
 
@@ -64,13 +119,13 @@ func (sc *SubscribeClientConfig) CreateSubscribeClient(log telegraf.Logger) (*Su
 }
 
 func (o *SubscribeClient) Connect() error {
-	err := o.OpcUAClient.Connect()
+	err := o.OpcUAClient.Connect(o.ctx)
 	if err != nil {
 		return err
 	}
 
 	o.Log.Debugf("Creating OPC UA subscription")
-	o.sub, err = o.Client.Subscribe(&opcua.SubscriptionParameters{
+	o.sub, err = o.Client.Subscribe(o.ctx, &opcua.SubscriptionParameters{
 		Interval: time.Duration(o.Config.SubscriptionInterval),
 	}, o.dataNotifications)
 	if err != nil {
@@ -84,13 +139,16 @@ func (o *SubscribeClient) Connect() error {
 
 func (o *SubscribeClient) Stop(ctx context.Context) <-chan struct{} {
 	o.Log.Debugf("Stopping OPC subscription...")
+	if o.State() != opcuaclient.Connected {
+		return nil
+	}
 	if o.sub != nil {
 		if err := o.sub.Cancel(ctx); err != nil {
 			o.Log.Warn("Cancelling OPC UA subscription failed with error ", err)
 		}
 	}
 	closing := o.OpcUAInputClient.Stop(ctx)
-	o.processingCancel()
+	o.cancel()
 	return closing
 }
 
@@ -101,22 +159,37 @@ func (o *SubscribeClient) CurrentValues() ([]telegraf.Metric, error) {
 func (o *SubscribeClient) StartStreamValues(ctx context.Context) (<-chan telegraf.Metric, error) {
 	err := o.Connect()
 	if err != nil {
+		switch o.Config.ConnectFailBehavior {
+		case "retry":
+			o.Log.Warnf("Failed to connect to OPC UA server %s. Will attempt to connect again at the next interval: %s", o.Config.Endpoint, err)
+			return nil, nil
+		case "ignore":
+			o.Log.Errorf("Failed to connect to OPC UA server %s. Will not retry: %s", o.Config.Endpoint, err)
+			return nil, nil
+		}
 		return nil, err
 	}
 
-	resp, err := o.sub.MonitorWithContext(ctx, ua.TimestampsToReturnBoth, o.monitoredItemsReqs...)
+	resp, err := o.sub.Monitor(ctx, ua.TimestampsToReturnBoth, o.monitoredItemsReqs...)
 	if err != nil {
 		return nil, fmt.Errorf("failed to start monitoring items: %w", err)
 	}
 	o.Log.Debug("Monitoring items")
 
-	for _, res := range resp.Results {
+	for idx, res := range resp.Results {
 		if !o.StatusCodeOK(res.StatusCode) {
+			// Verify NodeIDs array has been built before trying to get item; otherwise show '?' for node id
+			if len(o.OpcUAInputClient.NodeIDs) > idx {
+				o.Log.Debugf("Failed to create monitored item for node %v (%v)",
+					o.OpcUAInputClient.NodeMetricMapping[idx].Tag.FieldName, o.OpcUAInputClient.NodeIDs[idx].String())
+			} else {
+				o.Log.Debugf("Failed to create monitored item for node %v (%v)", o.OpcUAInputClient.NodeMetricMapping[idx].Tag.FieldName, '?')
+			}
+
 			return nil, fmt.Errorf("creating monitored item failed with status code: %w", res.StatusCode)
 		}
 	}
 
-	o.processingCtx, o.processingCancel = context.WithCancel(context.Background())
 	go o.processReceivedNotifications()
 
 	return o.metrics, nil
@@ -125,7 +198,7 @@ func (o *SubscribeClient) StartStreamValues(ctx context.Context) (<-chan telegra
 func (o *SubscribeClient) processReceivedNotifications() {
 	for {
 		select {
-		case <-o.processingCtx.Done():
+		case <-o.ctx.Done():
 			o.Log.Debug("Processing received notifications stopped")
 			return
 
