@@ -14,6 +14,8 @@ import (
 	"strings"
 	"time"
 
+	"github.com/shirou/gopsutil/v3/process"
+
 	"github.com/influxdata/telegraf"
 	"github.com/influxdata/telegraf/internal/choice"
 	"github.com/influxdata/telegraf/plugins/inputs"
@@ -24,34 +26,41 @@ var sampleConfig string
 
 // execCommand is so tests can mock out exec.Command usage.
 var execCommand = exec.Command
-var availableTags = []string{"cmdline", "pid", "ppid", "status", "user"}
 
 type PID int32
 
+type collectionConfig struct {
+	solarisMode bool
+	tagging     map[string]bool
+	features    map[string]bool
+}
+
 type Procstat struct {
 	PidFinder              string          `toml:"pid_finder"`
 	PidFile                string          `toml:"pid_file"`
 	Exe                    string          `toml:"exe"`
 	Pattern                string          `toml:"pattern"`
 	Prefix                 string          `toml:"prefix"`
-	CmdLineTag             bool            `toml:"cmdline_tag" deprecated:"1.29.0;use 'tag_with' instead"`
+	CmdLineTag             bool            `toml:"cmdline_tag" deprecated:"1.29.0;1.40.0;use 'tag_with' instead"`
 	ProcessName            string          `toml:"process_name"`
 	User                   string          `toml:"user"`
 	SystemdUnit            string          `toml:"systemd_unit"`
-	SupervisorUnit         []string        `toml:"supervisor_unit" deprecated:"1.29.0;use 'supervisor_units' instead"`
+	SupervisorUnit         []string        `toml:"supervisor_unit" deprecated:"1.29.0;1.40.0;use 'supervisor_units' instead"`
 	SupervisorUnits        []string        `toml:"supervisor_units"`
 	IncludeSystemdChildren bool            `toml:"include_systemd_children"`
 	CGroup                 string          `toml:"cgroup"`
-	PidTag                 bool            `toml:"pid_tag" deprecated:"1.29.0;use 'tag_with' instead"`
+	PidTag                 bool            `toml:"pid_tag" deprecated:"1.29.0;1.40.0;use 'tag_with' instead"`
 	WinService             string          `toml:"win_service"`
 	Mode                   string          `toml:"mode"`
+	Properties             []string        `toml:"properties"`
 	TagWith                []string        `toml:"tag_with"`
+	Filter                 []Filter        `toml:"filter"`
 	Log                    telegraf.Logger `toml:"-"`
 
-	solarisMode bool
-	finder      PIDFinder
-	processes   map[PID]Process
-	tagging     map[string]bool
+	finder    PIDFinder
+	processes map[PID]Process
+	cfg       collectionConfig
+	oldMode   bool
 
 	createProcess func(PID) (Process, error)
 }
@@ -61,14 +70,16 @@ type PidsTags struct {
 	Tags map[string]string
 }
 
+type processGroup struct {
+	processes []*process.Process
+	tags      map[string]string
+}
+
 func (*Procstat) SampleConfig() string {
 	return sampleConfig
 }
 
 func (p *Procstat) Init() error {
-	// Check solaris mode
-	p.solarisMode = strings.EqualFold(p.Mode, "solaris")
-
 	// Keep the old settings for compatibility
 	if p.PidTag && !choice.Contains("pid", p.TagWith) {
 		p.TagWith = append(p.TagWith, "pid")
@@ -77,53 +88,90 @@ func (p *Procstat) Init() error {
 		p.TagWith = append(p.TagWith, "cmdline")
 	}
 
-	// Check tagging and setup LUT
-	if err := choice.CheckSlice(p.TagWith, availableTags); err != nil {
-		return fmt.Errorf("invalid tag_with setting: %w", err)
-	}
-	p.tagging = make(map[string]bool, len(p.TagWith))
+	// Configure metric collection features
+	p.cfg.solarisMode = strings.EqualFold(p.Mode, "solaris")
+
+	// Convert tagging settings
+	p.cfg.tagging = make(map[string]bool, len(p.TagWith))
 	for _, tag := range p.TagWith {
-		p.tagging[tag] = true
+		switch tag {
+		case "cmdline", "pid", "ppid", "status", "user":
+		default:
+			return fmt.Errorf("invalid 'tag_with' setting %q", tag)
+		}
+		p.cfg.tagging[tag] = true
 	}
 
-	// Keep the old settings for compatibility
-	for _, u := range p.SupervisorUnit {
-		if !choice.Contains(u, p.SupervisorUnits) {
-			p.SupervisorUnits = append(p.SupervisorUnits, u)
+	// Convert collection properties
+	p.cfg.features = make(map[string]bool, len(p.Properties))
+	for _, prop := range p.Properties {
+		switch prop {
+		case "cpu", "limits", "memory", "mmap":
+		default:
+			return fmt.Errorf("invalid 'properties' setting %q", prop)
 		}
+		p.cfg.features[prop] = true
 	}
 
-	// Check filtering
-	switch {
-	case len(p.SupervisorUnits) > 0, p.SystemdUnit != "", p.WinService != "",
-		p.CGroup != "", p.PidFile != "", p.Exe != "", p.Pattern != "",
-		p.User != "":
-		// Do nothing as those are valid settings
-	default:
-		return errors.New("require filter option but none set")
-	}
+	// Check if we got any new-style configuration options and determine
+	// operation mode.
+	p.oldMode = len(p.Filter) == 0
+	if p.oldMode {
+		// Keep the old settings for compatibility
+		for _, u := range p.SupervisorUnit {
+			if !choice.Contains(u, p.SupervisorUnits) {
+				p.SupervisorUnits = append(p.SupervisorUnits, u)
+			}
+		}
 
-	// Instantiate the finder
-	switch p.PidFinder {
-	case "", "pgrep":
-		p.PidFinder = "pgrep"
-		finder, err := newPgrepFinder()
-		if err != nil {
-			return fmt.Errorf("creating pgrep finder failed: %w", err)
+		// Check filtering
+		switch {
+		case len(p.SupervisorUnits) > 0, p.SystemdUnit != "", p.WinService != "",
+			p.CGroup != "", p.PidFile != "", p.Exe != "", p.Pattern != "",
+			p.User != "":
+			// Do nothing as those are valid settings
+		default:
+			return errors.New("require filter option but none set")
 		}
-		p.finder = finder
-	case "native":
-		// gopsutil relies on pgrep when looking up children on darwin
-		// see https://github.com/shirou/gopsutil/blob/v3.23.10/process/process_darwin.go#L235
-		requiresChildren := len(p.SupervisorUnits) > 0 && p.Pattern != ""
-		if requiresChildren && runtime.GOOS == "darwin" {
-			return errors.New("configuration requires 'pgrep' finder on your OS")
+
+		// Instantiate the finder
+		switch p.PidFinder {
+		case "", "pgrep":
+			p.PidFinder = "pgrep"
+			finder, err := newPgrepFinder()
+			if err != nil {
+				return fmt.Errorf("creating pgrep finder failed: %w", err)
+			}
+			p.finder = finder
+		case "native":
+			// gopsutil relies on pgrep when looking up children on darwin
+			// see https://github.com/shirou/gopsutil/blob/v3.23.10/process/process_darwin.go#L235
+			requiresChildren := len(p.SupervisorUnits) > 0 && p.Pattern != ""
+			if requiresChildren && runtime.GOOS == "darwin" {
+				return errors.New("configuration requires 'pgrep' finder on your OS")
+			}
+			p.finder = &NativeFinder{}
+		case "test":
+			p.Log.Warn("running in test mode")
+		default:
+			return fmt.Errorf("unknown pid_finder %q", p.PidFinder)
+		}
+	} else {
+		// Check for mixed mode
+		switch {
+		case p.PidFile != "", p.Exe != "", p.Pattern != "", p.User != "",
+			p.SystemdUnit != "", len(p.SupervisorUnit) > 0,
+			len(p.SupervisorUnits) > 0, p.CGroup != "", p.WinService != "":
+			return errors.New("cannot operate in mixed mode with filters and old-style config")
+		}
+
+		// New-style operations
+		for i := range p.Filter {
+			p.Filter[i].Log = p.Log
+			if err := p.Filter[i].Init(); err != nil {
+				return fmt.Errorf("initializing filter %d failed: %w", i, err)
+			}
 		}
-		p.finder = &NativeFinder{}
-	case "test":
-		p.Log.Warn("running in test mode")
-	default:
-		return fmt.Errorf("unknown pid_finder %q", p.PidFinder)
 	}
 
 	// Initialize the running process cache
@@ -133,6 +181,14 @@ func (p *Procstat) Init() error {
 }
 
 func (p *Procstat) Gather(acc telegraf.Accumulator) error {
+	if p.oldMode {
+		return p.gatherOld(acc)
+	}
+
+	return p.gatherNew(acc)
+}
+
+func (p *Procstat) gatherOld(acc telegraf.Accumulator) error {
 	now := time.Now()
 	results, err := p.findPids()
 	if err != nil {
@@ -163,18 +219,24 @@ func (p *Procstat) Gather(acc telegraf.Accumulator) error {
 		}
 		count += len(r.PIDs)
 		for _, pid := range r.PIDs {
+			// Check if the process is still running
+			proc, err := p.createProcess(pid)
+			if err != nil {
+				// No problem; process may have ended after we found it or it
+				// might be delivered from a non-checking source like a PID file
+				// of a dead process.
+				continue
+			}
+
 			// Use the cached processes as we need the existing instances
 			// to compute delta-metrics (e.g. cpu-usage).
-			proc, found := p.processes[pid]
-			if !found {
+			if cached, found := p.processes[pid]; found {
+				proc = cached
+			} else {
 				// We've found a process that was not recorded before so add it
 				// to the list of processes
-				proc, err = p.createProcess(pid)
-				if err != nil {
-					// No problem; process may have ended after we found it
-					continue
-				}
-				// Assumption: if a process has no name, it probably does not exist
+
+				//nolint:errcheck // Assumption: if a process has no name, it probably does not exist
 				if name, _ := proc.Name(); name == "" {
 					continue
 				}
@@ -190,7 +252,7 @@ func (p *Procstat) Gather(acc telegraf.Accumulator) error {
 				p.processes[pid] = proc
 			}
 			running[pid] = true
-			m := proc.Metric(p.Prefix, p.tagging, p.solarisMode)
+			m := proc.Metric(p.Prefix, &p.cfg)
 			m.SetTime(now)
 			acc.AddMetric(m)
 		}
@@ -226,6 +288,100 @@ func (p *Procstat) Gather(acc telegraf.Accumulator) error {
 	return nil
 }
 
+func (p *Procstat) gatherNew(acc telegraf.Accumulator) error {
+	now := time.Now()
+
+	for _, f := range p.Filter {
+		groups, err := f.ApplyFilter()
+		if err != nil {
+			// Add lookup error-metric
+			acc.AddFields(
+				"procstat_lookup",
+				map[string]interface{}{
+					"pid_count":   0,
+					"running":     0,
+					"result_code": 1,
+				},
+				map[string]string{
+					"filter": f.Name,
+					"result": "lookup_error",
+				},
+				now,
+			)
+			acc.AddError(fmt.Errorf("applying filter %q failed: %w", f.Name, err))
+			continue
+		}
+
+		var count int
+		running := make(map[PID]bool)
+		for _, g := range groups {
+			count += len(g.processes)
+			for _, gp := range g.processes {
+				// Skip over non-running processes
+				if running, err := gp.IsRunning(); err != nil || !running {
+					continue
+				}
+
+				// Use the cached processes as we need the existing instances
+				// to compute delta-metrics (e.g. cpu-usage).
+				pid := PID(gp.Pid)
+				proc, found := p.processes[pid]
+				if !found {
+					//nolint:errcheck // Assumption: if a process has no name, it probably does not exist
+					if name, _ := gp.Name(); name == "" {
+						continue
+					}
+
+					// We've found a process that was not recorded before so add it
+					// to the list of processes
+					tags := make(map[string]string, len(g.tags)+1)
+					for k, v := range g.tags {
+						tags[k] = v
+					}
+					if p.ProcessName != "" {
+						proc.SetTag("process_name", p.ProcessName)
+					}
+					tags["filter"] = f.Name
+
+					proc = &Proc{
+						Process:     gp,
+						hasCPUTimes: false,
+						tags:        tags,
+					}
+					p.processes[pid] = proc
+				}
+				running[pid] = true
+				m := proc.Metric(p.Prefix, &p.cfg)
+				m.SetTime(now)
+				acc.AddMetric(m)
+			}
+		}
+
+		// Cleanup processes that are not running anymore
+		for pid := range p.processes {
+			if !running[pid] {
+				delete(p.processes, pid)
+			}
+		}
+
+		// Add lookup statistics-metric
+		acc.AddFields(
+			"procstat_lookup",
+			map[string]interface{}{
+				"pid_count":   count,
+				"running":     len(running),
+				"result_code": 0,
+			},
+			map[string]string{
+				"filter": f.Name,
+				"result": "success",
+			},
+			now,
+		)
+	}
+	return nil
+}
+
 // Get matching PIDs and their initial tags
 func (p *Procstat) findPids() ([]PidsTags, error) {
 	switch {
@@ -486,6 +642,9 @@ func (p *Procstat) winServicePIDs() ([]PID, error) {
 
 func init() {
 	inputs.Add("procstat", func() telegraf.Input {
-		return &Procstat{createProcess: newProc}
+		return &Procstat{
+			Properties:    []string{"cpu", "memory", "mmap"},
+			createProcess: newProc,
+		}
 	})
 }
