@@ -15,19 +15,20 @@ import (
 	"sync"
 	"time"
 
-	"github.com/influxdata/telegraf/filter"
-	"github.com/influxdata/telegraf/models"
-	"k8s.io/client-go/tools/cache"
-
+	"github.com/prometheus/common/expfmt"
 	"k8s.io/apimachinery/pkg/fields"
 	"k8s.io/apimachinery/pkg/labels"
+	"k8s.io/client-go/tools/cache"
 
 	"github.com/influxdata/telegraf"
 	"github.com/influxdata/telegraf/config"
+	"github.com/influxdata/telegraf/filter"
 	"github.com/influxdata/telegraf/internal"
+	"github.com/influxdata/telegraf/models"
 	httpconfig "github.com/influxdata/telegraf/plugins/common/http"
 	"github.com/influxdata/telegraf/plugins/inputs"
-	parserV2 "github.com/influxdata/telegraf/plugins/parsers/prometheus"
+	"github.com/influxdata/telegraf/plugins/parsers/openmetrics"
+	parser "github.com/influxdata/telegraf/plugins/parsers/prometheus"
 )
 
 //go:embed sample.conf
@@ -47,93 +48,71 @@ const (
 type PodID string
 
 type Prometheus struct {
-	// An array of urls to scrape metrics from.
-	URLs []string `toml:"urls"`
+	URLs                 []string          `toml:"urls"`
+	BearerToken          string            `toml:"bearer_token"`
+	BearerTokenString    string            `toml:"bearer_token_string"`
+	Username             string            `toml:"username"`
+	Password             string            `toml:"password"`
+	HTTPHeaders          map[string]string `toml:"http_headers"`
+	ContentLengthLimit   config.Size       `toml:"content_length_limit"`
+	ContentTypeOverride  string            `toml:"content_type_override"`
+	EnableRequestMetrics bool              `toml:"enable_request_metrics"`
+	MetricVersion        int               `toml:"metric_version"`
+	URLTag               string            `toml:"url_tag"`
+	IgnoreTimestamp      bool              `toml:"ignore_timestamp"`
 
-	// An array of Kubernetes services to scrape metrics from.
-	KubernetesServices []string
+	// Kubernetes service discovery
+	MonitorPods                 bool                `toml:"monitor_kubernetes_pods"`
+	PodScrapeScope              string              `toml:"pod_scrape_scope"`
+	NodeIP                      string              `toml:"node_ip"`
+	PodScrapeInterval           int                 `toml:"pod_scrape_interval"`
+	PodNamespace                string              `toml:"monitor_kubernetes_pods_namespace"`
+	PodNamespaceLabelName       string              `toml:"pod_namespace_label_name"`
+	KubernetesServices          []string            `toml:"kubernetes_services"`
+	KubeConfig                  string              `toml:"kube_config"`
+	KubernetesLabelSelector     string              `toml:"kubernetes_label_selector"`
+	KubernetesFieldSelector     string              `toml:"kubernetes_field_selector"`
+	MonitorKubernetesPodsMethod MonitorMethod       `toml:"monitor_kubernetes_pods_method"`
+	MonitorKubernetesPodsScheme string              `toml:"monitor_kubernetes_pods_scheme"`
+	MonitorKubernetesPodsPath   string              `toml:"monitor_kubernetes_pods_path"`
+	MonitorKubernetesPodsPort   int                 `toml:"monitor_kubernetes_pods_port"`
+	NamespaceAnnotationPass     map[string][]string `toml:"namespace_annotation_pass"`
+	NamespaceAnnotationDrop     map[string][]string `toml:"namespace_annotation_drop"`
+	PodAnnotationInclude        []string            `toml:"pod_annotation_include"`
+	PodAnnotationExclude        []string            `toml:"pod_annotation_exclude"`
+	PodLabelInclude             []string            `toml:"pod_label_include"`
+	PodLabelExclude             []string            `toml:"pod_label_exclude"`
+	CacheRefreshInterval        int                 `toml:"cache_refresh_interval"`
 
-	// Location of kubernetes config file
-	KubeConfig string
-
-	// Label Selector/s for Kubernetes
-	KubernetesLabelSelector string `toml:"kubernetes_label_selector"`
-
-	// Field Selector/s for Kubernetes
-	KubernetesFieldSelector string `toml:"kubernetes_field_selector"`
-
-	// Consul SD configuration
+	// Consul discovery
 	ConsulConfig ConsulConfig `toml:"consul"`
 
-	// Bearer Token authorization file path
-	BearerToken       string `toml:"bearer_token"`
-	BearerTokenString string `toml:"bearer_token_string"`
-
-	// Basic authentication credentials
-	Username string `toml:"username"`
-	Password string `toml:"password"`
-
-	HTTPHeaders map[string]string `toml:"http_headers"`
-
-	ResponseTimeout config.Duration `toml:"response_timeout" deprecated:"1.26.0;use 'timeout' instead"`
-
-	MetricVersion int `toml:"metric_version"`
-
-	URLTag string `toml:"url_tag"`
-
-	IgnoreTimestamp bool `toml:"ignore_timestamp"`
-
-	Log telegraf.Logger
-
+	Log telegraf.Logger `toml:"-"`
 	httpconfig.HTTPClientConfig
 
-	client  *http.Client
-	headers map[string]string
-
-	nsStore cache.Store
+	client      *http.Client
+	headers     map[string]string
+	contentType string
 
+	nsStore          cache.Store
 	nsAnnotationPass []models.TagFilter
 	nsAnnotationDrop []models.TagFilter
 
 	// Should we scrape Kubernetes services for prometheus annotations
-	MonitorPods           bool   `toml:"monitor_kubernetes_pods"`
-	PodScrapeScope        string `toml:"pod_scrape_scope"`
-	NodeIP                string `toml:"node_ip"`
-	PodScrapeInterval     int    `toml:"pod_scrape_interval"`
-	PodNamespace          string `toml:"monitor_kubernetes_pods_namespace"`
-	PodNamespaceLabelName string `toml:"pod_namespace_label_name"`
-	lock                  sync.Mutex
-	kubernetesPods        map[PodID]URLAndAddress
-	cancel                context.CancelFunc
-	wg                    sync.WaitGroup
+	lock           sync.Mutex
+	kubernetesPods map[PodID]URLAndAddress
+	cancel         context.CancelFunc
+	wg             sync.WaitGroup
 
 	// Only for monitor_kubernetes_pods=true and pod_scrape_scope="node"
-	podLabelSelector  labels.Selector
-	podFieldSelector  fields.Selector
-	isNodeScrapeScope bool
-
-	MonitorKubernetesPodsMethod MonitorMethod `toml:"monitor_kubernetes_pods_method"`
-	MonitorKubernetesPodsScheme string        `toml:"monitor_kubernetes_pods_scheme"`
-	MonitorKubernetesPodsPath   string        `toml:"monitor_kubernetes_pods_path"`
-	MonitorKubernetesPodsPort   int           `toml:"monitor_kubernetes_pods_port"`
-
-	NamespaceAnnotationPass map[string][]string `toml:"namespace_annotation_pass"`
-	NamespaceAnnotationDrop map[string][]string `toml:"namespace_annotation_drop"`
-
-	PodAnnotationInclude []string `toml:"pod_annotation_include"`
-	PodAnnotationExclude []string `toml:"pod_annotation_exclude"`
-
-	PodLabelInclude []string `toml:"pod_label_include"`
-	PodLabelExclude []string `toml:"pod_label_exclude"`
-
+	podLabelSelector           labels.Selector
+	podFieldSelector           fields.Selector
+	isNodeScrapeScope          bool
 	podAnnotationIncludeFilter filter.Filter
 	podAnnotationExcludeFilter filter.Filter
 	podLabelIncludeFilter      filter.Filter
 	podLabelExcludeFilter      filter.Filter
 
-	// Only for monitor_kubernetes_pods=true
-	CacheRefreshInterval int `toml:"cache_refresh_interval"`
-
 	// List of consul services to scrape
 	consulServices map[string]URLAndAddress
 }
@@ -143,6 +122,29 @@ func (*Prometheus) SampleConfig() string {
 }
 
 func (p *Prometheus) Init() error {
+	// Setup content-type override if requested
+	switch p.ContentTypeOverride {
+	case "": // No override
+	case "text":
+		p.contentType = string(expfmt.NewFormat(expfmt.TypeTextPlain))
+	case "protobuf-delimiter":
+		p.contentType = string(expfmt.NewFormat(expfmt.TypeProtoDelim))
+	case "protobuf-compact":
+		p.contentType = string(expfmt.NewFormat(expfmt.TypeProtoCompact))
+	case "protobuf-text":
+		p.contentType = string(expfmt.NewFormat(expfmt.TypeProtoText))
+	case "openmetrics-text":
+		f, err := expfmt.NewOpenMetricsFormat(expfmt.OpenMetricsVersion_1_0_0)
+		if err != nil {
+			return err
+		}
+		p.contentType = string(f)
+	case "openmetrics-protobuf":
+		p.contentType = "application/openmetrics-protobuf;version=1.0.0"
+	default:
+		return fmt.Errorf("invalid 'content_type_override' setting %q", p.ContentTypeOverride)
+	}
+
 	// Config processing for node scrape scope for monitor_kubernetes_pods
 	p.isNodeScrapeScope = strings.EqualFold(p.PodScrapeScope, "node")
 	if p.isNodeScrapeScope {
@@ -207,16 +209,26 @@ func (p *Prometheus) Init() error {
 		return err
 	}
 
-	ctx := context.Background()
-	if p.ResponseTimeout != 0 {
-		p.HTTPClientConfig.Timeout = p.ResponseTimeout
+	if p.MetricVersion == 0 {
+		p.MetricVersion = 1
 	}
 
+	ctx := context.Background()
+
 	client, err := p.HTTPClientConfig.CreateClient(ctx, p.Log)
 	if err != nil {
 		return err
 	}
 	p.client = client
+	if p.HTTPClientConfig.ResponseHeaderTimeout != 0 {
+		p.Log.Warn(
+			"Config option response_timeout was set to non-zero value. This option's behavior was " +
+				"changed in Telegraf 1.30.2 and now controls the HTTP client's header timeout and " +
+				"not the Prometheus timeout. Users can ignore this warning if that was the intention. " +
+				"Otherwise, please use the timeout config option for the Prometheus timeout.",
+		)
+	}
+
 	p.headers = map[string]string{
 		"User-Agent": internal.ProductToken(),
 		"Accept":     acceptHeader,
@@ -346,7 +358,13 @@ func (p *Prometheus) Gather(acc telegraf.Accumulator) error {
 		wg.Add(1)
 		go func(serviceURL URLAndAddress) {
 			defer wg.Done()
-			acc.AddError(p.gatherURL(serviceURL, acc))
+			requestFields, tags, err := p.gatherURL(serviceURL, acc)
+			acc.AddError(err)
+
+			// Add metrics
+			if p.EnableRequestMetrics {
+				acc.AddFields("prometheus_request", requestFields, tags)
+			}
 		}(URL)
 	}
 
@@ -355,44 +373,54 @@ func (p *Prometheus) Gather(acc telegraf.Accumulator) error {
 	return nil
 }
 
-func (p *Prometheus) gatherURL(u URLAndAddress, acc telegraf.Accumulator) error {
+func (p *Prometheus) gatherURL(u URLAndAddress, acc telegraf.Accumulator) (map[string]interface{}, map[string]string, error) {
 	var req *http.Request
-	var err error
 	var uClient *http.Client
-	var metrics []telegraf.Metric
+	requestFields := make(map[string]interface{})
+	tags := map[string]string{}
+	if p.URLTag != "" {
+		tags[p.URLTag] = u.OriginalURL.String()
+	}
+	if u.Address != "" {
+		tags["address"] = u.Address
+	}
+	for k, v := range u.Tags {
+		tags[k] = v
+	}
+
 	if u.URL.Scheme == "unix" {
 		path := u.URL.Query().Get("path")
 		if path == "" {
 			path = "/metrics"
 		}
+
+		var err error
 		addr := "http://localhost" + path
 		req, err = http.NewRequest("GET", addr, nil)
 		if err != nil {
-			return fmt.Errorf("unable to create new request %q: %w", addr, err)
+			return nil, nil, fmt.Errorf("unable to create new request %q: %w", addr, err)
 		}
 
-		// ignore error because it's been handled before getting here
+		//nolint:errcheck // ignore error because it's been handled before getting here
 		tlsCfg, _ := p.HTTPClientConfig.TLSConfig()
 		uClient = &http.Client{
 			Transport: &http.Transport{
 				TLSClientConfig:   tlsCfg,
 				DisableKeepAlives: true,
-				Dial: func(network, addr string) (net.Conn, error) {
+				Dial: func(string, string) (net.Conn, error) {
 					c, err := net.Dial("unix", u.URL.Path)
 					return c, err
 				},
 			},
 		}
-		if p.ResponseTimeout != 0 {
-			uClient.Timeout = time.Duration(p.ResponseTimeout)
-		}
 	} else {
 		if u.URL.Path == "" {
 			u.URL.Path = "/metrics"
 		}
+		var err error
 		req, err = http.NewRequest("GET", u.URL.String(), nil)
 		if err != nil {
-			return fmt.Errorf("unable to create new request %q: %w", u.URL.String(), err)
+			return nil, nil, fmt.Errorf("unable to create new request %q: %w", u.URL.String(), err)
 		}
 	}
 
@@ -401,7 +429,7 @@ func (p *Prometheus) gatherURL(u URLAndAddress, acc telegraf.Accumulator) error
 	if p.BearerToken != "" {
 		token, err := os.ReadFile(p.BearerToken)
 		if err != nil {
-			return err
+			return nil, nil, err
 		}
 		req.Header.Set("Authorization", "Bearer "+string(token))
 	} else if p.BearerTokenString != "" {
@@ -411,43 +439,87 @@ func (p *Prometheus) gatherURL(u URLAndAddress, acc telegraf.Accumulator) error
 	}
 
 	for key, value := range p.HTTPHeaders {
-		req.Header.Set(key, value)
+		if strings.EqualFold(key, "host") {
+			req.Host = value
+		} else {
+			req.Header.Set(key, value)
+		}
 	}
 
+	var err error
 	var resp *http.Response
+	var start time.Time
 	if u.URL.Scheme != "unix" {
+		start = time.Now()
 		//nolint:bodyclose // False positive (because of if-else) - body will be closed in `defer`
 		resp, err = p.client.Do(req)
 	} else {
+		start = time.Now()
 		//nolint:bodyclose // False positive (because of if-else) - body will be closed in `defer`
 		resp, err = uClient.Do(req)
 	}
+	end := time.Since(start).Seconds()
 	if err != nil {
-		return fmt.Errorf("error making HTTP request to %q: %w", u.URL, err)
+		return requestFields, tags, fmt.Errorf("error making HTTP request to %q: %w", u.URL, err)
 	}
+	requestFields["response_time"] = end
+
 	defer resp.Body.Close()
 
 	if resp.StatusCode != http.StatusOK {
-		return fmt.Errorf("%q returned HTTP status %q", u.URL, resp.Status)
+		return requestFields, tags, fmt.Errorf("%q returned HTTP status %q", u.URL, resp.Status)
 	}
 
-	body, err := io.ReadAll(resp.Body)
-	if err != nil {
-		return fmt.Errorf("error reading body: %w", err)
-	}
+	var body []byte
+	if p.ContentLengthLimit != 0 {
+		limit := int64(p.ContentLengthLimit)
 
-	if p.MetricVersion == 2 {
-		parser := parserV2.Parser{
-			Header:          resp.Header,
-			IgnoreTimestamp: p.IgnoreTimestamp,
+		// To determine whether io.ReadAll() ended due to EOF or reached the specified limit,
+		// read up to the specified limit plus one extra byte, and then make a decision based
+		// on the length of the result.
+		lr := io.LimitReader(resp.Body, limit+1)
+
+		body, err = io.ReadAll(lr)
+		if err != nil {
+			return requestFields, tags, fmt.Errorf("error reading body: %w", err)
+		}
+		if int64(len(body)) > limit {
+			p.Log.Infof("skipping %s: content length exceeded maximum body size (%d)", u.URL, limit)
+			return requestFields, tags, nil
 		}
-		metrics, err = parser.Parse(body)
 	} else {
-		metrics, err = Parse(body, resp.Header, p.IgnoreTimestamp)
+		body, err = io.ReadAll(resp.Body)
+		if err != nil {
+			return requestFields, tags, fmt.Errorf("error reading body: %w", err)
+		}
+	}
+	requestFields["content_length"] = len(body)
+
+	// Override the response format if the user requested it
+	if p.contentType != "" {
+		resp.Header.Set("Content-Type", p.contentType)
 	}
 
+	// Parse the metrics
+	var metricParser telegraf.Parser
+	if openmetrics.AcceptsContent(resp.Header) {
+		metricParser = &openmetrics.Parser{
+			Header:          resp.Header,
+			MetricVersion:   p.MetricVersion,
+			IgnoreTimestamp: p.IgnoreTimestamp,
+			Log:             p.Log,
+		}
+	} else {
+		metricParser = &parser.Parser{
+			Header:          resp.Header,
+			MetricVersion:   p.MetricVersion,
+			IgnoreTimestamp: p.IgnoreTimestamp,
+			Log:             p.Log,
+		}
+	}
+	metrics, err := metricParser.Parse(body)
 	if err != nil {
-		return fmt.Errorf("error reading metrics for %q: %w", u.URL, err)
+		return requestFields, tags, fmt.Errorf("error reading metrics for %q: %w", u.URL, err)
 	}
 
 	for _, metric := range metrics {
@@ -478,7 +550,7 @@ func (p *Prometheus) gatherURL(u URLAndAddress, acc telegraf.Accumulator) error
 		}
 	}
 
-	return nil
+	return requestFields, tags, nil
 }
 
 func (p *Prometheus) addHeaders(req *http.Request) {
@@ -533,6 +605,10 @@ func (p *Prometheus) Start(_ telegraf.Accumulator) error {
 func (p *Prometheus) Stop() {
 	p.cancel()
 	p.wg.Wait()
+
+	if p.client != nil {
+		p.client.CloseIdleConnections()
+	}
 }
 
 func init() {
