@@ -16,7 +16,6 @@ import (
 	"github.com/influxdata/telegraf/plugins/inputs"
 )
 
-// DO NOT REMOVE THE NEXT TWO LINES! This is required to embed the sampleConfig data.
 //go:embed sample.conf
 var sampleConfig string
 
@@ -39,6 +38,7 @@ func (px *Proxmox) Gather(acc telegraf.Accumulator) error {
 func (px *Proxmox) Init() error {
 	// Set hostname as default node name for backwards compatibility
 	if px.NodeName == "" {
+		//nolint:errcheck // best attempt setting of NodeName
 		hostname, _ := os.Hostname()
 		px.NodeName = hostname
 	}
@@ -118,7 +118,7 @@ func gatherQemuData(px *Proxmox, acc telegraf.Accumulator) {
 func gatherVMData(px *Proxmox, acc telegraf.Accumulator, rt ResourceType) {
 	vmStats, err := getVMStats(px, rt)
 	if err != nil {
-		px.Log.Error("Error getting VM stats: %v", err)
+		px.Log.Errorf("Error getting VM stats: %v", err)
 		return
 	}
 
@@ -138,7 +138,7 @@ func gatherVMData(px *Proxmox, acc telegraf.Accumulator, rt ResourceType) {
 		tags := getTags(px, vmStat.Name, vmConfig, rt)
 		currentVMStatus, err := getCurrentVMStatus(px, rt, vmStat.ID)
 		if err != nil {
-			px.Log.Errorf("Error getting VM curent VM status: %v", err)
+			px.Log.Errorf("Error getting VM current VM status: %v", err)
 			return
 		}
 
