@@ -39,7 +39,7 @@ var tomcatStatus8 = `<?xml version="1.0" encoding="UTF-8"?>
 </status>`
 
 func TestHTTPTomcat8(t *testing.T) {
-	ts := httptest.NewServer(http.HandlerFunc(func(w http.ResponseWriter, r *http.Request) {
+	ts := httptest.NewServer(http.HandlerFunc(func(w http.ResponseWriter, _ *http.Request) {
 		w.WriteHeader(http.StatusOK)
 		_, err := fmt.Fprintln(w, tomcatStatus8)
 		require.NoError(t, err)
@@ -124,7 +124,7 @@ var tomcatStatus6 = `<?xml version="1.0" encoding="utf-8"?>
 </status>`
 
 func TestHTTPTomcat6(t *testing.T) {
-	ts := httptest.NewServer(http.HandlerFunc(func(w http.ResponseWriter, r *http.Request) {
+	ts := httptest.NewServer(http.HandlerFunc(func(w http.ResponseWriter, _ *http.Request) {
 		w.WriteHeader(http.StatusOK)
 		_, err := fmt.Fprintln(w, tomcatStatus6)
 		require.NoError(t, err)
