@@ -132,16 +132,15 @@ func defaultVSphere() *VSphere {
 		DatacenterInclude:         []string{"/**"},
 		ClientConfig:              itls.ClientConfig{InsecureSkipVerify: true},
 
-		MaxQueryObjects:             256,
-		MaxQueryMetrics:             256,
-		ObjectDiscoveryInterval:     config.Duration(time.Second * 300),
-		Timeout:                     config.Duration(time.Second * 20),
-		ForceDiscoverOnInit:         true,
-		DiscoverConcurrency:         1,
-		CollectConcurrency:          1,
-		Separator:                   ".",
-		HistoricalInterval:          config.Duration(time.Second * 300),
-		DisconnectedServersBehavior: "error",
+		MaxQueryObjects:         256,
+		MaxQueryMetrics:         256,
+		ObjectDiscoveryInterval: config.Duration(time.Second * 300),
+		Timeout:                 config.Duration(time.Second * 20),
+		ForceDiscoverOnInit:     true,
+		DiscoverConcurrency:     1,
+		CollectConcurrency:      1,
+		Separator:               ".",
+		HistoricalInterval:      config.Duration(time.Second * 300),
 	}
 }
 
@@ -176,10 +175,10 @@ func testAlignUniform(t *testing.T, n int) {
 	}
 	e := Endpoint{log: testutil.Logger{}}
 	newInfo, newValues := e.alignSamples(info, values, 60*time.Second)
-	require.Equal(t, n/3, len(newInfo), "Aligned infos have wrong size")
-	require.Equal(t, n/3, len(newValues), "Aligned values have wrong size")
+	require.Len(t, newInfo, n/3, "Aligned infos have wrong size")
+	require.Len(t, newValues, n/3, "Aligned values have wrong size")
 	for _, v := range newValues {
-		require.Equal(t, 1.0, v, "Aligned value should be 1")
+		require.InDelta(t, 1.0, v, testutil.DefaultDelta, "Aligned value should be 1")
 	}
 }
 
@@ -202,10 +201,10 @@ func TestAlignMetrics(t *testing.T) {
 	}
 	e := Endpoint{log: testutil.Logger{}}
 	newInfo, newValues := e.alignSamples(info, values, 60*time.Second)
-	require.Equal(t, n/3, len(newInfo), "Aligned infos have wrong size")
-	require.Equal(t, n/3, len(newValues), "Aligned values have wrong size")
+	require.Len(t, newInfo, n/3, "Aligned infos have wrong size")
+	require.Len(t, newValues, n/3, "Aligned values have wrong size")
 	for _, v := range newValues {
-		require.Equal(t, 2.0, v, "Aligned value should be 2")
+		require.InDelta(t, 2.0, v, testutil.DefaultDelta, "Aligned value should be 2")
 	}
 }
 
@@ -252,11 +251,12 @@ func testLookupVM(ctx context.Context, t *testing.T, f *Finder, path string, exp
 	var vm []mo.VirtualMachine
 	err := f.Find(ctx, "VirtualMachine", path, &vm)
 	require.NoError(t, err)
-	require.Equal(t, expected, len(vm))
+	require.Len(t, vm, expected)
 	if expectedName != "" {
 		require.Equal(t, expectedName, vm[0].Name)
 	}
-	for _, v := range vm {
+	for i := range vm {
+		v := &vm[i]
 		require.Equal(t, poweredOn, v.Runtime.PowerState)
 	}
 }
@@ -282,31 +282,31 @@ func TestFinder(t *testing.T) {
 	var dc []mo.Datacenter
 	err = f.Find(ctx, "Datacenter", "/DC0", &dc)
 	require.NoError(t, err)
-	require.Equal(t, 1, len(dc))
+	require.Len(t, dc, 1)
 	require.Equal(t, "DC0", dc[0].Name)
 
 	var host []mo.HostSystem
 	err = f.Find(ctx, "HostSystem", "/DC0/host/DC0_H0/DC0_H0", &host)
 	require.NoError(t, err)
-	require.Equal(t, 1, len(host))
+	require.Len(t, host, 1)
 	require.Equal(t, "DC0_H0", host[0].Name)
 
 	host = []mo.HostSystem{}
 	err = f.Find(ctx, "HostSystem", "/DC0/host/DC0_C0/DC0_C0_H0", &host)
 	require.NoError(t, err)
-	require.Equal(t, 1, len(host))
+	require.Len(t, host, 1)
 	require.Equal(t, "DC0_C0_H0", host[0].Name)
 
 	var resourcepool = []mo.ResourcePool{}
 	err = f.Find(ctx, "ResourcePool", "/DC0/host/DC0_C0/Resources/DC0_C0_RP0", &resourcepool)
 	require.NoError(t, err)
-	require.Equal(t, 1, len(host))
+	require.Len(t, host, 1)
 	require.Equal(t, "DC0_C0_H0", host[0].Name)
 
 	host = []mo.HostSystem{}
 	err = f.Find(ctx, "HostSystem", "/DC0/host/DC0_C0/*", &host)
 	require.NoError(t, err)
-	require.Equal(t, 3, len(host))
+	require.Len(t, host, 3)
 
 	var vm []mo.VirtualMachine
 	testLookupVM(ctx, t, &f, "/DC0/vm/DC0_H0_VM0", 1, "")
@@ -325,7 +325,7 @@ func TestFinder(t *testing.T) {
 	vm = []mo.VirtualMachine{}
 	err = f.FindAll(ctx, "VirtualMachine", []string{"/DC0/vm/DC0_H0*", "/DC0/vm/DC0_C0*"}, []string{}, &vm)
 	require.NoError(t, err)
-	require.Equal(t, 4, len(vm))
+	require.Len(t, vm, 4)
 
 	rf := ResourceFilter{
 		finder:       &f,
@@ -335,7 +335,7 @@ func TestFinder(t *testing.T) {
 	}
 	vm = []mo.VirtualMachine{}
 	require.NoError(t, rf.FindAll(ctx, &vm))
-	require.Equal(t, 3, len(vm))
+	require.Len(t, vm, 3)
 
 	rf = ResourceFilter{
 		finder:       &f,
@@ -345,7 +345,7 @@ func TestFinder(t *testing.T) {
 	}
 	vm = []mo.VirtualMachine{}
 	require.NoError(t, rf.FindAll(ctx, &vm))
-	require.Equal(t, 0, len(vm))
+	require.Empty(t, vm)
 
 	rf = ResourceFilter{
 		finder:       &f,
@@ -355,7 +355,7 @@ func TestFinder(t *testing.T) {
 	}
 	vm = []mo.VirtualMachine{}
 	require.NoError(t, rf.FindAll(ctx, &vm))
-	require.Equal(t, 0, len(vm))
+	require.Empty(t, vm)
 
 	rf = ResourceFilter{
 		finder:       &f,
@@ -365,7 +365,7 @@ func TestFinder(t *testing.T) {
 	}
 	vm = []mo.VirtualMachine{}
 	require.NoError(t, rf.FindAll(ctx, &vm))
-	require.Equal(t, 8, len(vm))
+	require.Len(t, vm, 8)
 
 	rf = ResourceFilter{
 		finder:       &f,
@@ -375,7 +375,7 @@ func TestFinder(t *testing.T) {
 	}
 	vm = []mo.VirtualMachine{}
 	require.NoError(t, rf.FindAll(ctx, &vm))
-	require.Equal(t, 4, len(vm))
+	require.Len(t, vm, 4)
 }
 
 func TestFolders(t *testing.T) {
@@ -400,13 +400,13 @@ func TestFolders(t *testing.T) {
 	var folder []mo.Folder
 	err = f.Find(ctx, "Folder", "/F0", &folder)
 	require.NoError(t, err)
-	require.Equal(t, 1, len(folder))
+	require.Len(t, folder, 1)
 	require.Equal(t, "F0", folder[0].Name)
 
 	var dc []mo.Datacenter
 	err = f.Find(ctx, "Datacenter", "/F0/DC1", &dc)
 	require.NoError(t, err)
-	require.Equal(t, 1, len(dc))
+	require.Len(t, dc, 1)
 	require.Equal(t, "DC1", dc[0].Name)
 
 	testLookupVM(ctx, t, &f, "/F0/DC0/vm/**/F*", 0, "")
@@ -414,12 +414,46 @@ func TestFolders(t *testing.T) {
 	testLookupVM(ctx, t, &f, "/F0/DC1/vm/**/F*/**", 4, "")
 }
 
-func TestCollectionWithClusterMetrics(t *testing.T) {
-	if testing.Short() {
-		t.Skip("Skipping long test in short mode")
-	}
+func TestVsanCmmds(t *testing.T) {
+	m, s, err := createSim(0)
+	require.NoError(t, err)
+	defer m.Remove()
+	defer s.Close()
 
-	testCollection(t, false)
+	v := defaultVSphere()
+	ctx := context.Background()
+
+	c, err := NewClient(ctx, s.URL, v)
+	require.NoError(t, err)
+
+	f := Finder{c}
+	var clusters []mo.ClusterComputeResource
+	err = f.FindAll(ctx, "ClusterComputeResource", []string{"/**"}, []string{}, &clusters)
+	require.NoError(t, err)
+
+	clusterObj := object.NewClusterComputeResource(c.Client.Client, clusters[0].Reference())
+	_, err = getCmmdsMap(ctx, c.Client.Client, clusterObj)
+	require.Error(t, err)
+}
+
+func TestVsanTags(t *testing.T) {
+	host := "5b860329-3bc4-a76c-48b6-246e963cfcc0"
+	disk := "52ee3be1-47cc-b50d-ecab-01af0f706381"
+	ssdDisk := "52f26fc8-0b9b-56d8-3a32-a9c3bfbc6148"
+	ssd := "52173131-3384-bb63-4ef8-c00b0ce7e3e7"
+	hostname := "sc2-hs1-b2801.eng.vmware.com"
+	devName := "naa.55cd2e414d82c815:2"
+	var cmmds = map[string]CmmdsEntity{
+		disk:    {UUID: disk, Type: "DISK", Owner: host, Content: CmmdsContent{DevName: devName, IsSsd: 1.}},
+		ssdDisk: {UUID: ssdDisk, Type: "DISK", Owner: host, Content: CmmdsContent{DevName: devName, IsSsd: 0., SsdUUID: ssd}},
+		host:    {UUID: host, Type: "HOSTNAME", Owner: host, Content: CmmdsContent{Hostname: hostname}},
+	}
+	tags := populateCMMDSTags(make(map[string]string), "capacity-disk", disk, cmmds)
+	require.Len(t, tags, 2)
+	tags = populateCMMDSTags(make(map[string]string), "cache-disk", ssdDisk, cmmds)
+	require.Len(t, tags, 3)
+	tags = populateCMMDSTags(make(map[string]string), "host-domclient", host, cmmds)
+	require.Len(t, tags, 1)
 }
 
 func TestCollectionNoClusterMetrics(t *testing.T) {
@@ -443,7 +477,7 @@ func TestDisconnectedServerBehavior(t *testing.T) {
 	v.DisconnectedServersBehavior = "something else"
 	_, err = NewEndpoint(context.Background(), v, u, v.Log)
 	require.Error(t, err)
-	require.Equal(t, err.Error(), `"something else" is not a valid value for disconnected_servers_behavior`)
+	require.Equal(t, `"something else" is not a valid value for disconnected_servers_behavior`, err.Error())
 }
 
 func testCollection(t *testing.T, excludeClusters bool) {
@@ -480,8 +514,8 @@ func testCollection(t *testing.T, excludeClusters bool) {
 	require.NoError(t, v.Start(&acc))
 	defer v.Stop()
 	require.NoError(t, v.Gather(&acc))
-	require.Equal(t, 0, len(acc.Errors), fmt.Sprintf("Errors found: %s", acc.Errors))
-	require.True(t, len(acc.Metrics) > 0, "No metrics were collected")
+	require.Empty(t, acc.Errors, fmt.Sprintf("Errors found: %s", acc.Errors))
+	require.NotEmpty(t, acc.Metrics, "No metrics were collected")
 	cache := make(map[string]string)
 	client, err := v.endpoints[0].clientFactory.GetClient(context.Background())
 	require.NoError(t, err)
@@ -536,3 +570,53 @@ func mustContainAll(t *testing.T, tagMap map[string]string, mustHave []string) {
 		require.Contains(t, tagMap, tag)
 	}
 }
+
+func TestVersionLowerThan(t *testing.T) {
+	tests := []struct {
+		current string
+		major   int
+		minor   int
+		result  bool
+	}{
+		{
+			current: "7",
+			major:   6,
+			minor:   3,
+			result:  false,
+		},
+		{
+			current: "5",
+			major:   6,
+			minor:   3,
+			result:  true,
+		},
+		{
+			current: "6.0",
+			major:   6,
+			minor:   3,
+			result:  true,
+		},
+		{
+			current: "6.3",
+			major:   6,
+			minor:   3,
+			result:  false,
+		},
+		{
+			current: "6.2",
+			major:   6,
+			minor:   3,
+			result:  true,
+		},
+		{
+			current: "7.0.3.0",
+			major:   6,
+			minor:   7,
+			result:  false,
+		},
+	}
+	for _, tc := range tests {
+		result := versionLowerThan(tc.current, tc.major, tc.minor)
+		require.Equal(t, tc.result, result, fmt.Sprintf("%s < %d.%d", tc.current, tc.major, tc.minor))
+	}
+}
