@@ -11,6 +11,7 @@ import (
 	"bytes"
 	_ "embed"
 	"encoding/xml"
+	"errors"
 	"fmt"
 	"path/filepath"
 	"reflect"
@@ -33,6 +34,7 @@ type WinEventLog struct {
 	EventlogName           string          `toml:"eventlog_name"`
 	Query                  string          `toml:"xpath_query"`
 	FromBeginning          bool            `toml:"from_beginning"`
+	BatchSize              uint32          `toml:"event_batch_size"`
 	ProcessUserData        bool            `toml:"process_userdata"`
 	ProcessEventData       bool            `toml:"process_eventdata"`
 	Separator              string          `toml:"separator"`
@@ -56,11 +58,20 @@ func (*WinEventLog) SampleConfig() string {
 }
 
 func (w *WinEventLog) Init() error {
+	// Set default for batch-size
+	if w.BatchSize < 1 {
+		w.BatchSize = 5
+	}
+
 	w.subscriptionFlag = EvtSubscribeToFutureEvents
 	if w.FromBeginning {
 		w.subscriptionFlag = EvtSubscribeStartAtOldestRecord
 	}
 
+	if w.Query == "" {
+		w.Query = "*"
+	}
+
 	bookmark, err := _EvtCreateBookmark(nil)
 	if err != nil {
 		return err
@@ -82,13 +93,14 @@ func (w *WinEventLog) Start(_ telegraf.Accumulator) error {
 }
 
 func (w *WinEventLog) Stop() {
+	//nolint:errcheck // ending the subscription, error can be ignored
 	_ = _EvtClose(w.subscription)
 }
 
 func (w *WinEventLog) GetState() interface{} {
 	bookmarkXML, err := w.renderBookmark(w.bookmark)
 	if err != nil {
-		w.Log.Errorf("State-persistence failed, cannot render bookmark: %w", err)
+		w.Log.Errorf("State-persistence failed, cannot render bookmark: %v", err)
 		return ""
 	}
 	return bookmarkXML
@@ -102,7 +114,7 @@ func (w *WinEventLog) SetState(state interface{}) error {
 
 	ptr, err := syscall.UTF16PtrFromString(bookmarkXML)
 	if err != nil {
-		return fmt.Errorf("convertion to pointer failed: %w", err)
+		return fmt.Errorf("conversion to pointer failed: %w", err)
 	}
 
 	bookmark, err := _EvtCreateBookmark(ptr)
@@ -120,19 +132,20 @@ func (w *WinEventLog) Gather(acc telegraf.Accumulator) error {
 	for {
 		events, err := w.fetchEvents(w.subscription)
 		if err != nil {
-			if err == ERROR_NO_MORE_ITEMS {
+			if errors.Is(err, ERROR_NO_MORE_ITEMS) {
 				break
 			}
 			w.Log.Errorf("Error getting events: %v", err)
 			return err
 		}
 
-		for _, event := range events {
+		for i := range events {
 			// Prepare fields names usage counter
 			var fieldsUsage = map[string]int{}
 
 			tags := map[string]string{}
 			fields := map[string]interface{}{}
+			event := events[i]
 			evt := reflect.ValueOf(&event).Elem()
 			timeStamp := time.Now()
 			// Walk through all fields of Event struct to process System tags or fields
@@ -151,7 +164,7 @@ func (w *WinEventLog) Gather(acc telegraf.Accumulator) error {
 					fieldName = "ProcessID"
 					// Look up Process Name from pid
 					if should, _ := w.shouldProcessField("ProcessName"); should {
-						_, _, processName, err := GetFromSnapProcess(fieldValue)
+						processName, err := GetFromSnapProcess(fieldValue)
 						if err == nil {
 							computedValues["ProcessName"] = processName
 						}
@@ -252,7 +265,7 @@ func (w *WinEventLog) Gather(acc telegraf.Accumulator) error {
 func (w *WinEventLog) shouldExclude(field string) (should bool) {
 	for _, excludePattern := range w.ExcludeFields {
 		// Check if field name matches excluded list
-		if matched, _ := filepath.Match(excludePattern, field); matched {
+		if matched, err := filepath.Match(excludePattern, field); matched && err == nil {
 			return true
 		}
 	}
@@ -261,14 +274,14 @@ func (w *WinEventLog) shouldExclude(field string) (should bool) {
 
 func (w *WinEventLog) shouldProcessField(field string) (should bool, list string) {
 	for _, pattern := range w.EventTags {
-		if matched, _ := filepath.Match(pattern, field); matched {
+		if matched, err := filepath.Match(pattern, field); matched && err == nil {
 			// Tags are not excluded
 			return true, "tags"
 		}
 	}
 
 	for _, pattern := range w.EventFields {
-		if matched, _ := filepath.Match(pattern, field); matched {
+		if matched, err := filepath.Match(pattern, field); matched && err == nil {
 			if w.shouldExclude(field) {
 				return false, "excluded"
 			}
@@ -280,7 +293,7 @@ func (w *WinEventLog) shouldProcessField(field string) (should bool, list string
 
 func (w *WinEventLog) shouldExcludeEmptyField(field string, fieldType string, fieldValue interface{}) (should bool) {
 	for _, pattern := range w.ExcludeEmpty {
-		if matched, _ := filepath.Match(pattern, field); matched {
+		if matched, err := filepath.Match(pattern, field); matched && err == nil {
 			switch fieldType {
 			case "string":
 				return len(fieldValue.(string)) < 1
@@ -324,16 +337,11 @@ func (w *WinEventLog) evtSubscribe() (EvtHandle, error) {
 }
 
 func (w *WinEventLog) fetchEventHandles(subsHandle EvtHandle) ([]EvtHandle, error) {
-	var eventsNumber uint32
 	var evtReturned uint32
 
-	eventsNumber = 5
-
-	eventHandles := make([]EvtHandle, eventsNumber)
-
-	err := _EvtNext(subsHandle, eventsNumber, &eventHandles[0], 0, 0, &evtReturned)
-	if err != nil {
-		if err == ERROR_INVALID_OPERATION && evtReturned == 0 {
+	eventHandles := make([]EvtHandle, w.BatchSize)
+	if err := _EvtNext(subsHandle, w.BatchSize, &eventHandles[0], 0, 0, &evtReturned); err != nil {
+		if errors.Is(err, ERROR_INVALID_OPERATION) && evtReturned == 0 {
 			return nil, ERROR_NO_MORE_ITEMS
 		}
 		return nil, err
@@ -393,7 +401,7 @@ func (w *WinEventLog) renderEvent(eventHandle EvtHandle) (Event, error) {
 
 	buf := make([]byte, bufferSize)
 	event := Event{}
-	err := _EvtRender(0, eventHandle, EvtRenderEventXml, uint32(len(buf)), &buf[0], &bufferUsed, &propertyCount)
+	err := _EvtRender(0, eventHandle, EvtRenderEventXML, uint32(len(buf)), &buf[0], &bufferUsed, &propertyCount)
 	if err != nil {
 		return event, err
 	}
@@ -403,17 +411,16 @@ func (w *WinEventLog) renderEvent(eventHandle EvtHandle) (Event, error) {
 		return event, err
 	}
 
-	err = xml.Unmarshal([]byte(eventXML), &event)
+	err = xml.Unmarshal(eventXML, &event)
 	if err != nil {
-		// We can return event without most text values,
-		// that way we will not loose information
+		//nolint:nilerr // We can return event without most text values, that way we will not lose information
 		// This can happen when processing Forwarded Events
 		return event, nil
 	}
 
 	// Do resolve local messages the usual way, while using built-in information for events forwarded by WEC.
 	// This is a safety measure as the underlying Windows-internal EvtFormatMessage might segfault in cases
-	// where the publisher (i.e. the remote machine which forwared the event) is unavailable e.g. due to
+	// where the publisher (i.e. the remote machine which forwarded the event) is unavailable e.g. due to
 	// a reboot. See https://github.com/influxdata/telegraf/issues/12328 for the full story.
 	if event.RenderingInfo == nil {
 		return w.renderLocalMessage(event, eventHandle)
@@ -428,7 +435,7 @@ func (w *WinEventLog) renderLocalMessage(event Event, eventHandle EvtHandle) (Ev
 	if err != nil {
 		return event, nil
 	}
-	defer _EvtClose(publisherHandle)
+	defer _EvtClose(publisherHandle) //nolint:errcheck // Ignore error returned during Close
 
 	// Populating text values
 	keywords, err := formatEventString(EvtFormatMessageKeyword, eventHandle, publisherHandle)
@@ -493,7 +500,7 @@ func formatEventString(
 	var bufferUsed uint32
 	err := _EvtFormatMessage(publisherHandle, eventHandle, 0, 0, 0, messageFlag,
 		0, nil, &bufferUsed)
-	if err != nil && err != ERROR_INSUFFICIENT_BUFFER {
+	if err != nil && !errors.Is(err, ERROR_INSUFFICIENT_BUFFER) {
 		return "", err
 	}
 
