@@ -44,7 +44,7 @@ func TestGatherRemoteIntegration(t *testing.T) {
 
 	defer os.Remove(tmpfile.Name())
 
-	_, err = tmpfile.Write([]byte(pki.ReadServerCert()))
+	_, err = tmpfile.WriteString(pki.ReadServerCert())
 	require.NoError(t, err)
 
 	tests := []struct {
@@ -78,7 +78,7 @@ func TestGatherRemoteIntegration(t *testing.T) {
 		t.Run(test.name, func(t *testing.T) {
 			if test.unset {
 				cfg.Certificates = nil
-				cfg.GetCertificate = func(i *tls.ClientHelloInfo) (*tls.Certificate, error) {
+				cfg.GetCertificate = func(*tls.ClientHelloInfo) (*tls.Certificate, error) {
 					return nil, nil
 				}
 			}
@@ -160,7 +160,7 @@ func TestGatherLocal(t *testing.T) {
 			f, err := os.CreateTemp("", "x509_cert")
 			require.NoError(t, err)
 
-			_, err = f.Write([]byte(test.content))
+			_, err = f.WriteString(test.content)
 			require.NoError(t, err)
 
 			if runtime.GOOS != "windows" {
@@ -193,7 +193,7 @@ func TestTags(t *testing.T) {
 	f, err := os.CreateTemp("", "x509_cert")
 	require.NoError(t, err)
 
-	_, err = f.Write([]byte(cert))
+	_, err = f.WriteString(cert)
 	require.NoError(t, err)
 
 	require.NoError(t, f.Close())
@@ -242,7 +242,7 @@ func TestGatherExcludeRootCerts(t *testing.T) {
 	f, err := os.CreateTemp("", "x509_cert")
 	require.NoError(t, err)
 
-	_, err = f.Write([]byte(cert))
+	_, err = f.WriteString(cert)
 	require.NoError(t, err)
 
 	require.NoError(t, f.Close())
@@ -279,7 +279,7 @@ func TestGatherChain(t *testing.T) {
 			f, err := os.CreateTemp("", "x509_cert")
 			require.NoError(t, err)
 
-			_, err = f.Write([]byte(test.content))
+			_, err = f.WriteString(test.content)
 			require.NoError(t, err)
 
 			require.NoError(t, f.Close())
@@ -318,7 +318,8 @@ func TestGatherUDPCertIntegration(t *testing.T) {
 	defer listener.Close()
 
 	go func() {
-		_, _ = listener.Accept()
+		_, err := listener.Accept()
+		require.NoError(t, err)
 	}()
 
 	m := &X509Cert{
@@ -336,7 +337,7 @@ func TestGatherUDPCertIntegration(t *testing.T) {
 }
 
 func TestGatherTCPCert(t *testing.T) {
-	ts := httptest.NewTLSServer(http.HandlerFunc(func(w http.ResponseWriter, r *http.Request) {
+	ts := httptest.NewTLSServer(http.HandlerFunc(func(w http.ResponseWriter, _ *http.Request) {
 		w.WriteHeader(http.StatusOK)
 	}))
 	defer ts.Close()
@@ -451,8 +452,7 @@ func TestServerName(t *testing.T) {
 		{name: "errors", fromCfg: "otherex.com", fromTLS: "example.com", url: "https://other.example.com", err: true},
 	}
 
-	for _, elt := range tests {
-		test := elt
+	for _, test := range tests {
 		t.Run(test.name, func(t *testing.T) {
 			sc := &X509Cert{
 				Sources:      []string{test.url},
