@@ -4,12 +4,12 @@ package cloudwatch_logs
 import (
 	"context"
 	_ "embed"
+	"errors"
 	"fmt"
 	"sort"
 	"strings"
 	"time"
 
-	"github.com/aws/aws-sdk-go-v2/aws"
 	"github.com/aws/aws-sdk-go-v2/config"
 	"github.com/aws/aws-sdk-go-v2/service/cloudwatchlogs"
 	"github.com/aws/aws-sdk-go-v2/service/cloudwatchlogs/types"
@@ -100,28 +100,28 @@ func (*CloudWatchLogs) SampleConfig() string {
 // Init initialize plugin with checking configuration parameters
 func (c *CloudWatchLogs) Init() error {
 	if c.LogGroup == "" {
-		return fmt.Errorf("log group is not set")
+		return errors.New("log group is not set")
 	}
 
 	if c.LogStream == "" {
-		return fmt.Errorf("log stream is not set")
+		return errors.New("log stream is not set")
 	}
 
 	if c.LDMetricName == "" {
-		return fmt.Errorf("log data metrics name is not set")
+		return errors.New("log data metrics name is not set")
 	}
 
 	if c.LDSource == "" {
-		return fmt.Errorf("log data source is not set")
+		return errors.New("log data source is not set")
 	}
 	lsSplitArray := strings.Split(c.LDSource, ":")
 	if len(lsSplitArray) != 2 {
-		return fmt.Errorf("log data source is not properly formatted, ':' is missed.\n" +
+		return errors.New("log data source is not properly formatted, ':' is missed.\n" +
 			"Should be 'tag:<tag_mame>' or 'field:<field_name>'")
 	}
 
 	if lsSplitArray[0] != "tag" && lsSplitArray[0] != "field" {
-		return fmt.Errorf("log data source is not properly formatted.\n" +
+		return errors.New("log data source is not properly formatted.\n" +
 			"Should be 'tag:<tag_mame>' or 'field:<field_name>'")
 	}
 
@@ -153,23 +153,16 @@ func (c *CloudWatchLogs) Connect() error {
 	if err != nil {
 		return err
 	}
-	if c.CredentialConfig.EndpointURL != "" && c.CredentialConfig.Region != "" {
-		customResolver := aws.EndpointResolverWithOptionsFunc(func(service, region string, options ...interface{}) (aws.Endpoint, error) {
-			return aws.Endpoint{
-				PartitionID:   "aws",
-				URL:           c.CredentialConfig.EndpointURL,
-				SigningRegion: c.CredentialConfig.Region,
-			}, nil
-		})
-
-		cfg, err = config.LoadDefaultConfig(context.TODO(), config.WithEndpointResolverWithOptions(customResolver))
-		if err != nil {
-			return err
-		}
-	}
-
 	cfg.Credentials = awsCreds.Credentials
-	c.svc = cloudwatchlogs.NewFromConfig(cfg)
+
+	if c.CredentialConfig.EndpointURL != "" && c.CredentialConfig.Region != "" {
+		c.svc = cloudwatchlogs.NewFromConfig(cfg, func(o *cloudwatchlogs.Options) {
+			o.Region = c.CredentialConfig.Region
+			o.BaseEndpoint = &c.CredentialConfig.EndpointURL
+		})
+	} else {
+		c.svc = cloudwatchlogs.NewFromConfig(cfg)
+	}
 
 	//Find log group with name 'c.LogGroup'
 	if c.lg == nil { //In case connection is not retried, first time
