@@ -79,10 +79,12 @@ func TestGraphiteReconnect(t *testing.T) {
 
 	go func() {
 		defer wg.Done()
-		conn, _ := (tcpServer).Accept()
+		conn, err := (tcpServer).Accept()
+		require.NoError(t, err)
 		reader := bufio.NewReader(conn)
 		tp := textproto.NewReader(reader)
-		data1, _ := tp.ReadLine()
+		data1, err := tp.ReadLine()
+		require.NoError(t, err)
 		require.Equal(t, "192_168_0_1.|us-west-2|.mymeasurement.myfield 0.123 1289430000", data1)
 		require.NoError(t, conn.Close())
 		require.NoError(t, tcpServer.Close())
@@ -163,10 +165,12 @@ func TestGraphiteStrictRegex(t *testing.T) {
 	require.NoError(t, err)
 	go func() {
 		defer wg.Done()
-		conn, _ := (tcpServer).Accept()
+		conn, err := (tcpServer).Accept()
+		require.NoError(t, err)
 		reader := bufio.NewReader(conn)
 		tp := textproto.NewReader(reader)
-		data1, _ := tp.ReadLine()
+		data1, err := tp.ReadLine()
+		require.NoError(t, err)
 		require.Equal(t, "192_168_0_1.|us-west-2|.mymeasurement.myfield 0.123 1289430000", data1)
 		require.NoError(t, conn.Close())
 		require.NoError(t, tcpServer.Close())
@@ -696,10 +700,12 @@ func TCPServer1(t *testing.T, wg *sync.WaitGroup) {
 	require.NoError(t, err)
 	go func() {
 		defer wg.Done()
-		conn, _ := (tcpServer).Accept()
+		conn, err := (tcpServer).Accept()
+		require.NoError(t, err)
 		reader := bufio.NewReader(conn)
 		tp := textproto.NewReader(reader)
-		data1, _ := tp.ReadLine()
+		data1, err := tp.ReadLine()
+		require.NoError(t, err)
 		require.Equal(t, "my.prefix.192_168_0_1.mymeasurement.myfield 3.14 1289430000", data1)
 		require.NoError(t, conn.Close())
 		require.NoError(t, tcpServer.Close())
@@ -711,12 +717,15 @@ func TCPServer2(t *testing.T, wg *sync.WaitGroup) {
 	require.NoError(t, err)
 	go func() {
 		defer wg.Done()
-		conn2, _ := (tcpServer).Accept()
+		conn2, err := (tcpServer).Accept()
+		require.NoError(t, err)
 		reader := bufio.NewReader(conn2)
 		tp := textproto.NewReader(reader)
-		data2, _ := tp.ReadLine()
+		data2, err := tp.ReadLine()
+		require.NoError(t, err)
 		require.Equal(t, "my.prefix.192_168_0_1.mymeasurement 3.14 1289430000", data2)
-		data3, _ := tp.ReadLine()
+		data3, err := tp.ReadLine()
+		require.NoError(t, err)
 		require.Equal(t, "my.prefix.192_168_0_1.my_measurement 3.14 1289430000", data3)
 		require.NoError(t, conn2.Close())
 		require.NoError(t, tcpServer.Close())
@@ -728,10 +737,12 @@ func TCPServer1WithMultipleTemplates(t *testing.T, wg *sync.WaitGroup) {
 	require.NoError(t, err)
 	go func() {
 		defer wg.Done()
-		conn, _ := (tcpServer).Accept()
+		conn, err := (tcpServer).Accept()
+		require.NoError(t, err)
 		reader := bufio.NewReader(conn)
 		tp := textproto.NewReader(reader)
-		data1, _ := tp.ReadLine()
+		data1, err := tp.ReadLine()
+		require.NoError(t, err)
 		require.Equal(t, "my.prefix.mymeasurement.valuetag.192_168_0_1.myfield 3.14 1289430000", data1)
 		require.NoError(t, conn.Close())
 		require.NoError(t, tcpServer.Close())
@@ -743,12 +754,15 @@ func TCPServer2WithMultipleTemplates(t *testing.T, wg *sync.WaitGroup) {
 	require.NoError(t, err)
 	go func() {
 		defer wg.Done()
-		conn2, _ := (tcpServer).Accept()
+		conn2, err := (tcpServer).Accept()
+		require.NoError(t, err)
 		reader := bufio.NewReader(conn2)
 		tp := textproto.NewReader(reader)
-		data2, _ := tp.ReadLine()
+		data2, err := tp.ReadLine()
+		require.NoError(t, err)
 		require.Equal(t, "my.prefix.mymeasurement.valuetag.192_168_0_1 3.14 1289430000", data2)
-		data3, _ := tp.ReadLine()
+		data3, err := tp.ReadLine()
+		require.NoError(t, err)
 		require.Equal(t, "my.prefix.192_168_0_1.my_measurement.valuetag 3.14 1289430000", data3)
 		require.NoError(t, conn2.Close())
 		require.NoError(t, tcpServer.Close())
@@ -760,10 +774,12 @@ func TCPServer1WithTags(t *testing.T, wg *sync.WaitGroup) {
 	require.NoError(t, err)
 	go func() {
 		defer wg.Done()
-		conn, _ := (tcpServer).Accept()
+		conn, err := (tcpServer).Accept()
+		require.NoError(t, err)
 		reader := bufio.NewReader(conn)
 		tp := textproto.NewReader(reader)
-		data1, _ := tp.ReadLine()
+		data1, err := tp.ReadLine()
+		require.NoError(t, err)
 		require.Equal(t, "my.prefix.mymeasurement.myfield;host=192.168.0.1 3.14 1289430000", data1)
 		require.NoError(t, conn.Close())
 		require.NoError(t, tcpServer.Close())
@@ -775,12 +791,15 @@ func TCPServer2WithTags(t *testing.T, wg *sync.WaitGroup) {
 	require.NoError(t, err)
 	go func() {
 		defer wg.Done()
-		conn2, _ := (tcpServer).Accept()
+		conn2, err := (tcpServer).Accept()
+		require.NoError(t, err)
 		reader := bufio.NewReader(conn2)
 		tp := textproto.NewReader(reader)
-		data2, _ := tp.ReadLine()
+		data2, err := tp.ReadLine()
+		require.NoError(t, err)
 		require.Equal(t, "my.prefix.mymeasurement;host=192.168.0.1 3.14 1289430000", data2)
-		data3, _ := tp.ReadLine()
+		data3, err := tp.ReadLine()
+		require.NoError(t, err)
 		require.Equal(t, "my.prefix.my_measurement;host=192.168.0.1 3.14 1289430000", data3)
 		require.NoError(t, conn2.Close())
 		require.NoError(t, tcpServer.Close())
@@ -792,10 +811,12 @@ func TCPServer1WithTagsSeparatorUnderscore(t *testing.T, wg *sync.WaitGroup) {
 	require.NoError(t, err)
 	go func() {
 		defer wg.Done()
-		conn, _ := (tcpServer).Accept()
+		conn, err := (tcpServer).Accept()
+		require.NoError(t, err)
 		reader := bufio.NewReader(conn)
 		tp := textproto.NewReader(reader)
-		data1, _ := tp.ReadLine()
+		data1, err := tp.ReadLine()
+		require.NoError(t, err)
 		require.Equal(t, "my_prefix_mymeasurement_myfield;host=192.168.0.1 3.14 1289430000", data1)
 		require.NoError(t, conn.Close())
 		require.NoError(t, tcpServer.Close())
@@ -807,12 +828,15 @@ func TCPServer2WithTagsSeparatorUnderscore(t *testing.T, wg *sync.WaitGroup) {
 	require.NoError(t, err)
 	go func() {
 		defer wg.Done()
-		conn2, _ := (tcpServer).Accept()
+		conn2, err := (tcpServer).Accept()
+		require.NoError(t, err)
 		reader := bufio.NewReader(conn2)
 		tp := textproto.NewReader(reader)
-		data2, _ := tp.ReadLine()
+		data2, err := tp.ReadLine()
+		require.NoError(t, err)
 		require.Equal(t, "my_prefix_mymeasurement;host=192.168.0.1 3.14 1289430000", data2)
-		data3, _ := tp.ReadLine()
+		data3, err := tp.ReadLine()
+		require.NoError(t, err)
 		require.Equal(t, "my_prefix_my_measurement;host=192.168.0.1 3.14 1289430000", data3)
 		require.NoError(t, conn2.Close())
 		require.NoError(t, tcpServer.Close())
