@@ -6,6 +6,7 @@ import (
 	"errors"
 	"fmt"
 	"math"
+	"regexp"
 	"strconv"
 	"strings"
 	"time"
@@ -21,18 +22,26 @@ import (
 //go:embed sample.conf
 var sampleConfig string
 
+// matches any word that has a non valid backtick
+// `word`  							 <- doesn't match
+// “word , `wo`rd` , `word , word`   <- match
+var forbiddenBacktick = regexp.MustCompile("^[^\x60].*?[\x60]+.*?[^\x60]$|^[\x60].*[\x60]+.*[\x60]$|^[\x60]+.*[^\x60]$|^[^\x60].*[\x60]+$")
+var allowedBacktick = regexp.MustCompile("^[\x60].*[\x60]$")
+
 type IoTDB struct {
 	Host            string          `toml:"host"`
 	Port            string          `toml:"port"`
-	User            string          `toml:"user"`
-	Password        string          `toml:"password"`
+	User            config.Secret   `toml:"user"`
+	Password        config.Secret   `toml:"password"`
 	Timeout         config.Duration `toml:"timeout"`
 	ConvertUint64To string          `toml:"uint64_conversion"`
 	TimeStampUnit   string          `toml:"timestamp_precision"`
 	TreatTagsAs     string          `toml:"convert_tags_to"`
+	SanitizeTags    string          `toml:"sanitize_tag"`
 	Log             telegraf.Logger `toml:"-"`
 
-	session *client.Session
+	sanityRegex []*regexp.Regexp
+	session     *client.Session
 }
 
 type recordsWithTags struct {
@@ -64,17 +73,56 @@ func (s *IoTDB) Init() error {
 	if !choice.Contains(s.TreatTagsAs, []string{"fields", "device_id"}) {
 		return fmt.Errorf("unknown 'convert_tags_to' method %q", s.TreatTagsAs)
 	}
+
+	if s.User.Empty() {
+		s.User.Destroy()
+		s.User = config.NewSecret([]byte("root"))
+	}
+	if s.Password.Empty() {
+		s.Password.Destroy()
+		s.Password = config.NewSecret([]byte("root"))
+	}
+
+	switch s.SanitizeTags {
+	case "0.13":
+		matchUnsupportedCharacter := regexp.MustCompile("[^0-9a-zA-Z_:@#${}\x60]")
+
+		regex := []*regexp.Regexp{matchUnsupportedCharacter}
+		s.sanityRegex = append(s.sanityRegex, regex...)
+
+	// from version 1.x.x IoTDB changed the allowed keys in nodes
+	case "1.0", "1.1", "1.2", "1.3":
+		matchUnsupportedCharacter := regexp.MustCompile("[^0-9a-zA-Z_\x60]")
+		matchNumericString := regexp.MustCompile(`^\d+$`)
+
+		regex := []*regexp.Regexp{matchUnsupportedCharacter, matchNumericString}
+		s.sanityRegex = append(s.sanityRegex, regex...)
+	}
+
 	s.Log.Info("Initialization completed.")
 	return nil
 }
 
 func (s *IoTDB) Connect() error {
+	username, err := s.User.Get()
+	if err != nil {
+		return fmt.Errorf("getting username failed: %w", err)
+	}
+	password, err := s.Password.Get()
+	if err != nil {
+		username.Destroy()
+		return fmt.Errorf("getting password failed: %w", err)
+	}
+	defer password.Destroy()
 	sessionConf := &client.Config{
 		Host:     s.Host,
 		Port:     s.Port,
-		UserName: s.User,
-		Password: s.Password,
+		UserName: username.String(),
+		Password: password.String(),
 	}
+	username.Destroy()
+	password.Destroy()
+
 	var ss = client.NewSession(sessionConf)
 	s.session = &ss
 	timeoutInMs := int(time.Duration(s.Timeout).Milliseconds())
@@ -127,7 +175,7 @@ func (s *IoTDB) getDataTypeAndValue(value interface{}) (client.TSDataType, inter
 		case "text":
 			return client.TEXT, strconv.FormatUint(v, 10)
 		default:
-			return client.UNKNOW, int64(0)
+			return client.UNKNOWN, int64(0)
 		}
 	case float64:
 		return client.DOUBLE, v
@@ -136,7 +184,7 @@ func (s *IoTDB) getDataTypeAndValue(value interface{}) (client.TSDataType, inter
 	case bool:
 		return client.BOOLEAN, v
 	default:
-		return client.UNKNOW, int64(0)
+		return client.UNKNOWN, int64(0)
 	}
 }
 
@@ -175,7 +223,7 @@ func (s *IoTDB) convertMetricsToRecordsWithTags(metrics []telegraf.Metric) (*rec
 		var dataTypes []client.TSDataType
 		for _, field := range metric.FieldList() {
 			datatype, value := s.getDataTypeAndValue(field.Value)
-			if datatype == client.UNKNOW {
+			if datatype == client.UNKNOWN {
 				return nil, fmt.Errorf("datatype of %q is unknown, values: %v", field.Key, field.Value)
 			}
 			keys = append(keys, field.Key)
@@ -206,6 +254,28 @@ func (s *IoTDB) convertMetricsToRecordsWithTags(metrics []telegraf.Metric) (*rec
 	return rwt, nil
 }
 
+// checks is the tag contains any IoTDB invalid character
+func (s *IoTDB) validateTag(tag string) (string, error) {
+	// IoTDB uses "root" as a keyword and can be called only at the start of the path
+	if tag == "root" {
+		return "", errors.New("cannot use 'root' as tag")
+	} else if forbiddenBacktick.MatchString(tag) { // returns an error if the backsticks are used in an inappropriate way
+		return "", errors.New("cannot use ` in tag names")
+	} else if allowedBacktick.MatchString(tag) { // if the tag in already enclosed in tags returns the tag
+		return tag, nil
+	}
+
+	// loops through all the regex patterns and if one
+	// pattern matches returns the tag between `
+	for _, regex := range s.sanityRegex {
+		if regex.MatchString(tag) {
+			return "`" + tag + "`", nil
+		}
+	}
+
+	return tag, nil
+}
+
 // modify recordsWithTags according to 'TreatTagsAs' Configuration
 func (s *IoTDB) modifyRecordsWithTags(rwt *recordsWithTags) error {
 	switch s.TreatTagsAs {
@@ -214,7 +284,7 @@ func (s *IoTDB) modifyRecordsWithTags(rwt *recordsWithTags) error {
 		for index, tags := range rwt.TagsList { // for each record
 			for _, tag := range tags { // for each tag of this record, append it's Key:Value to measurements
 				datatype, value := s.getDataTypeAndValue(tag.Value)
-				if datatype == client.UNKNOW {
+				if datatype == client.UNKNOWN {
 					return fmt.Errorf("datatype of %q is unknown, values: %v", tag.Key, value)
 				}
 				rwt.MeasurementsList[index] = append(rwt.MeasurementsList[index], tag.Key)
@@ -228,7 +298,11 @@ func (s *IoTDB) modifyRecordsWithTags(rwt *recordsWithTags) error {
 		for index, tags := range rwt.TagsList { // for each record
 			topic := []string{rwt.DeviceIDList[index]}
 			for _, tag := range tags { // for each tag, append it's Value
-				topic = append(topic, tag.Value)
+				tagValue, err := s.validateTag(tag.Value) // validates tag
+				if err != nil {
+					return err
+				}
+				topic = append(topic, tagValue)
 			}
 			rwt.DeviceIDList[index] = strings.Join(topic, ".")
 		}
@@ -265,8 +339,6 @@ func newIoTDB() *IoTDB {
 	return &IoTDB{
 		Host:            "localhost",
 		Port:            "6667",
-		User:            "root",
-		Password:        "root",
 		Timeout:         config.Duration(time.Second * 5),
 		ConvertUint64To: "int64_clip",
 		TimeStampUnit:   "nanosecond",
