@@ -5,6 +5,7 @@ import (
 	"context"
 	ntls "crypto/tls"
 	_ "embed"
+	"sort"
 	"time"
 
 	"github.com/influxdata/influxdb-observability/common"
@@ -94,7 +95,7 @@ func (o *OpenTelemetry) Connect() error {
 		grpcTLSDialOption = grpc.WithTransportCredentials(insecure.NewCredentials())
 	}
 
-	grpcClientConn, err := grpc.Dial(o.ServiceAddress, grpcTLSDialOption, grpc.WithUserAgent(userAgent))
+	grpcClientConn, err := grpc.NewClient(o.ServiceAddress, grpcTLSDialOption, grpc.WithUserAgent(userAgent))
 	if err != nil {
 		return err
 	}
@@ -121,7 +122,34 @@ func (o *OpenTelemetry) Close() error {
 	return nil
 }
 
+// Split metrics up by timestamp and send to Google Cloud Stackdriver
 func (o *OpenTelemetry) Write(metrics []telegraf.Metric) error {
+	metricBatch := make(map[int64][]telegraf.Metric)
+	timestamps := []int64{}
+	for _, metric := range metrics {
+		timestamp := metric.Time().UnixNano()
+		if existingSlice, ok := metricBatch[timestamp]; ok {
+			metricBatch[timestamp] = append(existingSlice, metric)
+		} else {
+			metricBatch[timestamp] = []telegraf.Metric{metric}
+			timestamps = append(timestamps, timestamp)
+		}
+	}
+
+	// sort the timestamps we collected
+	sort.Slice(timestamps, func(i, j int) bool { return timestamps[i] < timestamps[j] })
+
+	o.Log.Debugf("Received %d metrics and split into %d groups by timestamp", len(metrics), len(metricBatch))
+	for _, timestamp := range timestamps {
+		if err := o.sendBatch(metricBatch[timestamp]); err != nil {
+			return err
+		}
+	}
+
+	return nil
+}
+
+func (o *OpenTelemetry) sendBatch(metrics []telegraf.Metric) error {
 	batch := o.metricsConverter.NewBatch()
 	for _, metric := range metrics {
 		var vType common.InfluxMetricValueType
@@ -137,12 +165,12 @@ func (o *OpenTelemetry) Write(metrics []telegraf.Metric) error {
 		case telegraf.Summary:
 			vType = common.InfluxMetricValueTypeSummary
 		default:
-			o.Log.Warnf("unrecognized metric type %Q", metric.Type())
+			o.Log.Warnf("Unrecognized metric type %v", metric.Type())
 			continue
 		}
 		err := batch.AddPoint(metric.Name(), metric.Tags(), metric.Fields(), metric.Time(), vType)
 		if err != nil {
-			o.Log.Warnf("failed to add point: %s", err)
+			o.Log.Warnf("Failed to add point: %v", err)
 			continue
 		}
 	}
