@@ -17,7 +17,10 @@ import (
 	"github.com/testcontainers/testcontainers-go/wait"
 
 	"github.com/influxdata/telegraf"
+	"github.com/influxdata/telegraf/config"
+	"github.com/influxdata/telegraf/internal"
 	"github.com/influxdata/telegraf/metric"
+	"github.com/influxdata/telegraf/models"
 	"github.com/influxdata/telegraf/plugins/outputs/postgresql/utils"
 	"github.com/influxdata/telegraf/testutil"
 )
@@ -48,6 +51,22 @@ func NewLogAccumulator(tb testing.TB) *LogAccumulator {
 	}
 }
 
+func (la *LogAccumulator) Level() telegraf.LogLevel {
+	switch la.emitLevel {
+	case pgx.LogLevelInfo:
+		return telegraf.Info
+	case pgx.LogLevelWarn:
+		return telegraf.Warn
+	case pgx.LogLevelError:
+		return telegraf.Error
+	case pgx.LogLevelNone:
+		return telegraf.None
+	}
+	return telegraf.Debug
+}
+
+func (*LogAccumulator) RegisterErrorCallback(func()) {}
+
 func (la *LogAccumulator) append(level pgx.LogLevel, format string, args []interface{}) {
 	la.tb.Helper()
 
@@ -231,7 +250,7 @@ func newPostgresqlTest(tb testing.TB) *PostgresqlTest {
 	require.NoError(tb, err, "failed to start container")
 
 	p := newPostgresql()
-	p.Connection = fmt.Sprintf(
+	connection := fmt.Sprintf(
 		"host=%s port=%s user=%s password=%s dbname=%s",
 		container.Address,
 		container.Ports[servicePort],
@@ -239,6 +258,7 @@ func newPostgresqlTest(tb testing.TB) *PostgresqlTest {
 		password,
 		testDatabaseName,
 	)
+	p.Connection = config.NewSecret([]byte(connection))
 	logger := NewLogAccumulator(tb)
 	p.Logger = logger
 	p.LogLevel = "debug"
@@ -260,12 +280,90 @@ func TestPostgresqlConnectIntegration(t *testing.T) {
 	require.EqualValues(t, 1, p.db.Stat().MaxConns())
 
 	p = newPostgresqlTest(t)
-	p.Connection += " pool_max_conns=2"
-	_ = p.Init()
+	connection, err := p.Connection.Get()
+	require.NoError(t, err)
+	p.Connection = config.NewSecret([]byte(connection.String() + " pool_max_conns=2"))
+	connection.Destroy()
+
+	require.NoError(t, p.Init())
 	require.NoError(t, p.Connect())
 	require.EqualValues(t, 2, p.db.Stat().MaxConns())
 }
 
+func TestConnectionIssueAtStartup(t *testing.T) {
+	// Test case for https://github.com/influxdata/telegraf/issues/14365
+	if testing.Short() {
+		t.Skip("Skipping integration test in short mode")
+	}
+
+	servicePort := "5432"
+	username := "postgres"
+	password := "postgres"
+	testDatabaseName := "telegraf_test"
+
+	container := testutil.Container{
+		Image:        "postgres:alpine",
+		ExposedPorts: []string{servicePort},
+		Env: map[string]string{
+			"POSTGRES_USER":     username,
+			"POSTGRES_PASSWORD": password,
+			"POSTGRES_DB":       "telegraf_test",
+		},
+		WaitingFor: wait.ForAll(
+			// the database comes up twice, once right away, then again a second
+			// time after the docker entrypoint starts configuration
+			wait.ForLog("database system is ready to accept connections").WithOccurrence(2),
+			wait.ForListeningPort(nat.Port(servicePort)),
+		),
+	}
+	require.NoError(t, container.Start(), "failed to start container")
+	defer container.Terminate()
+
+	// Pause the container for connectivity issues
+	require.NoError(t, container.Pause())
+
+	// Create a model to be able to use the startup retry strategy
+	dsn := config.NewSecret([]byte(fmt.Sprintf(
+		"host=%s port=%s user=%s password=%s dbname=%s  connect_timeout=1",
+		container.Address,
+		container.Ports[servicePort],
+		username,
+		password,
+		testDatabaseName,
+	)))
+	defer dsn.Destroy()
+	plugin := newPostgresql()
+	plugin.Connection = dsn
+	plugin.Logger = testutil.Logger{}
+	plugin.LogLevel = "debug"
+	model := models.NewRunningOutput(
+		plugin,
+		&models.OutputConfig{
+			Name:                 "postgres",
+			StartupErrorBehavior: "retry",
+		},
+		1000, 1000,
+	)
+	require.NoError(t, model.Init())
+
+	// The connect call should succeed even though the table creation was not
+	// successful due to the "retry" strategy
+	require.NoError(t, model.Connect())
+
+	// Writing the metrics in this state should fail because we are not fully
+	// started up
+	metrics := testutil.MockMetrics()
+	for _, m := range metrics {
+		model.AddMetric(m)
+	}
+	require.ErrorIs(t, model.WriteBatch(), internal.ErrNotConnected)
+
+	// Unpause the container, now writes should succeed
+	require.NoError(t, container.Resume())
+	require.NoError(t, model.WriteBatch())
+	model.Close()
+}
+
 func newMetric(
 	t *testing.T,
 	suffix string,
@@ -375,7 +473,7 @@ func TestWriteIntegration_concurrent(t *testing.T) {
 
 	p.Logger.WaitForCopy(t.Name()+"_b", false)
 	// release the lock on table _a
-	_ = tx.Rollback(ctx)
+	require.NoError(t, tx.Rollback(ctx))
 	p.Logger.WaitForCopy(t.Name()+"_a", false)
 
 	dumpA := dbTableDump(t, p.db, "_a")
@@ -759,7 +857,7 @@ func TestWriteIntegration_UnsignedIntegers(t *testing.T) {
 
 	p := newPostgresqlTest(t)
 	p.Uint64Type = PgUint8
-	_ = p.Init()
+	require.NoError(t, p.Init())
 	if err := p.Connect(); err != nil {
 		if strings.Contains(err.Error(), "retrieving OID for uint8 data type") {
 			t.Skipf("pguint extension is not installed")
