@@ -89,18 +89,18 @@ func (tm *TableManager) MatchSource(ctx context.Context, db dbh, rowSource *Tabl
 			if isTempError(err) {
 				return err
 			}
-			tm.Postgresql.Logger.Errorf("permanent error updating schema for %s: %w", tagTable.name, err)
+			tm.Postgresql.Logger.Errorf("Permanent error updating schema for %s: %v", tagTable.name, err)
 		}
 
 		if len(missingCols) > 0 {
 			colDefs := make([]string, 0, len(missingCols))
 			for _, col := range missingCols {
 				if err := rowSource.DropColumn(col); err != nil {
-					return fmt.Errorf("metric/table mismatch: Unable to omit field/column from \"%s\": %w", tagTable.name, err)
+					return fmt.Errorf("metric/table mismatch: Unable to omit field/column from %q: %w", tagTable.name, err)
 				}
 				colDefs = append(colDefs, col.Name+" "+col.Type)
 			}
-			tm.Logger.Errorf("table '%s' is missing tag columns (dropping metrics): %s",
+			tm.Logger.Errorf("Table %q is missing tag columns (dropping metrics): %s",
 				tagTable.name,
 				strings.Join(colDefs, ", "))
 		}
@@ -120,18 +120,18 @@ func (tm *TableManager) MatchSource(ctx context.Context, db dbh, rowSource *Tabl
 		if isTempError(err) {
 			return err
 		}
-		tm.Postgresql.Logger.Errorf("permanent error updating schema for %s: %w", metricTable.name, err)
+		tm.Postgresql.Logger.Errorf("Permanent error updating schema for %s: %v", metricTable.name, err)
 	}
 
 	if len(missingCols) > 0 {
 		colDefs := make([]string, 0, len(missingCols))
 		for _, col := range missingCols {
 			if err := rowSource.DropColumn(col); err != nil {
-				return fmt.Errorf("metric/table mismatch: Unable to omit field/column from \"%s\": %w", metricTable.name, err)
+				return fmt.Errorf("metric/table mismatch: Unable to omit field/column from %q: %w", metricTable.name, err)
 			}
 			colDefs = append(colDefs, col.Name+" "+col.Type)
 		}
-		tm.Logger.Errorf("table '%s' is missing columns (omitting fields): %s",
+		tm.Logger.Errorf("Table %q is missing columns (omitting fields): %s",
 			metricTable.name,
 			strings.Join(colDefs, ", "))
 	}
@@ -187,9 +187,9 @@ func (tm *TableManager) EnsureStructure(
 		}
 
 		if col.Role == utils.TagColType {
-			return nil, fmt.Errorf("column name too long: \"%s\"", col.Name)
+			return nil, fmt.Errorf("column name too long: %q", col.Name)
 		}
-		tm.Postgresql.Logger.Errorf("column name too long: \"%s\"", col.Name)
+		tm.Postgresql.Logger.Errorf("Column name too long: %q", col.Name)
 		invalidColumns = append(invalidColumns, col)
 	}
 
@@ -318,16 +318,17 @@ func (tm *TableManager) getColumns(ctx context.Context, db dbh, name string) (ma
 
 		role := utils.FieldColType
 		switch colName {
-		case timeColumnName:
+		case tm.timeColumn.Name:
 			role = utils.TimeColType
-		case tagIDColumnName:
+		case tm.tagIDColumn.Name:
 			role = utils.TagsIDColType
-		case tagsJSONColumnName:
+		case tm.tagsJSONColumn.Name:
 			role = utils.TagColType
-		case fieldsJSONColumnName:
+		case tm.fieldsJSONColumn.Name:
 			role = utils.FieldColType
 		default:
-			// We don't want to monopolize the column comment (preventing user from storing other information there), so just look at the first word
+			// We don't want to monopolize the column comment (preventing user from storing other information there),
+			// so just look at the first word
 			if desc != nil {
 				descWords := strings.Split(*desc, " ")
 				if descWords[0] == "tag" {
@@ -370,7 +371,7 @@ func (tm *TableManager) update(ctx context.Context,
 			return err
 		}
 		if _, err := tx.Exec(ctx, string(sql)); err != nil {
-			return fmt.Errorf("executing `%s`: %w", sql, err)
+			return fmt.Errorf("executing %q: %w", sql, err)
 		}
 	}
 
@@ -385,7 +386,7 @@ func (tm *TableManager) update(ctx context.Context,
 		stmt := fmt.Sprintf("COMMENT ON COLUMN %s.%s IS 'tag'",
 			tmplTable.String(), sqltemplate.QuoteIdentifier(col.Name))
 		if _, err := tx.Exec(ctx, stmt); err != nil {
-			return fmt.Errorf("setting column role comment: %s", err)
+			return fmt.Errorf("setting column role comment: %w", err)
 		}
 	}
 
