@@ -6,10 +6,14 @@ import (
 	_ "embed"
 	"errors"
 	"fmt"
+	"math"
 	"net"
+	"strconv"
 	"strings"
 	"time"
 
+	"github.com/mdlayher/vsock"
+
 	"github.com/influxdata/telegraf"
 	"github.com/influxdata/telegraf/config"
 	"github.com/influxdata/telegraf/internal"
@@ -55,13 +59,44 @@ func (sw *SocketWriter) Connect() error {
 	}
 
 	var c net.Conn
-	if tlsCfg == nil {
-		c, err = net.Dial(spl[0], spl[1])
+
+	if spl[0] == "vsock" {
+		addrTuple := strings.SplitN(spl[1], ":", 2)
+
+		// Check address string for containing two
+		if len(addrTuple) < 2 {
+			return errors.New("CID and/or port number missing")
+		}
+
+		// Parse CID and port number from address string both being 32-bit
+		// source: https://man7.org/linux/man-pages/man7/vsock.7.html
+		cid, err := strconv.ParseUint(addrTuple[0], 10, 32)
+		if err != nil {
+			return fmt.Errorf("failed to parse CID %s: %w", addrTuple[0], err)
+		}
+		if (cid >= uint64(math.Pow(2, 32))-1) && (cid <= 0) {
+			return fmt.Errorf("CID %d is out of range", cid)
+		}
+		port, err := strconv.ParseUint(addrTuple[1], 10, 32)
+		if err != nil {
+			return fmt.Errorf("failed to parse port number %s: %w", addrTuple[1], err)
+		}
+		if (port >= uint64(math.Pow(2, 32))-1) && (port <= 0) {
+			return fmt.Errorf("port number %d is out of range", port)
+		}
+		c, err = vsock.Dial(uint32(cid), uint32(port), nil)
+		if err != nil {
+			return err
+		}
 	} else {
-		c, err = tls.Dial(spl[0], spl[1], tlsCfg)
-	}
-	if err != nil {
-		return err
+		if tlsCfg == nil {
+			c, err = net.Dial(spl[0], spl[1])
+		} else {
+			c, err = tls.Dial(spl[0], spl[1], tlsCfg)
+		}
+		if err != nil {
+			return err
+		}
 	}
 
 	if err := sw.setKeepAlive(c); err != nil {
