@@ -3,12 +3,15 @@ package collectd
 import (
 	"context"
 	"testing"
+	"time"
 
 	"collectd.org/api"
 	"collectd.org/network"
 	"github.com/stretchr/testify/require"
 
 	"github.com/influxdata/telegraf"
+	"github.com/influxdata/telegraf/metric"
+	"github.com/influxdata/telegraf/testutil"
 )
 
 type AuthMap struct {
@@ -290,10 +293,10 @@ func TestParseLine(t *testing.T) {
 		ParseMultiValue: "split",
 	}
 	require.NoError(t, parser.Init())
-	metric, err := parser.ParseLine(string(bytes))
+	m, err := parser.ParseLine(string(bytes))
 	require.NoError(t, err)
 
-	assertEqualMetrics(t, singleMetric.expected, []telegraf.Metric{metric})
+	assertEqualMetrics(t, singleMetric.expected, []telegraf.Metric{m})
 }
 
 func writeValueList(valueLists []api.ValueList) (*network.Buffer, error) {
@@ -318,3 +321,91 @@ func assertEqualMetrics(t *testing.T, expected []metricData, received []telegraf
 		require.Equal(t, expected[i].fields, m.Fields())
 	}
 }
+
+var benchmarkData = []api.ValueList{
+	{
+		Identifier: api.Identifier{
+			Host:           "xyzzy",
+			Plugin:         "cpu",
+			PluginInstance: "1",
+			Type:           "cpu",
+			TypeInstance:   "user",
+		},
+		Values: []api.Value{
+			api.Counter(4),
+		},
+		DSNames: []string(nil),
+	},
+	{
+		Identifier: api.Identifier{
+			Host:           "xyzzy",
+			Plugin:         "cpu",
+			PluginInstance: "2",
+			Type:           "cpu",
+			TypeInstance:   "user",
+		},
+		Values: []api.Value{
+			api.Counter(5),
+		},
+		DSNames: []string(nil),
+	},
+}
+
+func TestBenchmarkData(t *testing.T) {
+	expected := []telegraf.Metric{
+		metric.New(
+			"cpu_value",
+			map[string]string{
+				"host":          "xyzzy",
+				"instance":      "1",
+				"type":          "cpu",
+				"type_instance": "user",
+			},
+			map[string]interface{}{
+				"value": 4.0,
+			},
+			time.Unix(0, 0),
+		),
+		metric.New(
+			"cpu_value",
+			map[string]string{
+				"host":          "xyzzy",
+				"instance":      "2",
+				"type":          "cpu",
+				"type_instance": "user",
+			},
+			map[string]interface{}{
+				"value": 5.0,
+			},
+			time.Unix(0, 0),
+		),
+	}
+
+	buf, err := writeValueList(benchmarkData)
+	require.NoError(t, err)
+	bytes, err := buf.Bytes()
+	require.NoError(t, err)
+
+	parser := &Parser{}
+	require.NoError(t, parser.Init())
+	actual, err := parser.Parse(bytes)
+	require.NoError(t, err)
+
+	testutil.RequireMetricsEqual(t, expected, actual, testutil.IgnoreTime(), testutil.SortMetrics())
+}
+
+func BenchmarkParsing(b *testing.B) {
+	buf, err := writeValueList(benchmarkData)
+	require.NoError(b, err)
+	bytes, err := buf.Bytes()
+	require.NoError(b, err)
+
+	parser := &Parser{}
+	require.NoError(b, parser.Init())
+
+	b.ResetTimer()
+	for n := 0; n < b.N; n++ {
+		//nolint:errcheck // Benchmarking so skip the error check to avoid the unnecessary operations
+		parser.Parse(bytes)
+	}
+}
