@@ -1,22 +1,26 @@
 package xpath
 
 import (
+	"encoding/base64"
 	"encoding/hex"
 	"errors"
 	"fmt"
+	"reflect"
+	"slices"
 	"strconv"
 	"strings"
 	"time"
 
 	"github.com/antchfx/jsonquery"
 	path "github.com/antchfx/xpath"
-	"github.com/doclambda/protobufquery"
+	"github.com/srebhan/cborquery"
+	"github.com/srebhan/protobufquery"
 
 	"github.com/influxdata/telegraf"
+	"github.com/influxdata/telegraf/config"
 	"github.com/influxdata/telegraf/filter"
 	"github.com/influxdata/telegraf/internal"
 	"github.com/influxdata/telegraf/metric"
-	"github.com/influxdata/telegraf/models"
 	"github.com/influxdata/telegraf/plugins/parsers"
 )
 
@@ -27,28 +31,31 @@ type dataDocument interface {
 	QueryAll(node dataNode, expr string) ([]dataNode, error)
 	CreateXPathNavigator(node dataNode) path.NodeNavigator
 	GetNodePath(node, relativeTo dataNode, sep string) string
+	GetNodeName(node dataNode, sep string, withParent bool) string
 	OutputXML(node dataNode) string
 }
 
 type Parser struct {
-	Format              string            `toml:"-"`
-	ProtobufMessageDef  string            `toml:"xpath_protobuf_file"`
-	ProtobufMessageType string            `toml:"xpath_protobuf_type"`
-	ProtobufImportPaths []string          `toml:"xpath_protobuf_import_paths"`
-	ProtobufSkipBytes   int64             `toml:"xpath_protobuf_skip_bytes"`
-	PrintDocument       bool              `toml:"xpath_print_document"`
-	AllowEmptySelection bool              `toml:"xpath_allow_empty_selection"`
-	NativeTypes         bool              `toml:"xpath_native_types"`
-	Configs             []Config          `toml:"xpath"`
-	DefaultMetricName   string            `toml:"-"`
-	DefaultTags         map[string]string `toml:"-"`
-	Log                 telegraf.Logger   `toml:"-"`
+	Format               string            `toml:"-"`
+	ProtobufMessageFiles []string          `toml:"xpath_protobuf_files"`
+	ProtobufMessageDef   string            `toml:"xpath_protobuf_file" deprecated:"1.32.0;1.40.0;use 'xpath_protobuf_files' instead"`
+	ProtobufMessageType  string            `toml:"xpath_protobuf_type"`
+	ProtobufImportPaths  []string          `toml:"xpath_protobuf_import_paths"`
+	ProtobufSkipBytes    int64             `toml:"xpath_protobuf_skip_bytes"`
+	PrintDocument        bool              `toml:"xpath_print_document"`
+	AllowEmptySelection  bool              `toml:"xpath_allow_empty_selection"`
+	NativeTypes          bool              `toml:"xpath_native_types"`
+	Trace                bool              `toml:"xpath_trace"`
+	Configs              []Config          `toml:"xpath"`
+	DefaultMetricName    string            `toml:"-"`
+	DefaultTags          map[string]string `toml:"-"`
+	Log                  telegraf.Logger   `toml:"-"`
 
 	// Required for backward compatibility
-	ConfigsXML     []Config `toml:"xml" deprecated:"1.23.1;use 'xpath' instead"`
-	ConfigsJSON    []Config `toml:"xpath_json" deprecated:"1.23.1;use 'xpath' instead"`
-	ConfigsMsgPack []Config `toml:"xpath_msgpack" deprecated:"1.23.1;use 'xpath' instead"`
-	ConfigsProto   []Config `toml:"xpath_protobuf" deprecated:"1.23.1;use 'xpath' instead"`
+	ConfigsXML     []Config `toml:"xml" deprecated:"1.23.1;1.35.0;use 'xpath' instead"`
+	ConfigsJSON    []Config `toml:"xpath_json" deprecated:"1.23.1;1.35.0;use 'xpath' instead"`
+	ConfigsMsgPack []Config `toml:"xpath_msgpack" deprecated:"1.23.1;1.35.0;use 'xpath' instead"`
+	ConfigsProto   []Config `toml:"xpath_protobuf" deprecated:"1.23.1;1.35.0;use 'xpath' instead"`
 
 	document dataDocument
 }
@@ -63,6 +70,7 @@ type Config struct {
 	Fields       map[string]string `toml:"fields"`
 	FieldsInt    map[string]string `toml:"fields_int"`
 	FieldsHex    []string          `toml:"fields_bytes_as_hex"`
+	FieldsBase64 []string          `toml:"fields_bytes_as_base64"`
 
 	FieldSelection  string `toml:"field_selection"`
 	FieldNameQuery  string `toml:"field_name"`
@@ -74,8 +82,9 @@ type Config struct {
 	TagValueQuery string `toml:"tag_value"`
 	TagNameExpand bool   `toml:"tag_name_expansion"`
 
-	FieldsHexFilter filter.Filter
-	Location        *time.Location
+	FieldsHexFilter    filter.Filter
+	FieldsBase64Filter filter.Filter
+	Location           *time.Location
 }
 
 func (p *Parser) Init() error {
@@ -86,21 +95,23 @@ func (p *Parser) Init() error {
 		// Required for backward compatibility
 		if len(p.ConfigsXML) > 0 {
 			p.Configs = append(p.Configs, p.ConfigsXML...)
-			models.PrintOptionDeprecationNotice(telegraf.Warn, "parsers.xpath", "xml", telegraf.DeprecationInfo{
+			config.PrintOptionDeprecationNotice("parsers.xpath", "xml", telegraf.DeprecationInfo{
 				Since:     "1.23.1",
-				RemovalIn: "2.0.0",
+				RemovalIn: "1.35.0",
 				Notice:    "use 'xpath' instead",
 			})
 		}
+	case "xpath_cbor":
+		p.document = &cborDocument{}
 	case "xpath_json":
 		p.document = &jsonDocument{}
 
 		// Required for backward compatibility
 		if len(p.ConfigsJSON) > 0 {
 			p.Configs = append(p.Configs, p.ConfigsJSON...)
-			models.PrintOptionDeprecationNotice(telegraf.Warn, "parsers.xpath", "xpath_json", telegraf.DeprecationInfo{
+			config.PrintOptionDeprecationNotice("parsers.xpath", "xpath_json", telegraf.DeprecationInfo{
 				Since:     "1.23.1",
-				RemovalIn: "2.0.0",
+				RemovalIn: "1.35.0",
 				Notice:    "use 'xpath' instead",
 			})
 		}
@@ -110,19 +121,22 @@ func (p *Parser) Init() error {
 		// Required for backward compatibility
 		if len(p.ConfigsMsgPack) > 0 {
 			p.Configs = append(p.Configs, p.ConfigsMsgPack...)
-			models.PrintOptionDeprecationNotice(telegraf.Warn, "parsers.xpath", "xpath_msgpack", telegraf.DeprecationInfo{
+			config.PrintOptionDeprecationNotice("parsers.xpath", "xpath_msgpack", telegraf.DeprecationInfo{
 				Since:     "1.23.1",
-				RemovalIn: "2.0.0",
+				RemovalIn: "1.35.0",
 				Notice:    "use 'xpath' instead",
 			})
 		}
 	case "xpath_protobuf":
+		if p.ProtobufMessageDef != "" && !slices.Contains(p.ProtobufMessageFiles, p.ProtobufMessageDef) {
+			p.ProtobufMessageFiles = append(p.ProtobufMessageFiles, p.ProtobufMessageDef)
+		}
 		pbdoc := protobufDocument{
-			MessageDefinition: p.ProtobufMessageDef,
-			MessageType:       p.ProtobufMessageType,
-			ImportPaths:       p.ProtobufImportPaths,
-			SkipBytes:         p.ProtobufSkipBytes,
-			Log:               p.Log,
+			MessageFiles: p.ProtobufMessageFiles,
+			MessageType:  p.ProtobufMessageType,
+			ImportPaths:  p.ProtobufImportPaths,
+			SkipBytes:    p.ProtobufSkipBytes,
+			Log:          p.Log,
 		}
 		if err := pbdoc.Init(); err != nil {
 			return err
@@ -132,9 +146,9 @@ func (p *Parser) Init() error {
 		// Required for backward compatibility
 		if len(p.ConfigsProto) > 0 {
 			p.Configs = append(p.Configs, p.ConfigsProto...)
-			models.PrintOptionDeprecationNotice(telegraf.Warn, "parsers.xpath", "xpath_proto", telegraf.DeprecationInfo{
+			config.PrintOptionDeprecationNotice("parsers.xpath", "xpath_proto", telegraf.DeprecationInfo{
 				Since:     "1.23.1",
-				RemovalIn: "2.0.0",
+				RemovalIn: "1.35.0",
 				Notice:    "use 'xpath' instead",
 			})
 		}
@@ -148,29 +162,35 @@ func (p *Parser) Init() error {
 	}
 
 	// Update the configs with default values
-	for i, config := range p.Configs {
-		if config.Selection == "" {
-			config.Selection = "/"
+	for i, cfg := range p.Configs {
+		if cfg.Selection == "" {
+			cfg.Selection = "/"
 		}
-		if config.TimestampFmt == "" {
-			config.TimestampFmt = "unix"
+		if cfg.TimestampFmt == "" {
+			cfg.TimestampFmt = "unix"
 		}
-		if config.Timezone == "" {
-			config.Location = time.UTC
+		if cfg.Timezone == "" {
+			cfg.Location = time.UTC
 		} else {
-			loc, err := time.LoadLocation(config.Timezone)
+			loc, err := time.LoadLocation(cfg.Timezone)
 			if err != nil {
 				return fmt.Errorf("invalid location in config %d: %w", i+1, err)
 			}
-			config.Location = loc
+			cfg.Location = loc
 		}
-		f, err := filter.Compile(config.FieldsHex)
+		f, err := filter.Compile(cfg.FieldsHex)
 		if err != nil {
 			return fmt.Errorf("creating hex-fields filter failed: %w", err)
 		}
-		config.FieldsHexFilter = f
+		cfg.FieldsHexFilter = f
 
-		p.Configs[i] = config
+		bf, err := filter.Compile(cfg.FieldsBase64)
+		if err != nil {
+			return fmt.Errorf("creating base64-fields filter failed: %w", err)
+		}
+		cfg.FieldsBase64Filter = bf
+
+		p.Configs[i] = cfg
 	}
 
 	return nil
@@ -191,19 +211,19 @@ func (p *Parser) Parse(buf []byte) ([]telegraf.Metric, error) {
 	// Queries
 	metrics := make([]telegraf.Metric, 0)
 	p.Log.Debugf("Number of configs: %d", len(p.Configs))
-	for _, config := range p.Configs {
-		selectedNodes, err := p.document.QueryAll(doc, config.Selection)
+	for _, cfg := range p.Configs {
+		selectedNodes, err := p.document.QueryAll(doc, cfg.Selection)
 		if err != nil {
 			return nil, err
 		}
 		if (len(selectedNodes) < 1 || selectedNodes[0] == nil) && !p.AllowEmptySelection {
-			p.debugEmptyQuery("metric selection", doc, config.Selection)
-			return metrics, fmt.Errorf("cannot parse with empty selection node")
+			p.debugEmptyQuery("metric selection", doc, cfg.Selection)
+			return metrics, errors.New("cannot parse with empty selection node")
 		}
 		p.Log.Debugf("Number of selected metric nodes: %d", len(selectedNodes))
 
 		for _, selected := range selectedNodes {
-			m, err := p.parseQuery(t, doc, selected, config)
+			m, err := p.parseQuery(t, doc, selected, cfg)
 			if err != nil {
 				return metrics, err
 			}
@@ -235,15 +255,15 @@ func (p *Parser) SetDefaultTags(tags map[string]string) {
 	p.DefaultTags = tags
 }
 
-func (p *Parser) parseQuery(starttime time.Time, doc, selected dataNode, config Config) (telegraf.Metric, error) {
+func (p *Parser) parseQuery(starttime time.Time, doc, selected dataNode, cfg Config) (telegraf.Metric, error) {
 	var timestamp time.Time
 	var metricname string
 
 	// Determine the metric name. If a query was specified, use the result of this query and the default metric name
 	// otherwise.
 	metricname = p.DefaultMetricName
-	if len(config.MetricQuery) > 0 {
-		v, err := p.executeQuery(doc, selected, config.MetricQuery)
+	if len(cfg.MetricQuery) > 0 {
+		v, err := p.executeQuery(doc, selected, cfg.MetricQuery)
 		if err != nil {
 			return nil, fmt.Errorf("failed to query metric name: %w", err)
 		}
@@ -257,15 +277,15 @@ func (p *Parser) parseQuery(starttime time.Time, doc, selected dataNode, config
 	}
 
 	// By default take the time the parser was invoked and override the value
-	// with the queried timestamp if an expresion was specified.
+	// with the queried timestamp if an expression was specified.
 	timestamp = starttime
-	if len(config.Timestamp) > 0 {
-		v, err := p.executeQuery(doc, selected, config.Timestamp)
+	if len(cfg.Timestamp) > 0 {
+		v, err := p.executeQuery(doc, selected, cfg.Timestamp)
 		if err != nil {
 			return nil, fmt.Errorf("failed to query timestamp: %w", err)
 		}
 		if v != nil {
-			timestamp, err = internal.ParseTimestamp(config.TimestampFmt, v, config.Location)
+			timestamp, err = internal.ParseTimestamp(cfg.TimestampFmt, v, cfg.Location)
 			if err != nil {
 				return nil, fmt.Errorf("failed to parse timestamp: %w", err)
 			}
@@ -274,39 +294,20 @@ func (p *Parser) parseQuery(starttime time.Time, doc, selected dataNode, config
 
 	// Query tags and add default ones
 	tags := make(map[string]string)
-	for name, query := range config.Tags {
-		// Execute the query and cast the returned values into strings
-		v, err := p.executeQuery(doc, selected, query)
-		if err != nil {
-			return nil, fmt.Errorf("failed to query tag %q: %w", name, err)
-		}
-		switch v := v.(type) {
-		case string:
-			tags[name] = v
-		case bool:
-			tags[name] = strconv.FormatBool(v)
-		case float64:
-			tags[name] = strconv.FormatFloat(v, 'G', -1, 64)
-		case nil:
-			continue
-		default:
-			return nil, fmt.Errorf("unknown format '%T' for tag %q", v, name)
-		}
-	}
 
 	// Handle the tag batch definitions if any.
-	if len(config.TagSelection) > 0 {
+	if len(cfg.TagSelection) > 0 {
 		tagnamequery := "name()"
 		tagvaluequery := "."
-		if len(config.TagNameQuery) > 0 {
-			tagnamequery = config.TagNameQuery
+		if len(cfg.TagNameQuery) > 0 {
+			tagnamequery = cfg.TagNameQuery
 		}
-		if len(config.TagValueQuery) > 0 {
-			tagvaluequery = config.TagValueQuery
+		if len(cfg.TagValueQuery) > 0 {
+			tagvaluequery = cfg.TagValueQuery
 		}
 
 		// Query all tags
-		selectedTagNodes, err := p.document.QueryAll(selected, config.TagSelection)
+		selectedTagNodes, err := p.document.QueryAll(selected, cfg.TagSelection)
 		if err != nil {
 			return nil, err
 		}
@@ -321,18 +322,13 @@ func (p *Parser) parseQuery(starttime time.Time, doc, selected dataNode, config
 				if !ok {
 					return nil, fmt.Errorf("failed to query tag name with query %q: result is not a string (%v)", tagnamequery, n)
 				}
+				name = p.constructFieldName(selected, selectedtag, name, cfg.TagNameExpand)
+
 				v, err := p.executeQuery(doc, selectedtag, tagvaluequery)
 				if err != nil {
 					return nil, fmt.Errorf("failed to query tag value for %q: %w", name, err)
 				}
 
-				if config.TagNameExpand {
-					p := p.document.GetNodePath(selectedtag, selected, "_")
-					if len(p) > 0 {
-						name = p + "_" + name
-					}
-				}
-
 				// Check if field name already exists and if so, append an index number.
 				if _, ok := tags[name]; ok {
 					for i := 1; ; i++ {
@@ -352,17 +348,111 @@ func (p *Parser) parseQuery(starttime time.Time, doc, selected dataNode, config
 				tags[name] = s
 			}
 		} else {
-			p.debugEmptyQuery("tag selection", selected, config.TagSelection)
+			p.debugEmptyQuery("tag selection", selected, cfg.TagSelection)
 		}
 	}
 
+	// Handle explicitly defined tags
+	for name, query := range cfg.Tags {
+		// Execute the query and cast the returned values into strings
+		v, err := p.executeQuery(doc, selected, query)
+		if err != nil {
+			return nil, fmt.Errorf("failed to query tag %q: %w", name, err)
+		}
+		switch v := v.(type) {
+		case string:
+			tags[name] = v
+		case bool:
+			tags[name] = strconv.FormatBool(v)
+		case float64:
+			tags[name] = strconv.FormatFloat(v, 'G', -1, 64)
+		case nil:
+			continue
+		default:
+			return nil, fmt.Errorf("unknown format '%T' for tag %q", v, name)
+		}
+	}
+
+	// Add default tags
 	for name, v := range p.DefaultTags {
 		tags[name] = v
 	}
 
 	// Query fields
 	fields := make(map[string]interface{})
-	for name, query := range config.FieldsInt {
+
+	// Handle the field batch definitions if any.
+	if len(cfg.FieldSelection) > 0 {
+		fieldnamequery := "name()"
+		fieldvaluequery := "."
+		if len(cfg.FieldNameQuery) > 0 {
+			fieldnamequery = cfg.FieldNameQuery
+		}
+		if len(cfg.FieldValueQuery) > 0 {
+			fieldvaluequery = cfg.FieldValueQuery
+		}
+
+		// Query all fields
+		selectedFieldNodes, err := p.document.QueryAll(selected, cfg.FieldSelection)
+		if err != nil {
+			return nil, err
+		}
+		p.Log.Debugf("Number of selected field nodes: %d", len(selectedFieldNodes))
+		if len(selectedFieldNodes) > 0 && selectedFieldNodes[0] != nil {
+			for _, selectedfield := range selectedFieldNodes {
+				n, err := p.executeQuery(doc, selectedfield, fieldnamequery)
+				if err != nil {
+					return nil, fmt.Errorf("failed to query field name with query %q: %w", fieldnamequery, err)
+				}
+				name, ok := n.(string)
+				if !ok {
+					return nil, fmt.Errorf("failed to query field name with query %q: result is not a string (%v)", fieldnamequery, n)
+				}
+				name = p.constructFieldName(selected, selectedfield, name, cfg.FieldNameExpand)
+
+				v, err := p.executeQuery(doc, selectedfield, fieldvaluequery)
+				if err != nil {
+					return nil, fmt.Errorf("failed to query field value for %q: %w", name, err)
+				}
+
+				// Check if field name already exists and if so, append an index number.
+				if _, ok := fields[name]; ok {
+					for i := 1; ; i++ {
+						p := name + "_" + strconv.Itoa(i)
+						if _, ok := fields[p]; !ok {
+							name = p
+							break
+						}
+					}
+				}
+
+				// Handle complex types which would be dropped otherwise for
+				// native type handling
+				if v != nil {
+					switch reflect.TypeOf(v).Kind() {
+					case reflect.Array, reflect.Slice, reflect.Map:
+						if b, ok := v.([]byte); ok {
+							if cfg.FieldsHexFilter != nil && cfg.FieldsHexFilter.Match(name) {
+								v = hex.EncodeToString(b)
+							}
+							if cfg.FieldsBase64Filter != nil && cfg.FieldsBase64Filter.Match(name) {
+								v = base64.StdEncoding.EncodeToString(b)
+							}
+						} else {
+							v = fmt.Sprintf("%v", v)
+						}
+					}
+				}
+
+				fields[name] = v
+			}
+		} else {
+			p.debugEmptyQuery("field selection", selected, cfg.FieldSelection)
+		}
+	}
+
+	// Handle explicitly defined fields
+	for name, query := range cfg.FieldsInt {
 		// Execute the query and cast the returned values into integers
 		v, err := p.executeQuery(doc, selected, query)
 		if err != nil {
@@ -388,75 +478,32 @@ func (p *Parser) parseQuery(starttime time.Time, doc, selected dataNode, config
 		}
 	}
 
-	for name, query := range config.Fields {
+	for name, query := range cfg.Fields {
 		// Execute the query and store the result in fields
 		v, err := p.executeQuery(doc, selected, query)
 		if err != nil {
 			return nil, fmt.Errorf("failed to query field %q: %w", name, err)
 		}
-		fields[name] = v
-	}
 
-	// Handle the field batch definitions if any.
-	if len(config.FieldSelection) > 0 {
-		fieldnamequery := "name()"
-		fieldvaluequery := "."
-		if len(config.FieldNameQuery) > 0 {
-			fieldnamequery = config.FieldNameQuery
-		}
-		if len(config.FieldValueQuery) > 0 {
-			fieldvaluequery = config.FieldValueQuery
-		}
-
-		// Query all fields
-		selectedFieldNodes, err := p.document.QueryAll(selected, config.FieldSelection)
-		if err != nil {
-			return nil, err
-		}
-		p.Log.Debugf("Number of selected field nodes: %d", len(selectedFieldNodes))
-		if len(selectedFieldNodes) > 0 && selectedFieldNodes[0] != nil {
-			for _, selectedfield := range selectedFieldNodes {
-				n, err := p.executeQuery(doc, selectedfield, fieldnamequery)
-				if err != nil {
-					return nil, fmt.Errorf("failed to query field name with query %q: %w", fieldnamequery, err)
-				}
-				name, ok := n.(string)
-				if !ok {
-					return nil, fmt.Errorf("failed to query field name with query %q: result is not a string (%v)", fieldnamequery, n)
-				}
-				v, err := p.executeQuery(doc, selectedfield, fieldvaluequery)
-				if err != nil {
-					return nil, fmt.Errorf("failed to query field value for %q: %w", name, err)
-				}
-
-				if config.FieldNameExpand {
-					p := p.document.GetNodePath(selectedfield, selected, "_")
-					if len(p) > 0 {
-						name = p + "_" + name
-					}
-				}
-
-				// Check if field name already exists and if so, append an index number.
-				if _, ok := fields[name]; ok {
-					for i := 1; ; i++ {
-						p := name + "_" + strconv.Itoa(i)
-						if _, ok := fields[p]; !ok {
-							name = p
-							break
-						}
-					}
-				}
-
-				if config.FieldsHexFilter != nil && config.FieldsHexFilter.Match(name) {
-					if b, ok := v.([]byte); ok {
+		// Handle complex types which would be dropped otherwise for
+		// native type handling
+		if v != nil {
+			switch reflect.TypeOf(v).Kind() {
+			case reflect.Array, reflect.Slice, reflect.Map:
+				if b, ok := v.([]byte); ok {
+					if cfg.FieldsHexFilter != nil && cfg.FieldsHexFilter.Match(name) {
 						v = hex.EncodeToString(b)
 					}
+					if cfg.FieldsBase64Filter != nil && cfg.FieldsBase64Filter.Match(name) {
+						v = base64.StdEncoding.EncodeToString(b)
+					}
+				} else {
+					v = fmt.Sprintf("%v", v)
 				}
-				fields[name] = v
 			}
-		} else {
-			p.debugEmptyQuery("field selection", selected, config.FieldSelection)
 		}
+
+		fields[name] = v
 	}
 
 	return metric.New(metricname, tags, fields, timestamp), nil
@@ -491,13 +538,15 @@ func (p *Parser) executeQuery(doc, selected dataNode, query string) (r interface
 		// enabled, we should return the native type of the data
 		if p.NativeTypes {
 			switch nn := current.(type) {
+			case *cborquery.NodeNavigator:
+				return nn.GetValue(), nil
 			case *jsonquery.NodeNavigator:
 				return nn.GetValue(), nil
 			case *protobufquery.NodeNavigator:
 				return nn.GetValue(), nil
 			}
 		}
-		// Fallback to get the string value representation
+
 		return iter.Current().Value(), nil
 	}
 
@@ -507,7 +556,7 @@ func (p *Parser) executeQuery(doc, selected dataNode, query string) (r interface
 func splitLastPathElement(query string) []string {
 	// This is a rudimentary xpath-parser that splits the path
 	// into the last path element and the remaining path-part.
-	// The last path element is then further splitted into
+	// The last path element is then further split into
 	// parts such as attributes or selectors. Each returned
 	// element is a full path!
 
@@ -516,18 +565,18 @@ func splitLastPathElement(query string) []string {
 		return []string{}
 	}
 
-	seperatorIdx := strings.LastIndex(query, "/")
-	if seperatorIdx < 0 {
+	separatorIdx := strings.LastIndex(query, "/")
+	if separatorIdx < 0 {
 		query = "./" + query
-		seperatorIdx = 1
+		separatorIdx = 1
 	}
 
 	// For double slash we want to split at the first slash
-	if seperatorIdx > 0 && query[seperatorIdx-1] == byte('/') {
-		seperatorIdx--
+	if separatorIdx > 0 && query[separatorIdx-1] == byte('/') {
+		separatorIdx--
 	}
 
-	base := query[:seperatorIdx]
+	base := query[:separatorIdx]
 	if base == "" {
 		base = "/"
 	}
@@ -535,7 +584,7 @@ func splitLastPathElement(query string) []string {
 	elements := make([]string, 0, 3)
 	elements = append(elements, base)
 
-	offset := seperatorIdx
+	offset := separatorIdx
 	if i := strings.Index(query[offset:], "::"); i >= 0 {
 		// Check for axis operator
 		offset += i
@@ -555,8 +604,32 @@ func splitLastPathElement(query string) []string {
 	return elements
 }
 
+func (p *Parser) constructFieldName(root, node dataNode, name string, expand bool) string {
+	var expansion string
+
+	// In case the name is empty we should determine the current node's name.
+	// This involves array index expansion in case the parent of the node is
+	// and array. If we expanded here, we should skip our parent as this is
+	// already encoded in the name
+	if name == "" {
+		name = p.document.GetNodeName(node, "_", !expand)
+	}
+
+	// If name expansion is requested, construct a path between the current
+	// node and the root node of the selection. Concatenate the elements with
+	// an underscore.
+	if expand {
+		expansion = p.document.GetNodePath(node, root, "_")
+	}
+
+	if len(expansion) > 0 {
+		name = expansion + "_" + name
+	}
+	return name
+}
+
 func (p *Parser) debugEmptyQuery(operation string, root dataNode, initialquery string) {
-	if p.Log == nil {
+	if p.Log == nil || !p.Trace {
 		return
 	}
 
@@ -595,6 +668,14 @@ func init() {
 			}
 		},
 	)
+	parsers.Add("xpath_cbor",
+		func(defaultMetricName string) telegraf.Parser {
+			return &Parser{
+				Format:            "xpath_cbor",
+				DefaultMetricName: defaultMetricName,
+			}
+		},
+	)
 	parsers.Add("xpath_json",
 		func(defaultMetricName string) telegraf.Parser {
 			return &Parser{
