@@ -13,7 +13,6 @@ import (
 	"github.com/influxdata/telegraf/config"
 	"github.com/influxdata/telegraf/internal/snmp"
 	"github.com/influxdata/telegraf/plugins/common/parallel"
-	si "github.com/influxdata/telegraf/plugins/inputs/snmp"
 	"github.com/influxdata/telegraf/plugins/processors"
 )
 
@@ -25,7 +24,6 @@ type keyType = string
 type valType = nameMap
 
 type mapFunc func(agent string) (nameMap, error)
-type makeTableFunc func(string) (*si.Table, error)
 
 type sigMap map[string]chan struct{}
 
@@ -43,8 +41,8 @@ type IfName struct {
 
 	Log telegraf.Logger `toml:"-"`
 
-	ifTable  *si.Table
-	ifXTable *si.Table
+	ifTable  *snmp.Table
+	ifXTable *snmp.Table
 
 	cache    *TTLCache
 	lock     sync.Mutex
@@ -52,9 +50,6 @@ type IfName struct {
 	sigs     sigMap
 
 	getMapRemote mapFunc
-	makeTable    makeTableFunc
-
-	translator si.Translator
 }
 
 const minRetry = 5 * time.Minute
@@ -65,7 +60,6 @@ func (*IfName) SampleConfig() string {
 
 func (d *IfName) Init() error {
 	d.getMapRemote = d.getMapRemoteNoMock
-	d.makeTable = d.makeTableNoMock
 
 	c := NewTTLCache(time.Duration(d.CacheTTL), d.CacheSize)
 	d.cache = &c
@@ -76,10 +70,6 @@ func (d *IfName) Init() error {
 		return fmt.Errorf("parsing SNMP client config: %w", err)
 	}
 
-	// Since OIDs in this plugin are always numeric there is no need
-	// to translate.
-	d.translator = si.NewNetsnmpTranslator()
-
 	return nil
 }
 
@@ -98,7 +88,7 @@ func (d *IfName) addTag(metric telegraf.Metric) error {
 
 	num, err := strconv.ParseUint(numS, 10, 64)
 	if err != nil {
-		return fmt.Errorf("couldn't parse source tag as uint")
+		return errors.New("couldn't parse source tag as uint")
 	}
 
 	firstTime := true
@@ -212,7 +202,7 @@ func (d *IfName) getMap(agent string) (entry nameMap, age time.Duration, err err
 		if ok {
 			return m, age, nil
 		}
-		return nil, 0, fmt.Errorf("getting remote table from cache")
+		return nil, 0, errors.New("getting remote table from cache")
 	}
 
 	// The cache missed and this is the first request for this
@@ -275,29 +265,23 @@ func init() {
 			AgentTag:           "agent",
 			CacheSize:          100,
 			MaxParallelLookups: 100,
-			ClientConfig: snmp.ClientConfig{
-				Retries:        3,
-				MaxRepetitions: 10,
-				Timeout:        config.Duration(5 * time.Second),
-				Version:        2,
-				Community:      "public",
-			},
-			CacheTTL: config.Duration(8 * time.Hour),
+			ClientConfig:       *snmp.DefaultClientConfig(),
+			CacheTTL:           config.Duration(8 * time.Hour),
 		}
 	})
 }
 
-func (d *IfName) makeTableNoMock(oid string) (*si.Table, error) {
+func (d *IfName) makeTable(oid string) (*snmp.Table, error) {
 	var err error
-	tab := si.Table{
+	tab := snmp.Table{
 		Name:       "ifTable",
 		IndexAsTag: true,
-		Fields: []si.Field{
+		Fields: []snmp.Field{
 			{Oid: oid, Name: "ifName"},
 		},
 	}
 
-	err = tab.Init(d.translator)
+	err = tab.Init(nil)
 	if err != nil {
 		//Init already wraps
 		return nil, err
@@ -306,17 +290,17 @@ func (d *IfName) makeTableNoMock(oid string) (*si.Table, error) {
 	return &tab, nil
 }
 
-func (d *IfName) buildMap(gs snmp.GosnmpWrapper, tab *si.Table) (nameMap, error) {
+func (d *IfName) buildMap(gs snmp.GosnmpWrapper, tab *snmp.Table) (nameMap, error) {
 	var err error
 
-	rtab, err := tab.Build(gs, true, d.translator)
+	rtab, err := tab.Build(gs, true)
 	if err != nil {
 		//Build already wraps
 		return nil, err
 	}
 
 	if len(rtab.Rows) == 0 {
-		return nil, fmt.Errorf("empty table")
+		return nil, errors.New("empty table")
 	}
 
 	t := make(nameMap)
@@ -325,11 +309,11 @@ func (d *IfName) buildMap(gs snmp.GosnmpWrapper, tab *si.Table) (nameMap, error)
 		if !ok {
 			//should always have an index tag because the table should
 			//always have IndexAsTag true
-			return nil, fmt.Errorf("no index tag")
+			return nil, errors.New("no index tag")
 		}
 		i, err := strconv.ParseUint(iStr, 10, 64)
 		if err != nil {
-			return nil, fmt.Errorf("index tag isn't a uint")
+			return nil, errors.New("index tag isn't a uint")
 		}
 		nameIf, ok := v.Fields["ifName"]
 		if !ok {
