@@ -13,16 +13,69 @@ import (
 	"github.com/stretchr/testify/require"
 
 	"github.com/influxdata/telegraf"
+	"github.com/influxdata/telegraf/plugins/serializers"
 	"github.com/influxdata/telegraf/testutil"
 )
 
+func BenchmarkRemoteWrite(b *testing.B) {
+	batch := make([]telegraf.Metric, 1000)
+	for i := range batch {
+		batch[i] = testutil.MustMetric(
+			"cpu",
+			map[string]string{
+				"host": "example.org",
+				"C":    "D",
+				"A":    "B",
+			},
+			map[string]interface{}{
+				"time_idle": 42.0,
+			},
+			time.Unix(0, 0),
+		)
+	}
+	s := &Serializer{}
+	for n := 0; n < b.N; n++ {
+		//nolint:errcheck // Benchmarking so skip the error check to avoid the unnecessary operations
+		s.SerializeBatch(batch)
+	}
+}
+
 func TestRemoteWriteSerialize(t *testing.T) {
 	tests := []struct {
 		name     string
-		config   FormatConfig
 		metric   telegraf.Metric
 		expected []byte
 	}{
+		// the only way that we can produce an empty metric name is if the
+		// metric is called "prometheus" and has no fields.
+		{
+			name: "empty name is skipped",
+			metric: testutil.MustMetric(
+				"prometheus",
+				map[string]string{
+					"host": "example.org",
+				},
+				map[string]interface{}{},
+				time.Unix(0, 0),
+			),
+			expected: []byte(``),
+		},
+		{
+			name: "empty labels are skipped",
+			metric: testutil.MustMetric(
+				"cpu",
+				map[string]string{
+					"": "example.org",
+				},
+				map[string]interface{}{
+					"time_idle": 42.0,
+				},
+				time.Unix(0, 0),
+			),
+			expected: []byte(`
+cpu_time_idle 42
+`),
+		},
 		{
 			name: "simple",
 			metric: testutil.MustMetric(
@@ -134,10 +187,9 @@ http_request_duration_seconds_bucket{le="0.5"} 129389
 	}
 	for _, tt := range tests {
 		t.Run(tt.name, func(t *testing.T) {
-			s := NewSerializer(FormatConfig{
-				MetricSortOrder: SortMetrics,
-				StringHandling:  tt.config.StringHandling,
-			})
+			s := &Serializer{
+				SortMetrics: true,
+			}
 			data, err := s.Serialize(tt.metric)
 			require.NoError(t, err)
 			actual, err := prompbToText(data)
@@ -151,10 +203,10 @@ http_request_duration_seconds_bucket{le="0.5"} 129389
 
 func TestRemoteWriteSerializeBatch(t *testing.T) {
 	tests := []struct {
-		name     string
-		config   FormatConfig
-		metrics  []telegraf.Metric
-		expected []byte
+		name          string
+		metrics       []telegraf.Metric
+		stringAsLabel bool
+		expected      []byte
 	}{
 		{
 			name: "simple",
@@ -463,11 +515,8 @@ cpu_time_idle 42
 `),
 		},
 		{
-			name: "string as label",
-			config: FormatConfig{
-				MetricSortOrder: SortMetrics,
-				StringHandling:  StringAsLabel,
-			},
+			name:          "string as label",
+			stringAsLabel: true,
 			metrics: []telegraf.Metric{
 				testutil.MustMetric(
 					"cpu",
@@ -484,11 +533,8 @@ cpu_time_idle{cpu="cpu0"} 42
 `),
 		},
 		{
-			name: "string as label duplicate tag",
-			config: FormatConfig{
-				MetricSortOrder: SortMetrics,
-				StringHandling:  StringAsLabel,
-			},
+			name:          "string as label duplicate tag",
+			stringAsLabel: true,
 			metrics: []telegraf.Metric{
 				testutil.MustMetric(
 					"cpu",
@@ -507,11 +553,8 @@ cpu_time_idle{cpu="cpu0"} 42
 `),
 		},
 		{
-			name: "replace characters when using string as label",
-			config: FormatConfig{
-				MetricSortOrder: SortMetrics,
-				StringHandling:  StringAsLabel,
-			},
+			name:          "replace characters when using string as label",
+			stringAsLabel: true,
 			metrics: []telegraf.Metric{
 				testutil.MustMetric(
 					"cpu",
@@ -614,11 +657,8 @@ rpc_duration_seconds_sum 17560473
 `),
 		},
 		{
-			name: "empty label string value",
-			config: FormatConfig{
-				MetricSortOrder: SortMetrics,
-				StringHandling:  StringAsLabel,
-			},
+			name:          "empty label string value",
+			stringAsLabel: true,
 			metrics: []telegraf.Metric{
 				testutil.MustMetric(
 					"prometheus",
@@ -638,10 +678,10 @@ rpc_duration_seconds_sum 17560473
 	}
 	for _, tt := range tests {
 		t.Run(tt.name, func(t *testing.T) {
-			s := NewSerializer(FormatConfig{
-				MetricSortOrder: SortMetrics,
-				StringHandling:  tt.config.StringHandling,
-			})
+			s := &Serializer{
+				SortMetrics:   true,
+				StringAsLabel: tt.stringAsLabel,
+			}
 			data, err := s.SerializeBatch(tt.metrics)
 			require.NoError(t, err)
 			actual, err := prompbToText(data)
@@ -667,14 +707,9 @@ func prompbToText(data []byte) ([]byte, error) {
 	}
 	samples := protoToSamples(&req)
 	for _, sample := range samples {
-		_, err = buf.Write([]byte(fmt.Sprintf("%s %s\n", sample.Metric.String(), sample.Value.String())))
-		if err != nil {
-			return nil, err
-		}
-	}
-	if err != nil {
-		return nil, err
+		buf.WriteString(fmt.Sprintf("%s %s\n", sample.Metric.String(), sample.Value.String()))
 	}
+
 	return buf.Bytes(), nil
 }
 
@@ -696,3 +731,24 @@ func protoToSamples(req *prompb.WriteRequest) model.Samples {
 	}
 	return samples
 }
+
+func BenchmarkSerialize(b *testing.B) {
+	s := &Serializer{}
+	metrics := serializers.BenchmarkMetrics(b)
+	b.ResetTimer()
+	for i := 0; i < b.N; i++ {
+		_, err := s.Serialize(metrics[i%len(metrics)])
+		require.NoError(b, err)
+	}
+}
+
+func BenchmarkSerializeBatch(b *testing.B) {
+	s := &Serializer{}
+	m := serializers.BenchmarkMetrics(b)
+	metrics := m[:]
+	b.ResetTimer()
+	for i := 0; i < b.N; i++ {
+		_, err := s.SerializeBatch(metrics)
+		require.NoError(b, err)
+	}
+}
